@@ -43,8 +43,8 @@ import java.util.Map;
 /** Implementation of {@link ConnectionBeanProvider} that uses a pool of 
  * {@link edu.xtec.util.db.ConnectionBean} objects.
  * Based on DbConnectionBroker 1.0.13, by Marc A. Mnich
- * @author fbusquets
- * @version 1.0.13
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.16
  */
 public class PooledConnectionBeanProvider extends ConnectionBeanProvider implements Runnable{
     
@@ -101,7 +101,8 @@ public class PooledConnectionBeanProvider extends ConnectionBeanProvider impleme
      * @throws Exception Throwed if dbDriver does not contain a valid driver name, or if it can't be
      * instantiated.
      */
-    protected void setUp(Map map) throws Exception {
+    @Override
+    protected void setUp(Map<String, String> map) throws Exception {
         
         super.setUp(map);
         if(dbDriver==null || dbDriver.length()==0)
@@ -114,7 +115,7 @@ public class PooledConnectionBeanProvider extends ConnectionBeanProvider impleme
         maxConns = Math.max(minConns, Math.min(15, Integer.parseInt(getValue(map, MAX_CONNS, DEFAULT_MAX_CONNS))));
         logFileString = getValue(map, LOG_FILE, DEFAULT_LOG_FILE);
         double maxConnTime = new Double(getValue(map, MAX_CONN_TIME, DEFAULT_MAX_CONN_TIME)).doubleValue();
-        boolean logAppend = new Boolean(getValue(map, LOG_APPEND, DEFAULT_LOG_APPEND)).booleanValue();
+        boolean logAppend = Boolean.valueOf(getValue(map, LOG_APPEND, DEFAULT_LOG_APPEND)).booleanValue();
         maxCheckoutSeconds = Integer.parseInt(getValue(map, MAX_CHECKOUT_SECONDS, DEFAULT_MAX_CHECKOUT_SECONDS));
         debugLevel = Integer.parseInt(getValue(map, DEBUG_LEVEL, DEFAULT_DEBUG_LEVEL));
         
@@ -204,7 +205,7 @@ public class PooledConnectionBeanProvider extends ConnectionBeanProvider impleme
                 } catch (SQLException e){
                     sqlEx=e;
                     if(log!=null && debugLevel > 0) {
-                        StringBuffer sb=new StringBuffer();
+                        StringBuilder sb=new StringBuilder();
                         sb.append(new Date()).append(" ->Attempt (").append(i);
                         sb.append(" of ").append(dbLoop).append(") failed to create new connections set at startup:\n");
                         sb.append(e).append("\n");
@@ -400,9 +401,9 @@ public class PooledConnectionBeanProvider extends ConnectionBeanProvider impleme
                             stmt.close();
                         }
                     } catch(SQLException e1){
-                    };
-                }
-                
+                        System.err.println(e1.getMessage());
+                    }
+                }                
             }
             
             try { 
@@ -556,7 +557,7 @@ public class PooledConnectionBeanProvider extends ConnectionBeanProvider impleme
      * @return A String useful only for debug purposes.
      */
     public String freeConnectionBean(ConnectionBean conn) {
-        StringBuffer res=new StringBuffer();
+        StringBuilder res=new StringBuilder();
         
         int thisconn = idOfConnection(conn);
         if(thisconn >= 0) {
@@ -747,33 +748,34 @@ public class PooledConnectionBeanProvider extends ConnectionBeanProvider impleme
     /** Provides information about the current state of this ConnectionBeanProvider.
      * @return Information string, formatted in HTML.
      */
+    @Override
     public String getInfo(){
         int totalUsageCount=globalUsageCount;
-        StringBuffer sb=new StringBuffer();
-        sb.append("<b>PooledConnectionBeanProvider ").append(hashCode()).append("</b><br>\n");
-        sb.append(super.getInfo());
-        sb.append("PID: ").append(pid).append("<br>\n");
-        sb.append("LogFileString: ").append(logFileString).append("<br>\n");
-        sb.append("currConnections: ").append(currConnections).append("<br>\n");
-        sb.append("connLast: ").append(connLast).append("<br>\n");
-        sb.append("minConns: ").append(minConns).append("<br>\n");
-        sb.append("maxConns: ").append(maxConns).append("<br>\n");
-        sb.append("maxConnMSec: ").append(maxConnMSec).append("<br>\n");
-        sb.append("maxCheckoutSeconds: ").append(maxCheckoutSeconds).append("<br>\n");
-        sb.append("debugLevel: ").append(debugLevel).append("<br>\n");        
-        sb.append("CURRENT CONNECTIONS:<br>\n");
-        sb.append("<hr>\n");
+        StringBuilder sb=new StringBuilder();
+        sb.append("<b>PooledConnectionBeanProvider ").append(hashCode()).append("</b><br>\n")
+        .append(super.getInfo())
+        .append("PID: ").append(pid).append("<br>\n")
+        .append("LogFileString: ").append(logFileString).append("<br>\n")
+        .append("currConnections: ").append(currConnections).append("<br>\n")
+        .append("connLast: ").append(connLast).append("<br>\n")
+        .append("minConns: ").append(minConns).append("<br>\n")
+        .append("maxConns: ").append(maxConns).append("<br>\n")
+        .append("maxConnMSec: ").append(maxConnMSec).append("<br>\n")
+        .append("maxCheckoutSeconds: ").append(maxCheckoutSeconds).append("<br>\n")
+        .append("debugLevel: ").append(debugLevel).append("<br>\n")
+        .append("CURRENT CONNECTIONS:<br>\n")
+        .append("<hr>\n");
         for(int i=0; i<maxConns; i++){
             ConnectionBean cb=connPool[i];
             if(cb==null)
                 sb.append("Empty ConnectionBean<br>\n");
             else{
-                sb.append("Id: "+connID[i]+"<br>\n");
-                sb.append("Status: "+connStatus[i]+"<br>\n");
-                sb.append("LockTime: "+connLockTime[i]+"<br>\n");
-                sb.append("CreateDate: "+new Date(connCreateDate[i])+"<br>\n");
-                sb.append("------------\n");
-                sb.append(cb.getInfo());
+                sb.append("Id: ").append(connID[i]).append("<br>\n")
+                .append("Status: ").append(connStatus[i]).append("<br>\n")
+                .append("LockTime: ").append(connLockTime[i]).append("<br>\n")
+                .append("CreateDate: ").append(new Date(connCreateDate[i])).append("<br>\n")
+                .append("------------\n")
+                .append(cb.getInfo());
                 totalUsageCount+=cb.usageCount;
             }
             sb.append("<hr>\n");
