@@ -226,6 +226,7 @@ public class MpegAudioFileReader extends TAudioFileReader
 	/**
 	 * Returns AudioFileFormat from File.
 	 */
+        @Override
 	public AudioFileFormat getAudioFileFormat(File file) throws UnsupportedAudioFileException, IOException
 	{		
 		return super.getAudioFileFormat(file);
@@ -234,6 +235,7 @@ public class MpegAudioFileReader extends TAudioFileReader
 	/**
 	 * Returns AudioFileFormat from URL.
 	 */
+        @Override
 	public AudioFileFormat getAudioFileFormat(URL url) throws UnsupportedAudioFileException, IOException
 	{		
 		if (TDebug.TraceAudioFileReader) {TDebug.out("MpegAudioFileReader.getAudioFileFormat(URL): begin"); }
@@ -316,20 +318,20 @@ public class MpegAudioFileReader extends TAudioFileReader
 			pis.unread(head);
 		}
 		// MPEG header info.
-		int nVersion = AudioSystem.NOT_SPECIFIED;
-		int nLayer = AudioSystem.NOT_SPECIFIED;
-		int nSFIndex = AudioSystem.NOT_SPECIFIED;
-		int nMode = AudioSystem.NOT_SPECIFIED;
-		int FrameSize = AudioSystem.NOT_SPECIFIED;
-		int nFrameSize = AudioSystem.NOT_SPECIFIED;
+		int nVersion; // = AudioSystem.NOT_SPECIFIED;
+		int nLayer; // = AudioSystem.NOT_SPECIFIED;
+		// int nSFIndex = AudioSystem.NOT_SPECIFIED;
+		int nMode;// = AudioSystem.NOT_SPECIFIED;
+		int FrameSize; // = AudioSystem.NOT_SPECIFIED;
+		//int nFrameSize = AudioSystem.NOT_SPECIFIED;
 		int nFrequency = AudioSystem.NOT_SPECIFIED;
 		int nTotalFrames = AudioSystem.NOT_SPECIFIED;
 		float FrameRate = AudioSystem.NOT_SPECIFIED;
-		int BitRate = AudioSystem.NOT_SPECIFIED;
+		int BitRate; // = AudioSystem.NOT_SPECIFIED;
 		int nChannels = AudioSystem.NOT_SPECIFIED;
 		int nHeader = AudioSystem.NOT_SPECIFIED;
-		int nTotalMS = AudioSystem.NOT_SPECIFIED;
-		boolean nVBR = false;
+		int nTotalMS; // = AudioSystem.NOT_SPECIFIED;
+		boolean nVBR; // = false;
 		AudioFormat.Encoding encoding = null;
 		try
 		{
@@ -343,14 +345,15 @@ public class MpegAudioFileReader extends TAudioFileReader
 			// nLayer = 1,2,3
 			nLayer = m_header.layer();
 			aff_properties.put("mp3.version.layer",Integer.toString(nLayer));			
-			nSFIndex = m_header.sample_frequency();
+			// nsFIndex is not used
+                        //nSFIndex = m_header.sample_frequency();
 			nMode = m_header.mode();
 			aff_properties.put("mp3.mode",new Integer(nMode));
 			nChannels = nMode == 3 ? 1 : 2;
 			aff_properties.put("mp3.channels",new Integer(nChannels));
 			nVBR = m_header.vbr();			
-			af_properties.put("vbr",new Boolean(nVBR));
-			aff_properties.put("mp3.vbr",new Boolean(nVBR));
+			af_properties.put("vbr", nVBR);
+			aff_properties.put("mp3.vbr", nVBR);
 			aff_properties.put("mp3.vbr.scale",new Integer(m_header.vbr_scale()));
 			FrameSize = m_header.calculate_framesize();
 			aff_properties.put("mp3.framesize.bytes",new Integer(FrameSize));
@@ -377,10 +380,10 @@ public class MpegAudioFileReader extends TAudioFileReader
 				nTotalMS = Math.round(m_header.total_ms(mLength));
 				aff_properties.put("duration",new Long((long)nTotalMS*1000L));
 			}
-			aff_properties.put("mp3.copyright",new Boolean(m_header.copyright()));
-			aff_properties.put("mp3.original",new Boolean(m_header.original()));
-			aff_properties.put("mp3.crc",new Boolean(m_header.checksums()));
-			aff_properties.put("mp3.padding",new Boolean(m_header.padding()));
+			aff_properties.put("mp3.copyright", m_header.copyright());
+			aff_properties.put("mp3.original", m_header.original());
+			aff_properties.put("mp3.crc", m_header.checksums());
+			aff_properties.put("mp3.padding", m_header.padding());
 			InputStream id3v2 = m_bitstream.getRawID3v2();
 			if (id3v2 != null)
 			{
@@ -435,6 +438,7 @@ public class MpegAudioFileReader extends TAudioFileReader
 	/**
 	 * Returns AudioInputStream from file.
 	 */
+        @Override
 	public AudioInputStream getAudioInputStream(File file) throws UnsupportedAudioFileException, IOException
 	{
 	  if (TDebug.TraceAudioFileReader) TDebug.out("getAudioInputStream(File file)");	  
@@ -523,6 +527,7 @@ public class MpegAudioFileReader extends TAudioFileReader
 	/**
 	 * Return the AudioInputStream from the given InputStream.
 	 */
+        @Override
 	public AudioInputStream getAudioInputStream(InputStream inputStream) throws UnsupportedAudioFileException, IOException
 	{
 	  if (TDebug.TraceAudioFileReader) TDebug.out("MpegAudioFileReader.getAudioInputStream(InputStream inputStream)");
@@ -597,7 +602,7 @@ public class MpegAudioFileReader extends TAudioFileReader
 
 		try
 		{
-			String value = null;
+			String value;
 			for (int i=0;i<bframes.length-4;i++)
 			{
 				String code = new String(bframes,i,4);
@@ -667,7 +672,8 @@ public class MpegAudioFileReader extends TAudioFileReader
 	  MP3Tag[] meta = icy.getTags();
 	  if (meta != null)
 	  {
-		  StringBuffer metaStr = new StringBuffer();
+		  // metaStr is not used
+                  //StringBuilder metaStr = new StringBuilder();
 		  for (int i=0;i<meta.length;i++)
 		  {
 			  String key = meta[i].getName();
