@@ -1,6 +1,6 @@
 /*--
 
- $Id: Element.java,v 1.1.1.1 2005/12/02 14:16:47 fbusquets Exp $
+ $Id: Element.java,v 1.2 2013-09-20 15:11:33 fbusquets Exp $
 
  Copyright (C) 2000-2004 Jason Hunter & Brett McLaughlin.
  All rights reserved.
@@ -66,7 +66,7 @@ import org.jdom.filter.*;
  * elements and content, directly access the element's textual content,
  * manipulate its attributes, and manage namespaces.
  *
- * @version $Revision: 1.1.1.1 $, $Date: 2005/12/02 14:16:47 $
+ * @version $Revision: 1.2 $, $Date: 2013-09-20 15:11:33 $
  * @author  Brett McLaughlin
  * @author  Jason Hunter
  * @author  Lucas Gonze
@@ -81,7 +81,7 @@ import org.jdom.filter.*;
 public class Element extends Content implements Parent {
 
     private static final String CVS_ID =
-    "@(#) $RCSfile: Element.java,v $ $Revision: 1.1.1.1 $ $Date: 2005/12/02 14:16:47 $ $Name:  $";
+    "@(#) $RCSfile: Element.java,v $ $Revision: 1.2 $ $Date: 2013-09-20 15:11:33 $ $Name:  $";
 
     private static final int INITIAL_ARRAY_SIZE = 5;
 
@@ -314,7 +314,7 @@ public class Element extends Content implements Parent {
             return getName();
         }
 
-        return new StringBuffer(namespace.getPrefix())
+        return new StringBuilder(namespace.getPrefix())
             .append(':')
             .append(name)
             // JCLIC modification
@@ -396,7 +396,7 @@ public class Element extends Content implements Parent {
      * @return a concatentation of all text node descendants
      */
     public String getValue() {
-        StringBuffer buffer = new StringBuffer();
+        StringBuilder buffer = new StringBuilder();
 
         Iterator itr = getContent().iterator();
         while (itr.hasNext()) {
@@ -468,7 +468,7 @@ public class Element extends Content implements Parent {
         }
 
         // Else build String up
-        StringBuffer textContent = new StringBuffer();
+        StringBuilder textContent = new StringBuilder();
         boolean hasText = false;
 
         for (int i = 0; i < content.size(); i++) {
@@ -1210,7 +1210,7 @@ public class Element extends Content implements Parent {
      *         <code>Element</code>
      */
     public String toString() {
-        StringBuffer stringForm = new StringBuffer(64)
+        StringBuilder stringForm = new StringBuilder(64)
             .append("[Element: <")
             .append(getQualifiedName());
 
