@@ -1,6 +1,6 @@
 /*--
 
- $Id: SAXHandler.java,v 1.1.1.1 2005/12/02 14:16:50 fbusquets Exp $
+ $Id: SAXHandler.java,v 1.2 2013-09-20 15:11:33 fbusquets Exp $
 
  Copyright (C) 2000-2004 Jason Hunter & Brett McLaughlin.
  All rights reserved.
@@ -66,7 +66,7 @@ import org.xml.sax.helpers.*;
 /**
  * A support class for {@link SAXBuilder}.
  *
- * @version $Revision: 1.1.1.1 $, $Date: 2005/12/02 14:16:50 $
+ * @version $Revision: 1.2 $, $Date: 2013-09-20 15:11:33 $
  * @author  Brett McLaughlin
  * @author  Jason Hunter
  * @author  Philip Nelson
@@ -78,7 +78,7 @@ public class SAXHandler extends DefaultHandler implements LexicalHandler,
                                                           DTDHandler {
 
     private static final String CVS_ID =
-      "@(#) $RCSfile: SAXHandler.java,v $ $Revision: 1.1.1.1 $ $Date: 2005/12/02 14:16:50 $ $Name:  $";
+      "@(#) $RCSfile: SAXHandler.java,v $ $Revision: 1.2 $ $Date: 2013-09-20 15:11:33 $ $Name:  $";
 
     /** Hash table to map SAX attribute type names to JDOM attribute types. */
     private static final Map attrNameToTypeMap = new HashMap(13);
@@ -121,7 +121,7 @@ public class SAXHandler extends DefaultHandler implements LexicalHandler,
     private List declaredNamespaces;
 
     /** Temporary holder for the internal subset */
-    private StringBuffer internalSubset = new StringBuffer();
+    private StringBuilder internalSubset = new StringBuilder();
 
     /** Temporary holder for Text and CDATA */
     private TextBuffer textBuffer = new TextBuffer();
