@@ -1,6 +1,6 @@
 /*--
 
- $Id: XMLOutputter.java,v 1.1.1.1 2005/12/02 14:16:53 fbusquets Exp $
+ $Id: XMLOutputter.java,v 1.2 2013-09-20 15:11:33 fbusquets Exp $
 
  Copyright (C) 2000-2004 Jason Hunter & Brett McLaughlin.
  All rights reserved.
@@ -100,7 +100,7 @@ import org.jdom.*;
  * configured with <code>{@link Format#setExpandEmptyElements}</code> to cause
  * them to be expanded to &lt;empty&gt;&lt;/empty&gt;.
  *
- * @version $Revision: 1.1.1.1 $, $Date: 2005/12/02 14:16:53 $
+ * @version $Revision: 1.2 $, $Date: 2013-09-20 15:11:33 $
  * @author  Brett McLaughlin
  * @author  Jason Hunter
  * @author  Jason Reid
@@ -115,7 +115,7 @@ import org.jdom.*;
 public class XMLOutputter implements Cloneable {
 
     private static final String CVS_ID =
-      "@(#) $RCSfile: XMLOutputter.java,v $ $Revision: 1.1.1.1 $ $Date: 2005/12/02 14:16:53 $ $Name:  $";
+      "@(#) $RCSfile: XMLOutputter.java,v $ $Revision: 1.2 $ $Date: 2013-09-20 15:11:33 $ $Name:  $";
 
     // For normal output
     private Format userFormat = Format.getRawFormat();
@@ -1350,7 +1350,7 @@ public class XMLOutputter implements Cloneable {
      * @return <code>String</code> with escaped content.
      */
     public String escapeAttributeEntities(String str) {
-        StringBuffer buffer;
+        StringBuilder buffer;
         char ch;
         String entity;
         EscapeStrategy strategy = currentFormat.escapeStrategy;
@@ -1398,7 +1398,7 @@ public class XMLOutputter implements Cloneable {
                 if (entity != null) {
                     // An entity occurred, so we'll have to use StringBuffer
                     // (allocate room for it plus a few more entities).
-                    buffer = new StringBuffer(str.length() + 20);
+                    buffer = new StringBuilder(str.length() + 20);
                     // Copy previous skipped characters and fall through
                     // to pickup current character
                     buffer.append(str.substring(0, i));
@@ -1437,7 +1437,7 @@ public class XMLOutputter implements Cloneable {
     public String escapeElementEntities(String str) {
         if (escapeOutput == false) return str;
 
-        StringBuffer buffer;
+        StringBuilder buffer;
         char ch;
         String entity;
         EscapeStrategy strategy = currentFormat.escapeStrategy;
@@ -1474,7 +1474,7 @@ public class XMLOutputter implements Cloneable {
                 if (entity != null) {
                     // An entity occurred, so we'll have to use StringBuffer
                     // (allocate room for it plus a few more entities).
-                    buffer = new StringBuffer(str.length() + 20);
+                    buffer = new StringBuilder(str.length() + 20);
                     // Copy previous skipped characters and fall through
                     // to pickup current character
                     buffer.append(str.substring(0, i));
@@ -1528,7 +1528,7 @@ public class XMLOutputter implements Cloneable {
      * @return a string listing the settings for this XMLOutputter instance
      */
     public String toString() {
-        StringBuffer buffer = new StringBuffer();
+        StringBuilder buffer = new StringBuilder();
         for (int i = 0; i < userFormat.lineSeparator.length(); i++) {
             char ch = userFormat.lineSeparator.charAt(i);
             switch (ch) {
