@@ -25,16 +25,16 @@ import edu.xtec.jclic.*;
 import edu.xtec.jclic.automation.ActiveBagContentKit;
 import edu.xtec.jclic.boxes.*;
 import edu.xtec.jclic.media.EventSounds;
+import edu.xtec.jclic.project.JClicProject;
 import edu.xtec.util.JDomUtility;
 import java.awt.*;
 import java.awt.event.MouseEvent;
-import edu.xtec.jclic.project.JClicProject;
 
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.28
  */
 public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compatible {
     
@@ -46,13 +46,15 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
         dragCells=true;
     }
     
+    @Override
     public void initNew(){
         super.initNew();
         abc[0]=ActiveBagContent.initNew(3, 2, 'A');
     }
     
+    @Override
     public org.jdom.Element getJDomElement(){
-        org.jdom.Element ex=null;
+        org.jdom.Element ex;
         if(abc[0]==null)
             return null;
         
@@ -70,6 +72,7 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
         return e;
     }
     
+    @Override
     public void setProperties(org.jdom.Element e, Object aux) throws Exception{
         org.jdom.Element child;
         super.setProperties(e, aux);
@@ -87,6 +90,7 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
         
     }
     
+    @Override
     public void setProperties(edu.xtec.jclic.clic3.Clic3Activity c3a) throws Exception{
         super.setProperties(c3a);
         abc[0]=c3a.createActiveBagContent(0);
@@ -100,14 +104,17 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
         return abc[0].getNumCells();
     }
     
+    @Override
     public boolean hasRandom(){
         return true;
     }
     
+    @Override
     public boolean shuffleAlways(){
         return true;
     }
     
+    @Override
     public boolean helpSolutionAllowed(){
         return true;
     }
@@ -131,6 +138,7 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
         }
         
         
+        @Override
         public void buildVisualComponents() throws Exception{
             
             if(firstRun) super.buildVisualComponents();
@@ -155,6 +163,7 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
             }
         }
         
+        @Override
         public void initActivity() throws Exception{
             super.initActivity();
             
@@ -191,10 +200,10 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
             return BoxBag.layoutDouble(preferredMaxSize, bgA, bgB, boxGridPos, margin);
         }
         
+        @Override
         public void processMouse(MouseEvent e){
             ActiveBox bx1, bx2;
             Point p=e.getPoint();
-            boolean m=false;
             
             if(playing) switch(e.getID()){
                 case MouseEvent.MOUSE_PRESSED:
@@ -234,8 +243,8 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
                                 bc.begin(p, bx1);
                             else
                                 bc.begin(p);
-                            m=bx1.playMedia(ps);
-                            if(!m) playEvent(EventSounds.CLICK);
+                            if(!bx1.playMedia(ps))
+                                playEvent(EventSounds.CLICK);
                         }
                     }
                     break;
@@ -247,6 +256,7 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
             }
         }
         
+        @Override
         public void showHelp(){
             if(!helpWindowAllowed() || bgA==null) return;
             HelpActivityComponent hac=null;
@@ -256,6 +266,7 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
                     public void render(Graphics2D g2, Rectangle dirtyRegion){
                         if(abb!=null) abb.update(g2, dirtyRegion, this);
                     }
+                    @Override
                     public void init(){
                         abb=ActiveBoxGrid.createEmptyGrid(null, this, DEFAULT_MARGIN, DEFAULT_MARGIN, abc[0]);
                         abb.setContent(abc[0]);
@@ -271,14 +282,14 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
                         if(p!=null)
                             p.translate((int)bgA.x-DEFAULT_MARGIN, (int)bgA.y-DEFAULT_MARGIN);
                     }
+                    @Override
                     public void processMouse(MouseEvent e){
                         ActiveBox bx;
-                        boolean m=false;
                         if(abb!=null) switch(e.getID()){
                             case MouseEvent.MOUSE_PRESSED:
                                 bx=abb.findActiveBox(e.getPoint());
                                 if(bx!=null){
-                                    m=bx.playMedia(ps);
+                                    boolean m=bx.playMedia(ps);
                                     markBox(bgB.getActiveBox(bx.idLoc), false);
                                     if(!m) playEvent(EventSounds.CLICK);
                                 }
@@ -296,22 +307,7 @@ public class DoublePuzzle extends Activity implements ActiveBagContentKit.Compat
             if(hac!=null)
                 hac.end();
         }
-        
-        public Object nextFocusedItem(){
-            // TODO: Check functionality
-            ActiveBox result = null;
-            ActiveBoxBag abb = bc.active ? bgB : bgA;            
-            int currentIndex=abb.boxIndex(focusedItem);
-            
-            setFocusedItem(null);
-            currentIndex=abb.getNextItem(currentIndex);
-            if(currentIndex>=abb.getNumCells())
-                currentIndex=0;
-            setFocusedItem(abb.getActiveBox(currentIndex));
-            return focusedItem;
-        }
-        
-        
+                
     }
     
 }
\ No newline at end of file
