@@ -23,18 +23,17 @@ package edu.xtec.jclic.activities.text;
 
 import edu.xtec.jclic.*;
 import edu.xtec.jclic.media.EventSounds;
-import edu.xtec.util.JDomUtility;
+import edu.xtec.jclic.project.JClicProject;
 import edu.xtec.util.Actions;
+import edu.xtec.util.JDomUtility;
+import java.awt.event.*;
 import javax.swing.*;
 import javax.swing.text.*;
-import javax.swing.event.*;
-import java.awt.event.*;
-import edu.xtec.jclic.project.JClicProject;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.16
  */
 public class FillInBlanks extends TextActivityBase {
     
@@ -54,6 +53,7 @@ public class FillInBlanks extends TextActivityBase {
     
     public static final String AUTO_JUMP="autoJump", FORCE_OK_TO_ADVANCE="forceOkToAdvance";
     
+    @Override
     public org.jdom.Element getJDomElement(){
         org.jdom.Element e=super.getJDomElement();
         if(autoJump)
@@ -64,6 +64,7 @@ public class FillInBlanks extends TextActivityBase {
         return e;
     }
     
+    @Override
     public void setProperties(org.jdom.Element e, Object aux) throws Exception{
         super.setProperties(e, aux);
         ev=Evaluator.getEvaluator(e.getChild(Evaluator.ELEMENT_NAME), project);
@@ -72,6 +73,7 @@ public class FillInBlanks extends TextActivityBase {
         forceOkToAdvance=JDomUtility.getBoolAttr(e, FORCE_OK_TO_ADVANCE, forceOkToAdvance);
     }
     
+    @Override
     public void setProperties(edu.xtec.jclic.clic3.Clic3Activity c3a) throws Exception{
         super.setProperties(c3a);
         ((ComplexEvaluator)ev).setProperties(c3a);
@@ -82,7 +84,13 @@ public class FillInBlanks extends TextActivityBase {
         //if(evalOnTheFly)
         //    hasCheckButton=false;
     }
-    
+
+    @Override
+    public boolean needsKeyboard(){
+        return true;
+    }
+
+    @Override
     public Activity.Panel getActivityPanel(PlayStation ps) {
         return new Panel(ps);
     }
@@ -97,6 +105,7 @@ public class FillInBlanks extends TextActivityBase {
             locked=true;
         }
         
+        @Override
         protected void initDocument() throws Exception{
             if(tad!=null){
                 playing=false;
@@ -123,6 +132,7 @@ public class FillInBlanks extends TextActivityBase {
             }
         }
         
+        @Override
         protected TextActivityPane buildPane(){
             //FillInBlanksPane fp=new FillInBlanksPane(this);
             FillInBlanksPane fp=new FillInBlanksPane();
@@ -140,6 +150,7 @@ public class FillInBlanks extends TextActivityBase {
                 super(FillInBlanks.Panel.this);
             }
             
+            @Override
             public boolean processMouse(MouseEvent e){
                 if(super.processMouse(e) && e.getID()==MouseEvent.MOUSE_PRESSED && playing && !locked){
                     int p=this.viewToModel(e.getPoint());
@@ -220,7 +231,7 @@ public class FillInBlanks extends TextActivityBase {
             
             protected int getFirstFillChar(TargetMarker tm){
                 for(int i=tm.begOffset; i<tm.endOffset; i++)
-                    if(playDoc.checkBooleanAttribute(i, playDoc.FILL))
+                    if(playDoc.checkBooleanAttribute(i, TextActivityDocument.FILL))
                         return i;
                 return -1;
             }
@@ -396,7 +407,7 @@ public class FillInBlanks extends TextActivityBase {
                 kitUpAction=getActionMap().get(DefaultEditorKit.upAction);
                 kitDownAction=getActionMap().get(DefaultEditorKit.downAction);
                 
-                java.util.HashMap actionKeys=Actions.getActionKeys(this);
+                java.util.Map<String, Object[]> actionKeys=Actions.getActionKeys(this);
                 //Actions.dumpActionKeys(actionKeys, getActionMap());
                 ActionMap am=new ActionMap();
                 am.setParent(getActionMap());
@@ -445,6 +456,7 @@ public class FillInBlanks extends TextActivityBase {
                 getInputMap().put(KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_F1, 0), showHelpAction.getValue(Action.NAME));
             }
             
+            @Override
             protected void targetChanged(TextTarget tt){
                 if(readyForActions()){
                     TargetMarker tm=playDoc.tmb.getElement(tt);
@@ -567,6 +579,7 @@ public class FillInBlanks extends TextActivityBase {
             return p;
         }
         
+        @Override
         protected void doCheck(boolean fromButton){
             if(playDoc==null || locked)
                 return;
@@ -598,6 +611,7 @@ public class FillInBlanks extends TextActivityBase {
                 finishActivity(true);
         }
         
+        @Override
         public void finishActivity(boolean result){
             pane.setEditable(false);
             pane.setEnabled(false);
@@ -605,7 +619,5 @@ public class FillInBlanks extends TextActivityBase {
             playDoc.tmb.getCurrentTarget().lostFocus(this);
             super.finishActivity(result);
         }
-        
     }
-    
 }
