@@ -21,21 +21,22 @@
 
 package edu.xtec.jclic.activities.text;
 
+import edu.xtec.jclic.Activity;
 import edu.xtec.jclic.boxes.*;
 import edu.xtec.jclic.clic3.*;
 import edu.xtec.util.JDomUtility;
-import javax.swing.text.*;
-import java.util.StringTokenizer;
-import java.awt.*;
-import edu.xtec.jclic.Activity;
 import edu.xtec.util.StreamIO;
+import java.awt.*;
+import java.util.ArrayList;
 import java.util.Iterator;
+import java.util.StringTokenizer;
+import javax.swing.text.*;
 
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.10
  */
 public class TextActivityDocument extends DefaultStyledDocument {
     
@@ -99,7 +100,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
         StyleConstants.setForeground(targetError, c3a.colorError[0]);
         
         boolean multiTarget=(c3a.puzMode==Clic3.FORATS);
-        StringBuffer sb=new StringBuffer();
+        StringBuilder sb=new StringBuilder();
         sb.append(Clic3.CHBLOCK).append(Clic3.CHINC);
         StringTokenizer st=new StringTokenizer(c3a.txBase, sb.substring(0), true);
         boolean intoBlock=false;
@@ -133,8 +134,10 @@ public class TextActivityDocument extends DefaultStyledDocument {
                     if(targetElementCount>6){
                         targetElementCount=0;
                         intoTarget=false;
-                        tm.endOffset=getLength();
-                        tmb.add(tm);
+                        if(tm!=null){
+                          tm.endOffset=getLength();
+                          tmb.add(tm);
+                        }
                     } else{
                         intoTarget=true;
                     }
@@ -145,7 +148,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
                         tm=new TargetMarker(this);
                         tm.begOffset=getLength();
                     }
-                    else{
+                    else if(tm!=null){
                         tm.endOffset=getLength();
                         tmb.add(tm);
                     }
@@ -183,14 +186,16 @@ public class TextActivityDocument extends DefaultStyledDocument {
                 else switch(targetElementCount){
                     case 1:
                         StringTokenizer stx=new StringTokenizer(t, ",");
-                        tm.target.iniChar=stx.nextToken().charAt(0);
-                        tm.target.isList=(stx.nextToken().compareTo("1")==0);
-                        tm.target.numIniChars=Integer.parseInt(stx.nextToken());
-                        tm.target.maxLenResp=Integer.parseInt(stx.nextToken());
-                        tm.target.infoMode=Integer.parseInt(stx.nextToken());
-                        int v=Integer.parseInt(stx.nextToken());
-                        tm.target.popupDelay=v&0xFF;
-                        tm.target.popupMaxTime=(v&0xFF00)>>8;
+                        if (tm != null) {
+                            tm.target.iniChar = stx.nextToken().charAt(0);
+                            tm.target.isList = (stx.nextToken().compareTo("1") == 0);
+                            tm.target.numIniChars = Integer.parseInt(stx.nextToken());
+                            tm.target.maxLenResp = Integer.parseInt(stx.nextToken());
+                            tm.target.infoMode = Integer.parseInt(stx.nextToken());
+                            int v = Integer.parseInt(stx.nextToken());
+                            tm.target.popupDelay = v & 0xFF;
+                            tm.target.popupMaxTime = (v & 0xFF00) >> 8;
+                        }
                         w=Integer.parseInt(stx.nextToken());
                         h=Integer.parseInt(stx.nextToken());
                         int flags=Integer.parseInt(stx.nextToken());
@@ -198,16 +203,18 @@ public class TextActivityDocument extends DefaultStyledDocument {
                         onlyPlay=((flags&2)==2);
                         break;
                     case 2:
-                        if(t.length()>0) tm.target.setAnswer(t);
+                        if(tm!=null && t.length()>0)
+                            tm.target.setAnswer(t);
                         break;
                     case 3:
                         StringTokenizer sty=new StringTokenizer(t, "\n\r");
-                        java.util.ArrayList al=new java.util.ArrayList();
+                        ArrayList<String> al=new ArrayList<String>();
                         while(sty.hasMoreTokens()){
                             String s=sty.nextToken();
-                            if(s.length()>0) al.add(s);
+                            if(s.length()>0)
+                                al.add(s);
                         }
-                        if(al.size()>0){
+                        if(tm!=null && al.size()>0){
                             tm.target.options=new String[al.size()];
                             for(int i=0; i<al.size(); i++){
                                 tm.target.options[i]=(String)(al.get(i));
@@ -215,10 +222,11 @@ public class TextActivityDocument extends DefaultStyledDocument {
                         }
                         break;
                     case 4:
-                        if(t.length()>0) tm.target.iniText=t;
+                        if(tm!=null && t.length()>0)
+                            tm.target.iniText=t;
                         break;
                     case 5:
-                        if(t.length()>0){
+                        if(tm!=null && t.length()>0){
                             tm.target.popupContent=new ActiveBoxContent();
                             tm.target.popupContent.setDimension(new Dimension(w, h));
                             c3a.setActiveBoxTextContent(tm.target.popupContent, t);
@@ -323,7 +331,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
                 StyleConstants.setForeground(a, JDomUtility.stringToColor(atr.getValue()));
             // other attributes:
             else if(atrName.equals(TARGET))
-                a.addAttribute(atrName, new Boolean(atr.getBooleanValue()));
+                a.addAttribute(atrName, atr.getBooleanValue());
             // Paragraph attributes:
             else if(atrName.equals(StyleConstants.BidiLevel.toString()))
                 StyleConstants.setBidiLevel(a, atr.getIntValue());
@@ -379,7 +387,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
     boolean style, boolean colour, boolean targetColour, boolean errorColour){
         
         boolean result=false;
-        StyleContext clon=null;
+        StyleContext clon;
         try{
             clon=(StyleContext)StreamIO.cloneObject(dest);
         } catch(Exception ex){
@@ -492,11 +500,11 @@ public class TextActivityDocument extends DefaultStyledDocument {
     }
     
     public static void addStylesToElement(org.jdom.Element e, StyleContext sc, int tabSpc) throws Exception{
-        java.util.Enumeration styleNamesEnum=sc.getStyleNames();
+        java.util.Enumeration<?> styleNamesEnum=sc.getStyleNames();
         // use Stack for reverse order
-        java.util.Stack styleNames=new java.util.Stack();
+        java.util.Stack<String> styleNames=new java.util.Stack<String>();
         while(styleNamesEnum.hasMoreElements())
-            styleNames.push(styleNamesEnum.nextElement());
+            styleNames.push((String)styleNamesEnum.nextElement());
         
         while(!styleNames.empty()){
             org.jdom.Element s=new org.jdom.Element(STYLE);
@@ -514,7 +522,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
     }
     
     public org.jdom.Element getJDomElement(Element element) throws Exception{
-        org.jdom.Element e=null;
+        org.jdom.Element e;
         String elementName=element.getName();
         AttributeSet atr=element.getAttributes();
         String style=(String)(atr.getAttribute(AttributeSet.NameAttribute));
@@ -710,7 +718,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
             while(i<l){
                 for(j=i+1; j<l; j++){
                     s2=getCharacterElement(j).getAttributes();
-                    if(!s.isEqual(s2)) break;
+                    if(s!=null && !s.isEqual(s2)) break;
                 }
                 attr=null;
                 si=null;
@@ -751,7 +759,7 @@ public class TextActivityDocument extends DefaultStyledDocument {
                     d.insertString(d.getLength(), si, attr!=null ? attr : s);
                 }
                 
-                if(tm!=null){
+                if(tmx!=null && tm!=null){
                     tmx.endOffset=d.getLength();
                     d.tmb.add(tmx);
                 }
@@ -779,22 +787,19 @@ public class TextActivityDocument extends DefaultStyledDocument {
     
     
     public JPanelActiveBox[] getPanelBoxes(){
-        java.util.Vector v=new java.util.Vector();
+        ArrayList<JPanelActiveBox> v=new ArrayList<JPanelActiveBox>();
         for(int i=0; i<getLength(); i++){
             Component c=StyleConstants.getComponent(getCharacterElement(i).getAttributes());
             if(c!=null && c instanceof JPanelActiveBox)
-                v.addElement(c);
-        }
-        JPanelActiveBox[] result=new JPanelActiveBox[v.size()];
-        v.copyInto(result);
-        return result;
+                v.add((JPanelActiveBox)c);
+        }        
+        return v.toArray(new JPanelActiveBox[v.size()]);        
     }
     
     public void attachTo(JTextComponent tc, Activity.Panel parent){
-        JPanelActiveBox[] boxes=getPanelBoxes();
-        for(int i=0; i<boxes.length; i++){
-            boxes[i].notifyMouseEventsTo(tc);
-            boxes[i].setPanelParent(parent);
+        for(JPanelActiveBox jpab : getPanelBoxes()){
+            jpab.notifyMouseEventsTo(tc);
+            jpab.setPanelParent(parent);
         }
     }
     
@@ -851,16 +856,15 @@ public class TextActivityDocument extends DefaultStyledDocument {
     protected void clearElementStyles(org.jdom.Element e) {
         String s=e.getName();
         if(P.equals(s) || TEXT.equals(s)){
+            java.util.HashSet<org.jdom.Attribute> set=new java.util.HashSet<org.jdom.Attribute>();
             Iterator it=e.getAttributes().iterator();
-            java.util.HashSet set=new java.util.HashSet();
             while(it.hasNext()){
                 org.jdom.Attribute at=(org.jdom.Attribute)it.next();
                 if(!TEXT.equals(at.getName()))
                     set.add(at);
             }
-            it=set.iterator();
-            while(it.hasNext())
-                e.removeAttribute((org.jdom.Attribute)it.next());
+            for(org.jdom.Attribute atr : set)
+                e.removeAttribute(atr);
         }
         Iterator it=e.getChildren().iterator();
         while(it.hasNext())
