@@ -21,21 +21,19 @@
 
 package edu.xtec.jclic.activities.text;
 
-import edu.xtec.jclic.*;
+import edu.xtec.jclic.bags.MediaBag;
 import edu.xtec.jclic.boxes.*;
 import edu.xtec.jclic.media.MediaContent;
 import edu.xtec.util.JDomUtility;
-import edu.xtec.util.Actions;
 import java.awt.*;
+import java.awt.event.*;
 import javax.swing.*;
 import javax.swing.text.*;
-import java.awt.event.*;
-import edu.xtec.jclic.bags.MediaBag;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.10
  */
 public class TextTarget extends java.lang.Object{
     
@@ -90,7 +88,7 @@ public class TextTarget extends java.lang.Object{
             x0=x1;
             x1=v;
         }
-        String s=null;
+        String s;
         try{
             s=doc.getText(x0, x1-x0);
         } catch(BadLocationException ex){
@@ -120,14 +118,14 @@ public class TextTarget extends java.lang.Object{
         org.jdom.Element e=new org.jdom.Element(ELEMENT_NAME);
         org.jdom.Element child;
         if(answer!=null){
-            for(int i=0; i<answer.length; i++)
-                e.addContent((new org.jdom.Element(ANSWER)).addContent(answer[i]));
+            for(String ans : answer)
+                e.addContent((new org.jdom.Element(ANSWER)).addContent(ans));
         }
         if(isList){
             child=new org.jdom.Element(OPTION_LIST);
             if(options!=null){
-                for(int i=0; i<options.length; i++)
-                    child.addContent((new org.jdom.Element(OPTION)).addContent(options[i]));
+                for(String opt : options)
+                    child.addContent((new org.jdom.Element(OPTION)).addContent(opt));
             }
             e.addContent(child);
         } else{
@@ -221,7 +219,7 @@ public class TextTarget extends java.lang.Object{
     }
     
     public String getAnswers(){
-        StringBuffer sb=new StringBuffer();
+        StringBuilder sb=new StringBuilder();
         if(answer!=null)
             for(int i=0; i<answer.length; i++){
                 if(i>0)
@@ -252,7 +250,7 @@ public class TextTarget extends java.lang.Object{
     }
     
     public String getFillString(int length){
-        StringBuffer s=new StringBuffer();
+        StringBuilder s=new StringBuilder();
         for(int i=0; i<length; i++){
             s.append(iniChar);
         }
@@ -328,16 +326,16 @@ public class TextTarget extends java.lang.Object{
             tabp.popupTimer.stopPopup();
     }
 
-    class TargetCombo extends JComboBox{
+    public class TargetCombo extends JComboBox{
         
         Color bgColor, foreColor;
         Color errBgColor, errForeColor;
         Font rFont;
         TargetComboCellRenderer cellRenderer;
-        JTextField editor;
+        JTextField txEditor;
         AbstractAction showListAction, fwdAction, bkAction;
         
-        public TargetCombo(Object[] items, AttributeSet targetAttr, AttributeSet errorAttr){
+        public TargetCombo(String[] items, AttributeSet targetAttr, AttributeSet errorAttr){
             super(items);
             setSelectedIndex(-1);
             showListAction=new AbstractAction("showList"){
@@ -381,10 +379,10 @@ public class TextTarget extends java.lang.Object{
             setEditable(true);
             Component c=getEditor().getEditorComponent();
             if(c instanceof JTextField)
-                editor=(JTextField)c;
+                txEditor=(JTextField)c;
             else
-                editor=new JTextField();
-            editor.setEnabled(false);
+                txEditor=new JTextField();
+            txEditor.setEnabled(false);
             checkColors();
             setAlignmentY(0.8f); 
             setKActions();            
@@ -393,8 +391,8 @@ public class TextTarget extends java.lang.Object{
         protected void setKActions(){
             registerKeyboardAction(showListAction, KeyStroke.getKeyStroke(KeyEvent.VK_DOWN, 0), JComponent.WHEN_FOCUSED);
             registerKeyboardAction(showListAction, KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0), JComponent.WHEN_FOCUSED);
-            editor.registerKeyboardAction(showListAction, KeyStroke.getKeyStroke(KeyEvent.VK_DOWN, 0), JComponent.WHEN_FOCUSED);
-            editor.registerKeyboardAction(showListAction, KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0), JComponent.WHEN_FOCUSED);
+            txEditor.registerKeyboardAction(showListAction, KeyStroke.getKeyStroke(KeyEvent.VK_DOWN, 0), JComponent.WHEN_FOCUSED);
+            txEditor.registerKeyboardAction(showListAction, KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0), JComponent.WHEN_FOCUSED);
             
             registerKeyboardAction(fwdAction, KeyStroke.getKeyStroke(KeyEvent.VK_RIGHT, 0), JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
             registerKeyboardAction(fwdAction, KeyStroke.getKeyStroke(KeyEvent.VK_TAB, 0), JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT);
@@ -406,14 +404,14 @@ public class TextTarget extends java.lang.Object{
         
         public void checkColors(){
             if(targetStatus==WITH_ERROR){
-                editor.setBackground(errBgColor);
-                editor.setForeground(errForeColor);
-                editor.setDisabledTextColor(errForeColor);
+                txEditor.setBackground(errBgColor);
+                txEditor.setForeground(errForeColor);
+                txEditor.setDisabledTextColor(errForeColor);
             }
             else{
-                editor.setBackground(bgColor);
-                editor.setForeground(foreColor);
-                editor.setDisabledTextColor(foreColor);
+                txEditor.setBackground(bgColor);
+                txEditor.setForeground(foreColor);
+                txEditor.setDisabledTextColor(foreColor);
             }
         }
         
@@ -427,11 +425,12 @@ public class TextTarget extends java.lang.Object{
             public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus){
                 setBackground(isSelected ? foreColor : bgColor);
                 setForeground(isSelected ? bgColor : foreColor);
-                setText(value.toString());
+                setText(value==null ? "" : value.toString());
                 return this;
             }            
         }
         
+        @Override
         public void setSelectedItem(Object o){
             super.setSelectedItem(o);
             if(o!=null && parentPane!=null){
@@ -520,6 +519,7 @@ public class TextTarget extends java.lang.Object{
             }
         }
         
+        @Override
         protected void fireActionPerformed(java.awt.event.ActionEvent e){
             if(action==true)
                 startPopup();
