@@ -25,16 +25,16 @@ import edu.xtec.jclic.*;
 import edu.xtec.jclic.automation.ActiveBagContentKit;
 import edu.xtec.jclic.boxes.*;
 import edu.xtec.jclic.media.EventSounds;
+import edu.xtec.jclic.project.JClicProject;
 import edu.xtec.util.JDomUtility;
-import javax.swing.JTextField;
 import java.awt.*;
 import java.awt.event.MouseEvent;
-import edu.xtec.jclic.project.JClicProject;
+import javax.swing.JTextField;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.28
  */
 public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compatible {
     
@@ -55,6 +55,7 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
         useIdAss=true;
     }
     
+    @Override
     public void initNew(){
         super.initNew();
         abc[0]=ActiveBagContent.initNew(3, 2, 'A');
@@ -63,8 +64,9 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
     
     protected static final String ANSWERS="answers", INVERSE="inverse";
     
+    @Override
     public org.jdom.Element getJDomElement(){
-        org.jdom.Element ex=null;
+        org.jdom.Element ex;
         
         if(abc[0]==null || abc[1]==null) return null;
         
@@ -91,10 +93,11 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
         return e;
     }
     
+    @Override
     public void setProperties(org.jdom.Element e, Object aux) throws Exception{
         org.jdom.Element child;
         super.setProperties(e, aux);
-        ActiveBagContent bag=null;
+        ActiveBagContent bag;
         abc[2]=null;
         java.util.Iterator itr = e.getChildren(ActiveBagContent.ELEMENT_NAME).iterator();
         while (itr.hasNext()){
@@ -125,6 +128,7 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
         
     }
     
+    @Override
     public void setProperties(edu.xtec.jclic.clic3.Clic3Activity c3a) throws Exception{
         super.setProperties(c3a);
         // Clic3 problem
@@ -150,13 +154,21 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
             return abc[0].getNumCells()-nonAssignedCells;
     }
     
+    @Override
     public boolean helpSolutionAllowed(){
         return true;
     }
     
+    @Override
     public boolean hasRandom(){
         return true;
     }
+
+    @Override
+    public boolean needsKeyboard(){
+        return true;
+    }
+
     
     public Activity.Panel getActivityPanel(PlayStation ps) {
         return new Panel(ps);
@@ -189,6 +201,7 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
             textField=null;
         }
         
+        @Override
         public void buildVisualComponents() throws Exception{
             
             if(firstRun)
@@ -244,6 +257,7 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
             }
         }
         
+        @Override
         public void initActivity() throws Exception{
             super.initActivity();
             
@@ -281,13 +295,12 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
         }
         
         private boolean checkInvAss(){
-            int i;
             if(invAss==false || invAssCheck==null)
                 return false;
-            for(i=0; i<invAssCheck.length; i++)
-                if(!invAssCheck[i])
-                    break;
-            return i==invAssCheck.length;
+            for(boolean b : invAssCheck)
+                if(!b)
+                    return false;
+            return true;
         }
         
         private void setCurrentCell(int i){
@@ -352,7 +365,7 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
                     bx=bg[0].getActiveBoxWithIdLoc(j);
                     if(bx.idAss!=-1) break;
                 }
-                if(bx.idAss==-1){
+                if(bx!=null && bx.idAss==-1){
                     // error ?
                     finishActivity(false);
                     textField.setEnabled(false);
@@ -362,15 +375,18 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
             
             // 29 - mai -2007
             // Draw border only if it has more than one cell
-            if(bg[0].getNumCells()>1)
+            if(bg[0].getNumCells()>1 && bx!=null)
                 bx.setMarked(true);
-            currentCell=bx.idLoc;
+            if(bx!=null)
+                currentCell=bx.idLoc;
             textField.setText("");
             textField.requestFocus();
             
-            bx.playMedia(ps);
+            if(bx!=null)
+                bx.playMedia(ps);
         }
         
+        @Override
         public void requestFocus(){
             if(playing && textField!=null)
                 textField.requestFocus();
@@ -381,6 +397,7 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
                 setCurrentCell(currentCell);
         }
         
+        @Override
         public void processMouse(MouseEvent e){
             ActiveBox bx;
             boolean m=false;
@@ -397,6 +414,7 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
             }
         }
         
+        @Override
         public void showHelp(){
             if(!helpWindowAllowed() || bg[0]==null) return;
             
@@ -409,6 +427,7 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
                     public void render(Graphics2D g2, Rectangle dirtyRegion){
                         if(abb!=null) abb.update(g2, dirtyRegion, this);
                     }
+                    @Override
                     public void init(){
                         currentResponse=textField.getText();
                         abb=(ActiveBoxBag)bg[0].clone();
@@ -424,23 +443,25 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
                         if(p!=null)
                             p.translate((int)bg[0].x-DEFAULT_MARGIN, (int)bg[0].y-DEFAULT_MARGIN);
                     }
+                    @Override
                     public void end(){
                         super.end();
                         textField.setText(currentResponse);
                     }
+                    @Override
                     public void processMouse(MouseEvent e){
                         ActiveBox bx;
-                        boolean m=false;
                         if(abb!=null) switch(e.getID()){
                             case MouseEvent.MOUSE_PRESSED:
                                 bx=abb.findActiveBox(e.getPoint());
                                 if(bx!=null){
-                                    m=bx.playMedia(ps);
+                                    boolean m=bx.playMedia(ps);
                                     String s=abc[1].getActiveBoxContent(bx.idOrder).text;
                                     if(s!=null)
                                         textField.setText(s.replace('|', ' '));
                                     ps.reportNewAction(getActivity(), ACTION_HELP, bx.getDescription(), null, false, cellsPlaced);
-                                    if(!m) playEvent(EventSounds.CLICK);
+                                    if(!m)
+                                        playEvent(EventSounds.CLICK);
                                 }
                                 break;
                             case MouseEvent.MOUSE_RELEASED:
@@ -457,8 +478,6 @@ public class WrittenAnswer extends Activity implements ActiveBagContentKit.Compa
                 
             if(hac!=null)
                 hac.end();
-        }
-        
+        }        
     }
-    
 }
