@@ -21,29 +21,29 @@
 
 package edu.xtec.jclic;
 
+import edu.xtec.jclic.activities.text.TextActivityEditorTextPanel;
 import edu.xtec.jclic.bags.MediaBagEditor;
+import edu.xtec.jclic.boxes.ActiveBagContentEditor;
 import edu.xtec.jclic.edit.*;
 import edu.xtec.jclic.misc.Utils;
 import edu.xtec.util.Options;
-import java.awt.Container;
-import java.util.Vector;
-import java.util.Iterator;
 import java.awt.Component;
+import java.util.ArrayList;
 import java.util.HashMap;
-import edu.xtec.jclic.boxes.ActiveBagContentEditor;
-import edu.xtec.jclic.activities.text.TextActivityEditorTextPanel;
-import edu.xtec.jclic.bags.ActivityBagElementEditor;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.16
  */
 public class ActivityEditorPanel extends EditorPanel {
     
-    Vector internalPanels;
+    List<ActivityEditorInternalPanel> internalPanels;
     String currentActivityClass;
-    HashMap panelStore;
+    Map<String, ActivityEditorInternalPanel> panelStore;
     public static final String 
     SINGLE="SINGLE", // puzzles and info
     SINGLE_ALT="SINGLE_ALT", // memory
@@ -59,8 +59,8 @@ public class ActivityEditorPanel extends EditorPanel {
     /** Creates new form MenuEditorPanel */
     public ActivityEditorPanel(Options options) {
         super(options);
-        internalPanels=new Vector(4);
-        panelStore=new HashMap();
+        internalPanels=new ArrayList<ActivityEditorInternalPanel>(4);
+        panelStore=new HashMap<String,ActivityEditorInternalPanel>();
         //ActivityBagElementEditor.createActions(options);
         initComponents();
         //addInternalPanel(new ActivityEditorDescPanel(options, this));
@@ -68,11 +68,12 @@ public class ActivityEditorPanel extends EditorPanel {
         setEnabled(false);
     }
     
+    @Override
     public void setEnabled(boolean enabled){
         super.setEnabled(enabled);
-        Iterator it=internalPanels.iterator();
+        Iterator<ActivityEditorInternalPanel> it=internalPanels.iterator();
         while(it.hasNext()){
-            ((ActivityEditorInternalPanel)it.next()).setEnabled(enabled);
+            it.next().setEnabled(enabled);
         }
     }
     
@@ -134,6 +135,7 @@ public class ActivityEditorPanel extends EditorPanel {
 
     }//GEN-END:initComponents
 
+    @Override
     protected synchronized void setEditor(Editor e){
         //System.out.println("SET EDITOR");
         if(e instanceof ActivityEditor){
@@ -196,31 +198,34 @@ public class ActivityEditorPanel extends EditorPanel {
     public void fillData() {
         Activity act=getActivity();
         if(act!=null){
-            Iterator it=internalPanels.iterator();
+            Iterator<ActivityEditorInternalPanel> it=internalPanels.iterator();
             while(it.hasNext())
-                ((ActivityEditorInternalPanel)it.next()).fillData();            
+                it.next().fillData();            
         }
     }
     
     public void saveData(){
         Activity act=getActivity();
         if(act!=null){
-            Iterator it=internalPanels.iterator();
+            Iterator<ActivityEditorInternalPanel> it=internalPanels.iterator();
             while(it.hasNext())
-                ((ActivityEditorInternalPanel)it.next()).saveData();
+                it.next().saveData();
             getActivityEditor().saveData();
         }
     }
     
+    @Override
     protected javax.swing.Icon getIcon(){
         return ActivityEditor.getIcon();
     }
     
+    @Override
     protected String getTitle(){
         return "activity";
         //return options.getMsg("menu_dlg_title");
     }
     
+    @Override
     public void focusLost(java.awt.event.FocusEvent focusEvent) {
         if(editor!=null)
             editor.collectData();
