@@ -21,41 +21,37 @@
 
 package edu.xtec.jclic;
 
-import edu.xtec.util.*;
-import edu.xtec.jclic.edit.*;
-import edu.xtec.jclic.media.*;
-import edu.xtec.jclic.fileSystem.*;
-import edu.xtec.jclic.project.*;
-import edu.xtec.jclic.boxes.*;
 import edu.xtec.jclic.bags.*;
-import edu.xtec.jclic.misc.Utils;
+import edu.xtec.jclic.boxes.*;
 import edu.xtec.jclic.clic3.Clic3;
+import edu.xtec.jclic.edit.*;
+import edu.xtec.jclic.fileSystem.*;
+import edu.xtec.jclic.media.*;
+import edu.xtec.jclic.misc.Utils;
+import edu.xtec.jclic.project.*;
 import edu.xtec.jclic.skins.AboutWindow;
-
-import javax.swing.*;
+import edu.xtec.util.*;
+import java.awt.BorderLayout;
 import java.awt.Cursor;
 import java.awt.Dimension;
-import java.util.Vector;
-import javax.swing.KeyStroke;
-import java.awt.event.KeyEvent;
+import java.awt.Frame;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import javax.swing.tree.DefaultTreeModel;
-import java.io.FileOutputStream;
-import edu.xtec.util.ProgressDialog;
-import java.awt.BorderLayout;
-import java.awt.Component;
-import java.awt.Frame;
-import java.awt.event.FocusListener;
+import java.awt.event.KeyEvent;
 import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
 import java.io.File;
-import javax.swing.JDialog;
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import javax.swing.*;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.17
  */
 public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPlayerContainer, RunnableComponent, Constants, ActionListener {
     
@@ -93,7 +89,7 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
         init();
     }
     
-    protected void init(){
+    protected final void init(){
         //setDragMode(JDesktopPane.OUTLINE_DRAG_MODE);
         settings=AuthorSettings.loadAuthorSettings(this);
         options.setLookAndFeel();
@@ -188,6 +184,7 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
             String activityName=null;
             boolean imported=false;
             
+            @Override
             public Object construct(){
                 
                 setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
@@ -198,9 +195,9 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                     activityName=sActivity;
                     boolean prompted=false;
                     
-                    boolean exit=false;
-                    
-                    while(!exit && !isCancelled()){
+                    //boolean exit=false;                    
+                    //while(!exit && !isCancelled()){
+                    while(!isCancelled()){
                         String dn=fullPath != null ? fullPath : sequence!=null ? sequence : activityName;
                         progressDialog.setText(messages.get("msg_loading")+" "+dn);
                         
@@ -212,11 +209,16 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                                 fullPath=fileSystem.getUrl(fullPath);
                                 if(fullPath.startsWith("file://"))
                                     fullPath=fullPath.substring(7);
+                                // Added 03-Feb-2011
+                                // Remove trailing parameters of URLs
+                                else if(fullPath.indexOf('?')>0)
+                                    fullPath=fullPath.substring(0, fullPath.indexOf('?'));
+                                // ----------
                             }
                             if(sequence==null)
                                 sequence="0";
                             
-                            String projectName=null;
+                            String projectName;
                             if(fullPath.endsWith(".jclic.zip")){
                                 fileSystem=FileSystem.createFileSystem(fullPath, thisAuthor);
                                 String[] projects=((ZipFileSystem)fileSystem).getEntries(".jclic");
@@ -308,7 +310,7 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                             project.activitySequence.checkAllElements();
                         
                         if(project!=null){
-                            java.util.HashMap hm=new java.util.HashMap();
+                            Map<String, String> hm=new HashMap<String, String>();
                             //project.activitySequence.listReferences(null, hm);
                             project.activityBag.listReferences(SEQUENCE_OBJECT, hm);
                             project.activityBag.listReferences(ACTIVITY_OBJECT, hm);
@@ -330,14 +332,14 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                         }
                         
                         if(fullPath==null && sequence==null && activityName==null){
-                            exit=true;
+                            //exit=true;
                             break;
                         }
                         else{
                             if(!prompted){
                                 prompted=(messages.showQuestionDlg(progressDialog, "msg_prompt_loadReferences", null, "yn")==Messages.YES);
                                 if(!prompted){
-                                    exit=true;
+                                    //exit=true;
                                     break;
                                 }
                             }
@@ -361,6 +363,7 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                 return abe;
             }
             
+            @Override
             public void finished(){
                 
                 progressDialog.setVisible(false);
@@ -368,24 +371,24 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                 setCursor(null);
                 
                 if(/*abe==null || */ worker==null || exception!=null){
-                    String sType=null;
-                    Vector v=new Vector();
+                    //String sType=null;
+                    List<Object> v=new ArrayList<Object>();
                     if(fullPath!=null){
                         v.add(fullPath);
-                        sType="msg_error_loading_project";
+                        //sType="msg_error_loading_project";
                     }
                     if(sequence!=null){
                         v.add(sequence);
-                        if(sType==null)
-                            sType="msg_error_loading_sequence";
+                        //if(sType==null)
+                        //    sType="msg_error_loading_sequence";
                     }
                     if(activityName!=null){
                         v.add(activityName);
-                        if(sType==null)
-                            sType="msg_error_loading_activity";
+                        //if(sType==null)
+                        //    sType="msg_error_loading_activity";
                     }
-                    if(sType==null)
-                        sType=Messages.ERROR;
+                    //if(sType==null)
+                    //    sType=Messages.ERROR;
                     
                     messages.showErrorWarning(thisAuthor, "err_reading_data", v, exception, null);
                 }
@@ -410,14 +413,20 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
         if(project!=null)
             project.end();
         project=p;
+        setFrameTitle(null);
+        checkActions();
+    }
+
+    protected void setFrameTitle(String s){
         java.awt.Frame fr=JOptionPane.getFrameForComponent(AuthorSingleFrame.this);
         if(fr!=null){
-            StringBuffer sb=new StringBuffer("JClic author");
-            if(project!=null)
+            StringBuilder sb=new StringBuilder("JClic author");
+            if(s!=null && s.length()>0)
+                sb.append(" - ").append(s);
+            else if(project != null)
                 sb.append(" - ").append(project.getName());
             fr.setTitle(sb.substring(0));
         }
-        checkActions();
     }
     
     protected void checkActions(){
@@ -478,6 +487,8 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
         toolsMenu.addSeparator();
         toolsMenu.add(new KJMenuItem(getAction(ACTION_DOCTREE)));
         toolsMenu.addSeparator();
+        toolsMenu.add(new KJMenuItem(getAction(ACTION_EXPORT_HTML5)));
+        toolsMenu.addSeparator();
         toolsMenu.add(new KJMenuItem(getAction(ACTION_CREATE_HTML)));
         toolsMenu.add(new KJMenuItem(getAction(ACTION_CREATE_INSTALLER)));
         menuBar.add(toolsMenu);
@@ -574,9 +585,10 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
     ACTION_CREATE_HTML=13,
     ACTION_CREATE_INSTALLER=14,
     ACTION_IMPORT_ACTIVITIES=15,
-    NUM_ACTIONS=16;
+    ACTION_EXPORT_HTML5=16,
+    AUTHOR_NUM_ACTIONS=17;
     
-    public static final String[] ACTION_NAME={
+    public static final String[] ACTION_NAMES={
         "openFile",
         "openUrl",
         "saveFile",
@@ -592,7 +604,8 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
         "editSeq",
         "createHTML",
         "createInstaller",
-        "importActivities"
+        "importActivities",
+        "exportProject"
     };
     public static final String[] ACTION_ICONS={
         "icons/file_open.gif",
@@ -610,11 +623,12 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
         "icons/sequence.gif",
         "icons/html_doc.gif",
         "icons/installer.gif",
-        "icons/import_act.png"
+        "icons/import_act.png",
+        "icons/html_doc.gif"
     };
     
     protected int getNumActions(){
-        return NUM_ACTIONS;
+        return AUTHOR_NUM_ACTIONS;
     }
     
     protected void buildActions(){
@@ -769,13 +783,35 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                     JClicProject prj=NewProjectDlg.prompt(AuthorSingleFrame.this, AuthorSingleFrame.this, createFileSystem());
                     if(prj!=null){
                         setProject(prj);
-                        //setProject(new JClicProject(AuthorSingleFrame.this, createFileSystem(), null));
                         attachProject();
                     }
                 }
             }
         };
         
+        actions[ACTION_EXPORT_HTML5]=new AbstractAction(){
+            public void actionPerformed(ActionEvent ev){
+                if(checkSaveChanges()){
+                    String inputPath=project.getFileSystem().getFullFileNamePath("");
+                    String[] folders=ExportToJSDlg.prompt(AuthorSingleFrame.this, AuthorSingleFrame.this,
+                            inputPath, AuthorSingleFrame.this.settings.rootExportPath,
+                            AuthorSingleFrame.this.settings.rootScormPath);
+                    if(folders!=null){
+                      boolean exportAll = folders[2].equals("true");
+                      String scormFile = folders[3];
+                      if(!exportAll)
+                        inputPath = project.getFileSystem().getFullRoot();
+                      String mainFile = project.getFileSystem().getRelativeFileNamePath(project.getFullPath());
+                      if(mainFile.endsWith(".zip"))
+                        mainFile = mainFile.substring(0, mainFile.length()-4);
+                      ExportTaskDlg.doTask(AuthorSingleFrame.this, settings, AuthorSingleFrame.this,
+                              inputPath, folders[0], mainFile,
+                              project, exportAll, scormFile);
+                    }
+                }
+            }
+        };
+        
         actions[ACTION_EDIT_PROJECT]=new AbstractAction(){
             public void actionPerformed(ActionEvent ev){
                 if(tabbedPane!=null)
@@ -823,7 +859,7 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
         actions[ACTION_EDIT_SEQ], actions[ACTION_EDIT_ACTIVITIES],
         actions[ACTION_EDIT_MEDIA], actions[ACTION_EDIT_PROJECT],
         actions[ACTION_CREATE_HTML], actions[ACTION_CREATE_INSTALLER],
-        actions[ACTION_IMPORT_ACTIVITIES]};
+        actions[ACTION_IMPORT_ACTIVITIES], actions[ACTION_EXPORT_HTML5]};
         
         checkActions();
     }
@@ -847,24 +883,19 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                 }
             }
             
-            String result=null;
+            String result;
             File f=new File(path);
             if(!saveAs && f.exists() && f.canWrite())
                 result=path;
             else
                 result=fs.chooseFile(path, true, filters, options, null, AuthorSingleFrame.this, false);
             if(result!=null){
-                /*
-                try{
-                    projectEditor.saveProject(result);
-                    addRecentFile(project.getFullPath());
-                    ok=true;
-                } catch(Exception ex){
-                    messages.showErrorWarning(AuthorSingleFrame.this, "FILE_ERR_SAVING", result, ex, null);
-                }
-                 */
                 
                 ok=doSaveFile(result);
+
+                // 03-Feb-2011
+                // Correction of bug #53
+                setFrameTitle(null);
             }
         }
         return ok;
@@ -882,9 +913,10 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
         //System.gc();
         
         worker=new edu.xtec.util.SwingWorker(){
-            Exception exception=null;
-            
+            Exception exception=null;            
             AuthorSingleFrame thisAuthor=AuthorSingleFrame.this;
+            
+            @Override
             public Object construct(){
                 Object o=null;
                 setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
@@ -892,13 +924,14 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                     projectEditor.saveProject(fName);
                     saveResult=true;
                     addRecentFile(project.getFullPath());
-                    o=new Boolean(true);
+                    o=true;
                 } catch(Exception ex){
                     exception=ex;
                 }
                 return o;
             }
             
+            @Override
             public void finished(){
                 progressDialog.setVisible(false);
                 setCursor(null);
@@ -927,9 +960,10 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
         System.gc();
         
         worker=new edu.xtec.util.SwingWorker(){
-            Exception exception=null;
-            
+            Exception exception=null;            
             AuthorSingleFrame thisAuthor=AuthorSingleFrame.this;
+
+            @Override
             public Object construct(){
                 Object o=null;
                 setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
@@ -956,11 +990,11 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                             Object[] selection=actList.getSelectedValues();
                             
                             // check media elements to import
-                            Vector mediaNames=new Vector();
+                            List<String> mediaNames=new ArrayList<String>();
                             for(int i=0; i<selection.length; i++){
                                 ActivityBagElement abe=(ActivityBagElement)selection[i];
-                                java.util.HashMap map=abe.getReferences();
-                                java.util.Iterator it=map.keySet().iterator();
+                                Map map=abe.getReferences();
+                                Iterator it=map.keySet().iterator();
                                 while(it.hasNext()){
                                     String media=(String)it.next();
                                     Object mediaType=map.get(media);
@@ -972,7 +1006,7 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                             }
                             
                             // get the list of media bag elements
-                            Vector mediaBagElements=new Vector();
+                            ArrayList<MediaBagElement> mediaBagElements=new ArrayList<MediaBagElement>();
                             for(int i=0; i<mediaNames.size(); i++){
                                 MediaBagElement mb=jcp.mediaBag.getElement((String)mediaNames.get(i));
                                 if(mb!=null)
@@ -980,8 +1014,7 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                             }
                             
                             //check for repeated media names and import media
-                            for(int i=0; i<mediaBagElements.size(); i++){
-                                MediaBagElement mbe=(MediaBagElement)mediaBagElements.get(i);
+                            for(MediaBagElement mbe : mediaBagElements){
                                 String name=mbe.getName();
                                 String rootName=name;
                                 progressDialog.setText(messages.get("import_impmedia")+" "+name);
@@ -1031,7 +1064,7 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                                 projectEditor.getActivityBagEditor().insertEditor(abeed, true, -1, false);
                             }
                             
-                            o=new Boolean(true);
+                            o=true;
                         }
                     }
                     
@@ -1041,6 +1074,7 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                 return o;
             }
             
+            @Override
             public void finished(){
                 progressDialog.setVisible(false);
                 setCursor(null);
@@ -1084,9 +1118,9 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
     }
     
     protected String getActionName(int actionId){
-        if(actionId<0 || actionId>=ACTION_NAME.length)
+        if(actionId<0 || actionId>=ACTION_NAMES.length)
             return null;
-        return ACTION_NAME[actionId];
+        return ACTION_NAMES[actionId];
     }
     
     protected Icon getActionIcon(int actionId){
@@ -1166,7 +1200,9 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
                 player.setProject(project);
                 player.getHistory().clearHistory();
             }
-            projectEditor.setTestPlayerContainer(this);
+            // 22-Jan-2013: JClicAuthor hangs when an I/O error occurs
+            if(projectEditor!=null)
+                projectEditor.setTestPlayerContainer(this);
         }
         actions[ACTION_DOCTREE].setEnabled(project!=null);
     }
@@ -1211,9 +1247,9 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
             }
         });
         
-        JClicProject project=new JClicProject(this, new FileSystem(this), "");
+        JClicProject newProject=new JClicProject(this, new FileSystem(this), "");
         
-        projectEditor=(JClicProjectEditor)project.getEditor(null);
+        projectEditor=(JClicProjectEditor)newProject.getEditor(null);
         
         ProjectSettingsEditor psed=projectEditor.getProjectSettingsEditor();
         projectSettingsEditorPanel=psed.createEditorPanel(options);
@@ -1230,12 +1266,13 @@ public class AuthorSingleFrame extends JPanel implements ResourceBridge, TestPla
         tabbedPane.addTab(messages.get("edit_sequences"), ActivitySequenceEditor.getIcon(), activitySequenceEditorPanel, messages.get("edit_sequences_tooltip"));
         
         playerDlg=new JDialog(JOptionPane.getFrameForComponent(this), "test player", true);
-        player=new Player(options, project);
+        player=new Player(options, newProject);
         player.getHistory().setTestMode(true);
         player.appName="JClic test player";
         player.addTo(playerDlg, null);
         playerDlg.addWindowListener(new WindowAdapter(){
             //public void windowClosing(WindowEvent e){
+            @Override
             public void windowClosed(WindowEvent e){
                 player.closeHelpWindow();
                 //player.stopMedia(-1);
