@@ -21,15 +21,14 @@
 
 package edu.xtec.jclic.activities.panels;
 
-import edu.xtec.jclic.ActivityEditor;
 import edu.xtec.jclic.Activity;
+import edu.xtec.jclic.ActivityEditor;
 import edu.xtec.jclic.ActivityEditorPanel;
-import edu.xtec.jclic.boxes.ActiveBagContentEditor;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.29
  */
 public class IdentifyEditor extends ActivityEditor {
     
@@ -40,6 +39,7 @@ public class IdentifyEditor extends ActivityEditor {
             act.abc[0].defaultIdValue=0;
     }
     
+    @Override
     protected void createPanels(ActivityEditorPanel panel){        
         panel.addInternalPanel(ActivityEditorPanel.SINGLE_BOOL_ALT, null, null);
     } 
