@@ -21,14 +21,13 @@
 
 package edu.xtec.jclic.activities.panels;
 
-import edu.xtec.jclic.ActivityEditor;
 import edu.xtec.jclic.Activity;
+import edu.xtec.jclic.ActivityEditor;
 import edu.xtec.jclic.ActivityEditorPanel;
-import edu.xtec.jclic.boxes.ActiveBagContentEditor;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
+ * @author Francesc Busquets (fbusquets@xtec.cat)
  * @version 1.0
  */
 public class InformationScreenEditor extends ActivityEditor {
@@ -38,6 +37,7 @@ public class InformationScreenEditor extends ActivityEditor {
         super(act);
     }
     
+    @Override
     protected void createPanels(ActivityEditorPanel panel){        
         panel.addInternalPanel(ActivityEditorPanel.SINGLE, null, null);
     } 
