@@ -31,13 +31,13 @@ import edu.xtec.util.Options;
 import java.awt.Component;
 import java.awt.Dimension;
 import javax.swing.text.AttributeSet;
-import javax.swing.text.StyleConstants;
 import javax.swing.text.BadLocationException;
+import javax.swing.text.StyleConstants;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.29
  */
 public class TextActivityBaseEditor extends ActivityEditor {
     
@@ -46,6 +46,7 @@ public class TextActivityBaseEditor extends ActivityEditor {
         super(act);
     }
     
+    @Override
     protected void createPanels(ActivityEditorPanel panel){        
         panel.addInternalPanel(ActivityEditorPanel.TEXT_BASE, null, null);
     } 
@@ -102,7 +103,7 @@ public class TextActivityBaseEditor extends ActivityEditor {
         if(getTextActivity()==null)
             return false;
         TextActivityDocument tad=getTextActivity().tad;
-        String text="";
+        String text;
         try{
             text=tad.getText(0, tad.getLength());
         } catch(Exception ex){
