@@ -21,28 +21,29 @@
 
 package edu.xtec.jclic.activities.text;
 
-import edu.xtec.util.Options;
-import edu.xtec.jclic.beans.TextListEditor;
+import edu.xtec.jclic.bags.MediaBagEditor;
 import edu.xtec.jclic.beans.SmallIntEditor;
-import edu.xtec.util.Resizer;
-import edu.xtec.jclic.boxes.JPanelActiveBox;
-import java.awt.Rectangle;
-import javax.swing.JComponent;
-import java.awt.Point;
+import edu.xtec.jclic.beans.TextListEditor;
 import edu.xtec.jclic.boxes.ActiveBoxContent;
 import edu.xtec.jclic.boxes.ActiveBoxContentEditor;
-import java.awt.Dimension;
-import java.util.Arrays;
+import edu.xtec.jclic.boxes.JPanelActiveBox;
+import edu.xtec.util.Options;
+import edu.xtec.util.Resizer;
 import edu.xtec.util.ResizerPanel;
-import edu.xtec.jclic.bags.MediaBagEditor;
 import java.awt.CardLayout;
-import java.util.HashMap;
 import java.awt.Component;
+import java.awt.Dimension;
+import java.awt.Point;
+import java.awt.Rectangle;
+import java.util.Arrays;
+import java.util.HashMap;
+import java.util.Map;
+import javax.swing.JComponent;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.16
  */
 public class TextTargetEditorPanel extends javax.swing.JPanel implements java.beans.PropertyChangeListener, java.awt.event.ActionListener, Resizer.ResizerListener {
     
@@ -59,7 +60,7 @@ public class TextTargetEditorPanel extends javax.swing.JPanel implements java.be
     protected static final String[] popKeys={"no", "always", "onError", "onDemand"};
     protected String[] popItems;
     
-    protected static final HashMap panels=new HashMap(1);
+    protected static final Map<Options, TextTargetEditorPanel> panels=new HashMap<Options, TextTargetEditorPanel>(1);
     
     /** Creates new form TextTargetPanel */
     public TextTargetEditorPanel(Options options, MediaBagEditor mbe) {
@@ -413,10 +414,10 @@ public class TextTargetEditorPanel extends javax.swing.JPanel implements java.be
             if(answers.length>0)
                 textTarget.answer=answers;
             if(listChk.isSelected()){
-                String[] options=listEditor.getTextList();
-                if(options.length>0){
+                String[] textList=listEditor.getTextList();
+                if(textList.length>0){
                     textTarget.isList=true;
-                    textTarget.options=options;
+                    textTarget.options=textList;
                 }
             }
             else{
@@ -498,7 +499,7 @@ public class TextTargetEditorPanel extends javax.swing.JPanel implements java.be
     // End of variables declaration//GEN-END:variables
 
     public static boolean editTextTarget(TextTarget tt, Options options, MediaBagEditor mbe, Component parent){
-        TextTargetEditorPanel ttep=(TextTargetEditorPanel)panels.get(options);
+        TextTargetEditorPanel ttep=panels.get(options);
         if(ttep==null){
             ttep=new TextTargetEditorPanel(options, mbe);
             panels.put(options, ttep);
