@@ -21,15 +21,14 @@
 
 package edu.xtec.jclic.activities.text;
 
-import edu.xtec.jclic.ActivityEditor;
 import edu.xtec.jclic.Activity;
+import edu.xtec.jclic.ActivityEditor;
 import edu.xtec.jclic.ActivityEditorPanel;
-import edu.xtec.jclic.boxes.ActiveBagContentEditor;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.29
  */
 public class WrittenAnswerEditor extends ActivityEditor {
     
@@ -38,6 +37,7 @@ public class WrittenAnswerEditor extends ActivityEditor {
         super(act);
     }
     
+    @Override
     protected void createPanels(ActivityEditorPanel panel){        
         panel.addInternalPanel(ActivityEditorPanel.DOUBLE_REL_ALT, null, null);
     } 
