@@ -22,31 +22,23 @@
 package edu.xtec.jclic.bags;
 
 import edu.xtec.jclic.*;
-import edu.xtec.jclic.CopyActivityAttributesPanel;
 import edu.xtec.jclic.edit.*;
-import edu.xtec.util.Options;
-
-import java.awt.Component;
-import javax.swing.ImageIcon;
-import javax.swing.Icon;
-import javax.swing.tree.TreeNode;
-import java.util.Iterator;
-import javax.swing.tree.MutableTreeNode;
 import edu.xtec.jclic.project.JClicProjectEditor;
-import javax.swing.JComboBox;
-import javax.swing.JTextField;
-import javax.swing.JComponent;
-import edu.xtec.util.TripleString;
-import edu.xtec.jclic.misc.Utils;
 import edu.xtec.util.Messages;
-import edu.xtec.util.StrUtils;
+import edu.xtec.util.Options;
+import java.awt.Component;
+import java.util.ArrayList;
 import java.util.Enumeration;
-import java.util.Vector;
+import java.util.Iterator;
+import java.util.List;
+import javax.swing.Icon;
+import javax.swing.ImageIcon;
+import javax.swing.tree.MutableTreeNode;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.16
  */
 public class ActivityBagEditor extends Editor {
     
@@ -82,6 +74,7 @@ public class ActivityBagEditor extends Editor {
         return  ActivityBagEditorPanel.class;
     }
     
+    @Override
     public String getTitleKey(){
         return "edit_activities";
     }
@@ -96,10 +89,12 @@ public class ActivityBagEditor extends Editor {
         return icon;
     }
     
+    @Override
     public javax.swing.Icon getIcon(boolean leaf, boolean expanded){
         return getIcon();
     }
     
+    @Override
     public String toString(){
         return "Activity bag";
     }    
@@ -154,7 +149,7 @@ public class ActivityBagEditor extends Editor {
 
         // ------------------
         
-        Activity act=null;
+        Activity act;
         try{
             act=Activity.getActivity(actClassName, getProjectEditor().getProject());
             act.name=actName;
@@ -191,6 +186,7 @@ public class ActivityBagEditor extends Editor {
         setModified(true);
     }
         
+    @Override
     public void setActionsOwner() {
         allowDelete = allowCut = allowCopy = allowPaste = false;
         super.setActionsOwner();
@@ -199,6 +195,7 @@ public class ActivityBagEditor extends Editor {
         }
     }
     
+    @Override
     public void clearActionsOwner(){
         super.clearActionsOwner();
         if(actionsCreated){
@@ -237,6 +234,7 @@ public class ActivityBagEditor extends Editor {
         }
     }           
         
+    @Override
     public void insert(MutableTreeNode newChild, int childIndex){
         super.insert(newChild, childIndex);
         if(!initializing){
@@ -258,6 +256,7 @@ public class ActivityBagEditor extends Editor {
         }
     }
     
+    @Override
     public void remove(int childIndex){
         super.remove(childIndex);
         getActivityBag().removeElementAt(childIndex);
@@ -273,13 +272,13 @@ public class ActivityBagEditor extends Editor {
     
     public int checkOrphanElements(Options options, Component parent, boolean prompt){
         int result=Messages.YES;
-        Vector v=new Vector();
+        List<String> v=new ArrayList<String>();
         ActivityBagElement[] abel=getActivityBag().getElements();
         ActivitySequenceEditor ased=getProjectEditor().getActivitySequenceEditor();
         ActivitySequenceElement[] asel=ased.getActivitySequence().getElements();
         for(int i=0; i<abel.length; i++){
             String actName=abel[i].getName();
-            int j=0;
+            int j;
             for(j=0; j<asel.length; j++){
                 if(asel[j].getActivityName().equals(actName))
                     break;
@@ -294,16 +293,16 @@ public class ActivityBagEditor extends Editor {
                 //result=options.getMessages().showQuestionDlg(parent, "edit_project_orphanActivities", null, true);                
                 Object[] object=new Object[]{
                     options.getMsg("edit_project_orphanActivities"),
-                    v.size()>10 ? (Object)(new javax.swing.JScrollPane(new javax.swing.JList(v))) : (Object)v,
+                    v.size()>10 ? (Object)(new javax.swing.JScrollPane(new javax.swing.JList(v.toArray()))) : (Object)v,
                     options.getMsg("edit_project_orphanActivities_prompt"),
                 };
                 result=options.getMessages().showQuestionDlgObj(parent, object, "edit_project_orphanActivities_title", "ync");
                 doIt=(result==Messages.YES);
             }
             if(doIt){
-                Iterator it=v.iterator();
+                Iterator<String> it=v.iterator();
                 while(it.hasNext()){
-                    ased.createNewSequenceElement((String)it.next(), null, -1);
+                    ased.createNewSequenceElement(it.next(), null, -1);
                 }
             }
         }
