@@ -43,8 +43,8 @@ import javax.swing.event.DocumentEvent;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.09
  */
 public class ActivitySequenceElementEditorPanel extends EditorPanel {
     
@@ -442,7 +442,8 @@ public class ActivitySequenceElementEditorPanel extends EditorPanel {
                 actModel=new ListComboModel(lm);
                 actCombo.setModel(actModel);
             }
-            actCombo.setSelectedItem(jcpe.getActivityBagEditor().getChildByName(ase.getActivityName()));
+            if(ase!=null)
+                actCombo.setSelectedItem(jcpe.getActivityBagEditor().getChildByName(ase.getActivityName()));
         }
         else{
             actModel=new ListComboModel();
@@ -469,6 +470,7 @@ public class ActivitySequenceElementEditorPanel extends EditorPanel {
         repaint();
     }    
     
+    @Override
     public boolean eventPerformed(EventObject ev){
         
         Object src=(ev==null ? null : ev.getSource());
@@ -503,6 +505,7 @@ public class ActivitySequenceElementEditorPanel extends EditorPanel {
         return true;
     }
     
+    @Override
     public boolean documentChangePerformed(DocumentEvent documentEvent){
         if(documentEvent!=null && documentEvent.getDocument().equals(tagText.getDocument()))
             updateTable();
@@ -547,7 +550,8 @@ public class ActivitySequenceElementEditorPanel extends EditorPanel {
         return ji;
     }
         
-    public void setEnabled(boolean enabled){
+    @Override
+    public final void setEnabled(boolean enabled){
         super.setEnabled(enabled);
         actCombo.setEnabled(enabled);
         fwdEnabledChk.setEnabled(enabled);
@@ -602,10 +606,12 @@ public class ActivitySequenceElementEditorPanel extends EditorPanel {
         }
     }
     
+    @Override
     protected Icon getIcon(){
         return ActivitySequenceElementEditor.getIcon();
     }
     
+    @Override
     protected String getTitle(){
         return "Activity sequence element";
         //return options.getMsg("library_dlg_title");
@@ -641,7 +647,7 @@ public class ActivitySequenceElementEditorPanel extends EditorPanel {
     }
     
     private void setJumpLabels(){
-        StringBuffer sb=new StringBuffer();
+        StringBuilder sb=new StringBuilder();
         ActivitySequenceElement ase=getActivitySequenceElement();
         if(ase!=null && ase.fwdJump!=null){
             if(ase.fwdJump.sequence!=null)
@@ -679,10 +685,12 @@ public class ActivitySequenceElementEditorPanel extends EditorPanel {
             checkIcon();
         }
         
+        @Override
         protected Object createObject(){
             return new ConditionalJumpInfo(JumpInfo.RETURN, null, upper ? 80 : 20);
         }
         
+        @Override
         protected Object editObject(Object o){
             if(o==null)
                 o=createObject();
@@ -696,6 +704,7 @@ public class ActivitySequenceElementEditorPanel extends EditorPanel {
             return b ? cjp.getJumpInfo() : null;
         };
         
+        @Override
         public void changeObject(Object o){
             super.changeObject(o);
             checkIcon();
