@@ -23,35 +23,33 @@ package edu.xtec.jclic.bags;
 
 import edu.xtec.jclic.Constants;
 import edu.xtec.jclic.edit.*;
-import edu.xtec.util.Options;
-import edu.xtec.util.StrUtils;
-import java.awt.Component;
-import edu.xtec.jclic.misc.Utils;
 import edu.xtec.jclic.fileSystem.FileSystem;
 import edu.xtec.jclic.fileSystem.ZipFileSystem;
+import edu.xtec.jclic.misc.Utils;
 import edu.xtec.jclic.project.JClicProjectEditor;
 import edu.xtec.util.Messages;
+import edu.xtec.util.Options;
 import edu.xtec.util.ProgressDialog;
+import edu.xtec.util.StrUtils;
 import edu.xtec.util.StreamIO;
-import edu.xtec.util.SwingWorker;
 import java.awt.Color;
-import java.awt.Cursor;
+import java.awt.Component;
 import java.awt.Image;
 import java.awt.image.BufferedImage;
 import java.io.File;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.Iterator;
-import java.util.Vector;
+import java.util.List;
 import javax.swing.Icon;
 import javax.swing.JComponent;
-import javax.swing.SwingUtilities;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.16
  */
 public class MediaBagEditor extends Editor{
 
@@ -94,6 +92,7 @@ public class MediaBagEditor extends Editor{
         return MediaBagMultiEditorPanel.class;
     }
     
+    @Override
     public String getTitleKey(){
         return "edit_media";
     }
@@ -107,7 +106,7 @@ public class MediaBagEditor extends Editor{
     }    
             
     public static String[] selectMediaFiles(MediaBag mediaBag, Options options, Component dlgOwner, int fileFilters, String defaultFile){
-        String[] result=null;
+        String[] result;
         FileSystem fs=mediaBag.getProject().getFileSystem();
         //int[] filters=new int[]{fileFilters};
         //if(fileFilters<0){
@@ -150,7 +149,7 @@ public class MediaBagEditor extends Editor{
         FileSystem fs=mb.getProject().getFileSystem();
         String[] fNames=selectMediaFiles(getMediaBag(), options, dlgOwner, fileFilters, null);
         if(fNames!=null){
-            Vector v=new Vector();
+            List<MediaBagElementEditor> v=new ArrayList<MediaBagElementEditor>();
             for(int i=0; i<fNames.length; i++){
                 if(mb.getElementByFileName(fNames[i])!=null){
                     msg.showAlert(dlgOwner, new String[]{
@@ -230,14 +229,13 @@ public class MediaBagEditor extends Editor{
                     }
 
                     if(!cancel && mb.addElement(mbe)){
-                        v.add(mbe.getEditor(this));
+                        v.add((MediaBagElementEditor)mbe.getEditor(this));
                         //fireEditorDataChanged(null);
                     }
                 }
             }
             if(v.size()>0){
-                result=new MediaBagElementEditor[v.size()];
-                v.copyInto(result);
+                result=v.toArray(new MediaBagElementEditor[v.size()]);
                 fireEditorDataChanged(null);
             }
         }
@@ -246,7 +244,9 @@ public class MediaBagEditor extends Editor{
     
     public void updateAllElements(JComponent parent){        
         final ProgressDialog progressDialog=new ProgressDialog(parent, getOptions());
-        SwingWorker sw=new SwingWorker(){
+        edu.xtec.util.SwingWorker sw=new edu.xtec.util.SwingWorker(){
+            
+            @Override
             public Object construct(){
                 FileSystem fs=getMediaBag().getProject().getFileSystem();
                 ZipFileSystem zfs=(fs instanceof ZipFileSystem) ? (ZipFileSystem)fs : null;
@@ -273,6 +273,8 @@ public class MediaBagEditor extends Editor{
                 fireEditorDataChanged(null);                
                 return null;
             }
+            
+            @Override
             public void finished(){
                 progressDialog.setVisible(false);
             }
@@ -283,7 +285,9 @@ public class MediaBagEditor extends Editor{
     public void exportAllElements(final JComponent parent){
         final Options options=getOptions();
         final ProgressDialog progressDialog=new ProgressDialog(parent, options);
-        SwingWorker sw=new SwingWorker(){
+        edu.xtec.util.SwingWorker sw=new edu.xtec.util.SwingWorker(){
+
+            @Override            
             public Object construct(){
                 FileSystem fs=getMediaBag().getProject().getFileSystem();
                 ZipFileSystem zfs=(fs instanceof ZipFileSystem) ? (ZipFileSystem)fs : null;
@@ -346,6 +350,8 @@ public class MediaBagEditor extends Editor{
                 progressDialog.setFileLabel(null);
                 return null;
             }
+            
+            @Override            
             public void finished(){
                 progressDialog.setVisible(false);
             }
@@ -353,6 +359,7 @@ public class MediaBagEditor extends Editor{
         progressDialog.start("edit_media_refreshAll", "edit_media_refreshAll_working", sw, true, true, false);
     }
 
+    @Override
     public void setActionsOwner(){
         allowDelete = allowCut = allowCopy = allowPaste = false;
         super.setActionsOwner();
@@ -365,6 +372,7 @@ public class MediaBagEditor extends Editor{
         }
     }
     
+    @Override
     public void clearActionsOwner(){
         super.clearActionsOwner();
         if(actionsCreated){
@@ -431,8 +439,8 @@ public class MediaBagEditor extends Editor{
         return result;
     }
     
-    public Vector getChildrenList(int filters){
-        Vector v=new Vector();
+    public List<MediaBagElementEditor> getChildrenList(int filters){
+        List<MediaBagElementEditor> v=new ArrayList<MediaBagElementEditor>();
         Iterator it=getMediaBag().getElementsByName().iterator();
         String[] extFilters=Utils.getFileFilterExtensions(filters);
         while(it.hasNext()){
@@ -470,7 +478,7 @@ public class MediaBagEditor extends Editor{
     
     public int checkOrphanElements(Options options, Component parent, boolean prompt){
         int result=Messages.YES;
-        Vector v=new Vector();
+        List<MediaBagElementEditor> v=new ArrayList<MediaBagElementEditor>();
         Enumeration en=children();
         while(en.hasMoreElements()){
             MediaBagElementEditor mbed=(MediaBagElementEditor)en.nextElement();
@@ -483,17 +491,16 @@ public class MediaBagEditor extends Editor{
                 //result=options.getMessages().showQuestionDlg(parent, "edit_project_orphanMedia", null, true);
                 Object[] object=new Object[]{
                     options.getMsg("edit_project_orphanMedia"),
-                    v.size()>10 ? (Object)(new javax.swing.JScrollPane(new javax.swing.JList(v))) : (Object)v,
+                    v.size()>10 ? (Object)(new javax.swing.JScrollPane(new javax.swing.JList(v.toArray()))) : (Object)v,
                     options.getMsg("edit_project_orphanMedia_prompt"),
                 };
                 result=options.getMessages().showQuestionDlgObj(parent, object, "edit_project_orphanMedia_title", "ync");
                 doIt=(result==Messages.YES);
             }
             if(doIt){
-                Iterator it=v.iterator();
+                Iterator<MediaBagElementEditor> it=v.iterator();
                 while(it.hasNext()){
-                    MediaBagElementEditor mbed=(MediaBagElementEditor)it.next();
-                    mbed.delete(true);
+                    it.next().delete(true);
                 }
             }
         }
