@@ -32,16 +32,16 @@ import edu.xtec.util.Messages;
 import edu.xtec.util.Options;
 import java.awt.Component;
 import java.awt.Image;
+import java.util.ArrayList;
 import java.util.HashMap;
-import java.util.Vector;
+import java.util.List;
+import java.util.Map;
 import javax.swing.Icon;
-import javax.swing.ImageIcon;
-import javax.swing.JOptionPane;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.16
  */
 public class MediaBagElementEditor extends Editor{
     
@@ -97,7 +97,7 @@ public class MediaBagElementEditor extends Editor{
         String oldName=getName();
         String errMsg=null;
         newName=newName.trim();
-        Component parent=(agent instanceof Component) ? (Component)agent : null;
+        Component parentComponent=(agent instanceof Component) ? (Component)agent : null;
         boolean result=false;
         
         if(oldName.equals(newName)){
@@ -118,8 +118,8 @@ public class MediaBagElementEditor extends Editor{
             //    fireEditorDataChanged(agent);
         }
         
-        if(errMsg!=null && msg!=null && parent!=null){
-            msg.showAlert(parent, errMsg);            
+        if(errMsg!=null && msg!=null && parentComponent!=null){
+            msg.showAlert(parentComponent, errMsg);            
         }
         return result;
     }
@@ -135,8 +135,8 @@ public class MediaBagElementEditor extends Editor{
         String oldFileName=getMediaBagElement().getFileName();
         
         FileSystem fs=getMediaBag().getProject().getFileSystem();
-        newFileName=fs.stdFn(newFileName.trim());
-        Component parent=(agent instanceof Component) ? (Component)agent : null;
+        newFileName=FileSystem.stdFn(newFileName.trim());
+        Component parentComponent=(agent instanceof Component) ? (Component)agent : null;
         
         if(oldFileName.equals(newFileName)){
             // do nothing           
@@ -147,8 +147,8 @@ public class MediaBagElementEditor extends Editor{
         else if(newFileName.length()<1)
             errMsg="edit_media_chfile_invalid";
         else if(getMediaBag().getElementByFileName(newFileName)!=null){
-            if(msg!=null && parent!=null){            
-                msg.showAlert(parent, new String[]{
+            if(msg!=null && parentComponent!=null){            
+                msg.showAlert(parentComponent, new String[]{
                     msg.get("edit_media_exists_1"),
                     newFileName,
                     msg.get("edit_media_exists_2")
@@ -161,12 +161,13 @@ public class MediaBagElementEditor extends Editor{
             fireEditorDataChanged(agent);
         }
         
-        if(errMsg!=null && msg!=null && parent!=null){
-            msg.showAlert(parent, errMsg);            
+        if(errMsg!=null && msg!=null && parentComponent!=null){
+            msg.showAlert(parentComponent, errMsg);            
         }        
         return result;
     }
         
+    @Override
     public String toString(){
         return getName();
     }
@@ -174,6 +175,7 @@ public class MediaBagElementEditor extends Editor{
     protected void saveData(){
     }
         
+    @Override
     protected boolean delete(boolean changeSelection){        
         MediaBagEditor mbe=(MediaBagEditor)getEditorParent();                                
         boolean result=super.delete(changeSelection);
@@ -184,6 +186,7 @@ public class MediaBagElementEditor extends Editor{
         return result;
     }
     
+    @Override
     protected boolean canClone(){
         return false;
     }
@@ -196,6 +199,7 @@ public class MediaBagElementEditor extends Editor{
         allowPaste=false;
     }
     
+    @Override
     public void setActionsOwner(){        
         setActionsFlag();
         super.setActionsOwner();
@@ -206,6 +210,7 @@ public class MediaBagElementEditor extends Editor{
         }
     }
     
+    @Override
     public void clearActionsOwner(){
         super.clearActionsOwner();
         if(actionsCreated){
@@ -220,15 +225,18 @@ public class MediaBagElementEditor extends Editor{
         return icon;
     }
     
+    @Override
     public Icon getIcon(boolean leaf, boolean expanded){
         //return leaf ? getIcon() : null;
         return getIcon();
     }
     
+    @Override
     public boolean canBeParentOf(Editor e){
         return false;
     }
     
+    @Override
     public boolean canBeSiblingOf(Editor e){
         return (e instanceof MediaBagElementEditor);
     }
@@ -256,7 +264,7 @@ public class MediaBagElementEditor extends Editor{
     
     public String getDescription(Options options){
         MediaBagElement mbe=getMediaBagElement();
-        StringBuffer sb=new StringBuffer();
+        StringBuilder sb=new StringBuilder();
         String fileName=mbe.getFileName();
         if(fileName!=null){
             int type=Utils.getFileType(fileName);
@@ -304,15 +312,15 @@ public class MediaBagElementEditor extends Editor{
         return result;
     }
     
-    public Vector listReferences(){
-        Vector result=null;
+    public List<String> listReferences(){
+        List<String> result=null;
         MediaBag mb=getMediaBag();
         if(mb!=null){
-            HashMap hm=new HashMap();
+            Map<String, String> hm=new HashMap<String, String>();
             mb.listReferencesTo(getName(), Constants.MEDIA_OBJECT, hm);
-            result=new Vector(hm.keySet());
+            result=new ArrayList<String>(hm.keySet());
         }
-        allowDelete=(result==null || result.size()==0);
+        allowDelete=(result==null || result.isEmpty());
         deleteAction.setEnabled(allowDelete);
         return result;        
     }
