@@ -21,35 +21,29 @@
 
 package edu.xtec.jclic.boxes;
 
-import javax.swing.JPanel;
-import edu.xtec.util.Options;
-import java.awt.Graphics;
-import java.awt.Graphics2D;
-import java.awt.RenderingHints;
+import edu.xtec.jclic.Activity;
 import edu.xtec.jclic.Constants;
+import edu.xtec.jclic.activities.textGrid.CrossWord;
 import edu.xtec.jclic.bags.MediaBagEditor;
+import edu.xtec.util.ResizerPanel;
 import java.awt.AWTEvent;
-import java.awt.event.MouseEvent;
-import java.awt.geom.Point2D;
-import java.awt.Rectangle;
-import java.awt.Point;
 import java.awt.Color;
 import java.awt.Cursor;
-import edu.xtec.jclic.Activity;
-import edu.xtec.jclic.activities.textGrid.CrossWord;
-import java.awt.geom.Rectangle2D;
-import edu.xtec.jclic.boxes.BoxConnector;
-import edu.xtec.jclic.shapers.Shaper;
-import edu.xtec.util.ResizerPanel;
-import java.awt.Dimension;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.Point;
+import java.awt.Rectangle;
+import java.awt.RenderingHints;
 import java.awt.event.FocusEvent;
 import java.awt.event.FocusListener;
 import java.awt.event.KeyEvent;
+import java.awt.event.MouseEvent;
+import java.awt.geom.Point2D;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.09
  */
 public class ActiveBagContentPreviewPanel extends ResizerPanel implements FocusListener {
     
@@ -206,6 +200,7 @@ public class ActiveBagContentPreviewPanel extends ResizerPanel implements FocusL
         }
     }
     
+    @Override
     public void doLayout(){
         if(bg[0]!=null){
             if(bg[1]!=null)
@@ -215,6 +210,7 @@ public class ActiveBagContentPreviewPanel extends ResizerPanel implements FocusL
         }
     }
     
+    @Override
     public void paintComponent(Graphics g){
         super.paintComponent(g);
         if(bg[0]!=null){
@@ -269,6 +265,7 @@ public class ActiveBagContentPreviewPanel extends ResizerPanel implements FocusL
         this.mbe=mbe;
     }
     
+    @Override
     protected void processEvent(AWTEvent e){
         boolean consumed=false;
         if(bg[0]!=null){
@@ -553,7 +550,7 @@ public class ActiveBagContentPreviewPanel extends ResizerPanel implements FocusL
                     xbg.setAlternative(true);
                  */
                 
-                boolean xbgAlt=false;
+                boolean xbgAlt;
                 ActiveBoxBag xbg=(xbox==abg[0] ? abg[0] : (xbox==abg[1] ? abg[1] : null));
                 xbgAlt = xbg!=null && xbg.isAlternative();
                 setActiveBagContent(index, abc[index], altAbc[index], tgc[index]);
@@ -630,9 +627,10 @@ public class ActiveBagContentPreviewPanel extends ResizerPanel implements FocusL
         if(checkBool && abg[0]!=null){
             for(int i=0; i<abg[0].getNumCells(); i++){
                 ActiveBox bx=abg[0].getActiveBox(i);
-                if(bx!=null)
+                if(bx!=null) {
                     bx.setInverted(editMode==EDIT_BOOL ? bx.getContent().id>0 : false);
                     bx.setMarked(editMode==EDIT_BOOL ? bx.getContent().id>0 : false);
+                }
             }
         }
         repaint();
@@ -731,7 +729,7 @@ public class ActiveBagContentPreviewPanel extends ResizerPanel implements FocusL
             }            
             if(delete)
                 ch1=tgc[cgrid].wild;            
-            if(ch1!=0){
+            if(ch1!=0 && cur!=null){
                 if(crossWord){
                     checkWildChanges(cur, ch1);
                 }
