@@ -22,33 +22,34 @@
 package edu.xtec.jclic.media;
 
 import edu.xtec.jclic.Constants;
-import edu.xtec.util.Options;
 import edu.xtec.jclic.bags.MediaBagEditor;
-import java.util.Vector;
-import java.util.HashMap;
-import java.awt.Component;
-import edu.xtec.util.Messages;
-import java.util.EventObject;
-import javax.swing.JTextField;
-import javax.swing.event.DocumentEvent;
-import java.beans.PropertyChangeEvent;
-import javax.swing.text.Document;
-import edu.xtec.jclic.beans.SmallIntEditor;
-import java.awt.CardLayout;
-import java.util.Enumeration;
-import edu.xtec.jclic.misc.Utils;
 import edu.xtec.jclic.bags.MediaBagSelector;
 import edu.xtec.jclic.beans.MediaContentButton;
+import edu.xtec.jclic.beans.SmallIntEditor;
+import edu.xtec.jclic.misc.Utils;
+import edu.xtec.util.Messages;
+import edu.xtec.util.Options;
 import edu.xtec.util.ResourceManager;
 import edu.xtec.util.StrUtils;
+import java.awt.CardLayout;
+import java.awt.Component;
+import java.util.ArrayList;
+import java.util.Enumeration;
+import java.util.EventObject;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 import javax.swing.JList;
 import javax.swing.JScrollPane;
+import javax.swing.JTextField;
 import javax.swing.JToggleButton;
+import javax.swing.event.DocumentEvent;
+import javax.swing.text.Document;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.17
  */
 
 public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
@@ -58,7 +59,7 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
     MediaBagEditor mbe;
     public static final String PROP_MC="mediaContent";
     private static final String[] LOCATION_FROM_MSG_CODES={"box", "window", "frame"};    
-    Vector locationFromNames;
+    List<String> locationFromNames;
     private JTextField[] textFields;
     
     /** Creates new form MediaContentEditor */
@@ -72,12 +73,9 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
     }
     
     private void pre_init(){
-        //mediaTypeNames=new Vector();
-        //for(int i=0; i<MediaContent.NUM_MEDIA_TYPES; i++)
-        //    mediaTypeNames.add(options.getMsg("edit_mc_type_"+MEDIA_TYPE_MSG_CODES[i]));
-        locationFromNames=new Vector();
-        for(int i=0; i<LOCATION_FROM_MSG_CODES.length; i++)
-            locationFromNames.add(options.getMsg("edit_mc_location_from_"+LOCATION_FROM_MSG_CODES[i]));
+        locationFromNames=new ArrayList<String>();
+        for(String code : LOCATION_FROM_MSG_CODES)
+            locationFromNames.add(options.getMsg("edit_mc_location_from_"+code));
     }
     
     private void post_init(){
@@ -190,23 +188,14 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
      * WARNING: Do NOT modify this code. The content of this method is
      * always regenerated by the Form Editor.
      */
-    private void initComponents() {//GEN-BEGIN:initComponents
-        javax.swing.JPanel filePanelCard0;
-        javax.swing.JPanel filePanelCard1;
-        javax.swing.JPanel filePanelCard2;
-        javax.swing.JPanel fragmentPanelCard0;
-        javax.swing.JPanel fragmentPanelCard1;
-        javax.swing.JPanel fragmentPanelCard2;
+    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
+    private void initComponents() {
         java.awt.GridBagConstraints gridBagConstraints;
-        javax.swing.JPanel locationPanelCard0;
-        javax.swing.JPanel locationPanelCard1;
-        javax.swing.JPanel lpanel;
-        javax.swing.JToggleButton toggleType00;
 
         mediaTypes = new javax.swing.ButtonGroup();
         posTypes = new javax.swing.ButtonGroup();
         mediaTypePanel = new javax.swing.JPanel();
-        toggleType00 = new javax.swing.JToggleButton();
+        javax.swing.JToggleButton toggleType00 = new javax.swing.JToggleButton();
         toggleType01 = new javax.swing.JToggleButton();
         toggleType02 = new javax.swing.JToggleButton();
         toggleType03 = new javax.swing.JToggleButton();
@@ -225,30 +214,30 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         loopChk = new javax.swing.JCheckBox();
         autostartChk = new javax.swing.JCheckBox();
         filePanel = new javax.swing.JPanel();
-        filePanelCard0 = new javax.swing.JPanel();
-        filePanelCard1 = new javax.swing.JPanel();
+        javax.swing.JPanel filePanelCard0 = new javax.swing.JPanel();
+        javax.swing.JPanel filePanelCard1 = new javax.swing.JPanel();
         lbFile = new javax.swing.JLabel();
         fileTxt = new javax.swing.JTextField();
         findFileBtn = new javax.swing.JButton();
-        filePanelCard2 = new javax.swing.JPanel();
+        javax.swing.JPanel filePanelCard2 = new javax.swing.JPanel();
         lbRecbuffer = new javax.swing.JLabel();
         recBufferEditor = new edu.xtec.jclic.beans.SmallIntEditor();
         lbLength = new javax.swing.JLabel();
         lengthEditor = new edu.xtec.jclic.beans.SmallIntEditor();
         fragmentPanel = new javax.swing.JPanel();
-        fragmentPanelCard0 = new javax.swing.JPanel();
-        fragmentPanelCard1 = new javax.swing.JPanel();
+        javax.swing.JPanel fragmentPanelCard0 = new javax.swing.JPanel();
+        javax.swing.JPanel fragmentPanelCard1 = new javax.swing.JPanel();
         lbFrom = new javax.swing.JLabel();
         fromTxt = new javax.swing.JTextField();
         lbTo = new javax.swing.JLabel();
         toTxt = new javax.swing.JTextField();
-        fragmentPanelCard2 = new javax.swing.JPanel();
+        javax.swing.JPanel fragmentPanelCard2 = new javax.swing.JPanel();
         lbExternal = new javax.swing.JLabel();
         externalTxt = new javax.swing.JTextField();
         locationPanel = new javax.swing.JPanel();
-        locationPanelCard0 = new javax.swing.JPanel();
-        locationPanelCard1 = new javax.swing.JPanel();
-        lpanel = new javax.swing.JPanel();
+        javax.swing.JPanel locationPanelCard0 = new javax.swing.JPanel();
+        javax.swing.JPanel locationPanelCard1 = new javax.swing.JPanel();
+        javax.swing.JPanel lpanel = new javax.swing.JPanel();
         posCellRadio = new javax.swing.JRadioButton();
         posWindowRadio = new javax.swing.JRadioButton();
         posAbsoluteRadio = new javax.swing.JRadioButton();
@@ -257,20 +246,20 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         lbY = new javax.swing.JLabel();
         yTxt = new javax.swing.JTextField();
         lbLocFrom = new javax.swing.JLabel();
-        locFromCombo = new javax.swing.JComboBox(locationFromNames);
+        locFromCombo = new javax.swing.JComboBox(locationFromNames.toArray());
         catchMouseChk = new javax.swing.JCheckBox();
         stretchChk = new javax.swing.JCheckBox();
 
+        setBorder(javax.swing.BorderFactory.createEtchedBorder());
         setLayout(new java.awt.BorderLayout());
 
-        setBorder(new javax.swing.border.EtchedBorder());
+        mediaTypePanel.setBorder(javax.swing.BorderFactory.createTitledBorder(options.getMsg("edit_mc_type")));
         mediaTypePanel.setLayout(new java.awt.GridBagLayout());
 
-        mediaTypePanel.setBorder(new javax.swing.border.TitledBorder(options.getMsg("edit_mc_type")));
+        mediaTypes.add(toggleType00);
         toggleType00.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[0]));
         toggleType00.setText(options.getMsg("edit_mc_type_unknown"));
         toggleType00.setToolTipText(options.getMsg("edit_mc_type_unknown"));
-        mediaTypes.add(toggleType00);
         toggleType00.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -278,10 +267,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType00, gridBagConstraints);
 
+        mediaTypes.add(toggleType01);
         toggleType01.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[1]));
         toggleType01.setText(options.getMsg("edit_mc_type_sound"));
         toggleType01.setToolTipText(options.getMsg("edit_mc_type_sound"));
-        mediaTypes.add(toggleType01);
         toggleType01.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -289,10 +278,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType01, gridBagConstraints);
 
+        mediaTypes.add(toggleType02);
         toggleType02.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[2]));
         toggleType02.setText(options.getMsg("edit_mc_type_video"));
         toggleType02.setToolTipText(options.getMsg("edit_mc_type_video"));
-        mediaTypes.add(toggleType02);
         toggleType02.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -300,10 +289,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType02, gridBagConstraints);
 
+        mediaTypes.add(toggleType03);
         toggleType03.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[3]));
         toggleType03.setText(options.getMsg("edit_mc_type_midi"));
         toggleType03.setToolTipText(options.getMsg("edit_mc_type_midi"));
-        mediaTypes.add(toggleType03);
         toggleType03.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -311,22 +300,22 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType03, gridBagConstraints);
 
+        mediaTypes.add(toggleType04);
         toggleType04.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[4]));
         toggleType04.setText(options.getMsg("edit_mc_type_cdaudio"));
         toggleType04.setToolTipText(options.getMsg("edit_mc_type_cdaudio"));
-        mediaTypes.add(toggleType04);
-        toggleType04.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         toggleType04.setEnabled(false);
+        toggleType04.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
         gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType04, gridBagConstraints);
 
+        mediaTypes.add(toggleType05);
         toggleType05.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[5]));
         toggleType05.setText(options.getMsg("edit_mc_type_record"));
         toggleType05.setToolTipText(options.getMsg("edit_mc_type_record"));
-        mediaTypes.add(toggleType05);
         toggleType05.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -334,10 +323,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType05, gridBagConstraints);
 
+        mediaTypes.add(toggleType06);
         toggleType06.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[6]));
         toggleType06.setText(options.getMsg("edit_mc_type_play_recorded"));
         toggleType06.setToolTipText(options.getMsg("edit_mc_type_play_recorded"));
-        mediaTypes.add(toggleType06);
         toggleType06.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -345,10 +334,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType06, gridBagConstraints);
 
+        mediaTypes.add(toggleType07);
         toggleType07.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[7]));
         toggleType07.setText(options.getMsg("edit_mc_type_run_activity"));
         toggleType07.setToolTipText(options.getMsg("edit_mc_type_run_activity"));
-        mediaTypes.add(toggleType07);
         toggleType07.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -356,10 +345,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType07, gridBagConstraints);
 
+        mediaTypes.add(toggleType08);
         toggleType08.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[8]));
         toggleType08.setText(options.getMsg("edit_mc_type_run_sequence"));
         toggleType08.setToolTipText(options.getMsg("edit_mc_type_run_sequence"));
-        mediaTypes.add(toggleType08);
         toggleType08.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -367,10 +356,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType08, gridBagConstraints);
 
+        mediaTypes.add(toggleType09);
         toggleType09.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[9]));
         toggleType09.setText(options.getMsg("edit_mc_type_run_external"));
         toggleType09.setToolTipText(options.getMsg("edit_mc_type_run_external"));
-        mediaTypes.add(toggleType09);
         toggleType09.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -378,10 +367,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType09, gridBagConstraints);
 
+        mediaTypes.add(toggleType10);
         toggleType10.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[10]));
         toggleType10.setText(options.getMsg("edit_mc_type_url"));
         toggleType10.setToolTipText(options.getMsg("edit_mc_type_url"));
-        mediaTypes.add(toggleType10);
         toggleType10.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -389,10 +378,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType10, gridBagConstraints);
 
+        mediaTypes.add(toggleType11);
         toggleType11.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[11]));
         toggleType11.setText(options.getMsg("edit_mc_type_exit"));
         toggleType11.setToolTipText(options.getMsg("edit_mc_type_exit"));
-        mediaTypes.add(toggleType11);
         toggleType11.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -400,10 +389,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
         mediaTypePanel.add(toggleType11, gridBagConstraints);
 
+        mediaTypes.add(toggleType12);
         toggleType12.setIcon(ResourceManager.getImageIcon(MediaContentButton.MEDIA_ICONS[12]));
         toggleType12.setText(options.getMsg("edit_mc_type_return"));
         toggleType12.setToolTipText(options.getMsg("edit_mc_type_return"));
-        mediaTypes.add(toggleType12);
         toggleType12.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -445,7 +434,6 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         mainPanel.add(autostartChk, gridBagConstraints);
 
         filePanel.setLayout(new java.awt.CardLayout());
-
         filePanel.add(filePanelCard0, "card0");
 
         filePanelCard1.setLayout(new java.awt.GridBagLayout());
@@ -512,7 +500,6 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         mainPanel.add(filePanel, gridBagConstraints);
 
         fragmentPanel.setLayout(new java.awt.CardLayout());
-
         fragmentPanel.add(fragmentPanelCard0, "card0");
 
         fragmentPanelCard1.setLayout(new java.awt.GridBagLayout());
@@ -577,16 +564,15 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         mainPanel.add(fragmentPanel, gridBagConstraints);
 
         locationPanel.setLayout(new java.awt.CardLayout());
-
         locationPanel.add(locationPanelCard0, "card0");
 
         locationPanelCard1.setLayout(new java.awt.GridBagLayout());
 
+        lpanel.setBorder(javax.swing.BorderFactory.createTitledBorder(options.getMsg("edit_mc_location")));
         lpanel.setLayout(new java.awt.GridBagLayout());
 
-        lpanel.setBorder(new javax.swing.border.TitledBorder(options.getMsg("edit_mc_location")));
-        posCellRadio.setText(options.getMsg("edit_mc_pos_cell"));
         posTypes.add(posCellRadio);
+        posCellRadio.setText(options.getMsg("edit_mc_pos_cell"));
         posCellRadio.addActionListener(this);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -595,8 +581,8 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(3, 3, 0, 3);
         lpanel.add(posCellRadio, gridBagConstraints);
 
-        posWindowRadio.setText(options.getMsg("edit_mc_pos_window"));
         posTypes.add(posWindowRadio);
+        posWindowRadio.setText(options.getMsg("edit_mc_pos_window"));
         posWindowRadio.addActionListener(this);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -604,8 +590,8 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
         lpanel.add(posWindowRadio, gridBagConstraints);
 
-        posAbsoluteRadio.setText(options.getMsg("edit_mc_pos_absolute"));
         posTypes.add(posAbsoluteRadio);
+        posAbsoluteRadio.setText(options.getMsg("edit_mc_pos_absolute"));
         posAbsoluteRadio.addActionListener(this);
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
@@ -688,10 +674,10 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         mainPanel.add(locationPanel, gridBagConstraints);
 
         add(mainPanel, java.awt.BorderLayout.CENTER);
-
-    }//GEN-END:initComponents
+    }// </editor-fold>//GEN-END:initComponents
     
     
+    @Override
     public boolean documentChangePerformed(DocumentEvent ev){
         Document doc=ev.getDocument();
         int v=0;
@@ -703,6 +689,7 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
         return false;
     }
     
+    @Override
     public boolean eventPerformed(EventObject ev){
         if(ev!=null && ev.getSource()!=null){
             setInitializing(true);
@@ -994,11 +981,11 @@ public class MediaContentEditor extends edu.xtec.util.CtrlPanel {
     private javax.swing.JTextField yTxt;
     // End of variables declaration//GEN-END:variables
     
-    private static HashMap panels=new HashMap();
+    private static Map<Options, MediaContentEditor> panels=new HashMap<Options, MediaContentEditor>();
     public static MediaContent getMediaContent(MediaContent initialMc, Component parent, Options options, MediaBagEditor mbe){
         MediaContent result=null;
         Messages msg=options.getMessages();
-        MediaContentEditor mce=(MediaContentEditor)panels.get(options);
+        MediaContentEditor mce=panels.get(options);
         if(mce==null){
             mce=new MediaContentEditor(options, initialMc, mbe);
             panels.put(options, mce);
