@@ -21,23 +21,23 @@
 
 package edu.xtec.util;
 
-import javax.swing.*;
-import javax.swing.event.*;
-import javax.swing.tree.*;
+import edu.xtec.jclic.fileSystem.FileSystem;
+import edu.xtec.jclic.misc.Utils;
 import java.awt.Component;
 import java.awt.Dimension;
-import javax.swing.event.ListSelectionListener;
+import java.io.FileOutputStream;
+import java.util.ArrayList;
+import java.util.List;
+import javax.swing.*;
+import javax.swing.event.*;
 import javax.swing.table.AbstractTableModel;
 import javax.swing.table.DefaultTableModel;
-import edu.xtec.jclic.fileSystem.FileSystem;
-import edu.xtec.util.ResourceBridge;
-import edu.xtec.jclic.misc.Utils;
-import java.io.FileOutputStream;
+import javax.swing.tree.*;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.17
  */
 public class JDomTreePanel extends javax.swing.JPanel {
     
@@ -375,15 +375,13 @@ public class JDomTreePanel extends javax.swing.JPanel {
             int r=table.getSelectedRow();
             if(r>=0){
                 if(r==0){
-                    java.util.List ls=current.getElement().getContent();
-                    java.util.Iterator it=ls.iterator();
-                    java.util.Vector v=new java.util.Vector();
-                    while(it.hasNext()){
-                        Object o=it.next();
+                    List<org.jdom.Text> toRemove=new ArrayList<org.jdom.Text>();
+                    List<?> ls=current.getElement().getContent();
+                    for(Object o : ls){
                         if(o instanceof org.jdom.Text)
-                            v.add(o);
+                            toRemove.add((org.jdom.Text)o);
                     }
-                    ls.removeAll(v);
+                    ls.removeAll(toRemove);
                 }
                 else{
                     String s=(String)current.getValueAt(r, 0);
