@@ -23,7 +23,6 @@ package edu.xtec.jclic;
 
 import edu.xtec.jclic.automation.AutoContentProvider;
 import edu.xtec.jclic.bags.MediaBagElement;
-import edu.xtec.jclic.boxes.AbstractBox;
 import edu.xtec.jclic.boxes.ActiveBagContent;
 import edu.xtec.jclic.boxes.ActiveBoxBag;
 import edu.xtec.jclic.boxes.ActiveBoxContent;
@@ -50,13 +49,11 @@ import java.awt.Image;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.RenderingHints;
-import java.awt.Robot;
 import java.awt.event.KeyEvent;
 import java.awt.event.MouseEvent;
-import java.awt.geom.Point2D;
 import java.lang.reflect.Constructor;
-import java.util.HashMap;
 import java.util.Iterator;
+import java.util.Map;
 import java.util.StringTokenizer;
 import javax.swing.BorderFactory;
 import javax.swing.JPanel;
@@ -69,10 +66,10 @@ import javax.swing.border.BevelBorder;
  * responsible of the user interaction with the activity content.
  * Activities should extend both <CODE>Activity</CODE> and
  * <CODE>Activity.Panel</CODE> classes in order to become fully operative.
- * JClic stores activities in memory as {@link org.JDom.Element} objects. So,
+ * JClic stores activities in memory as {@link org.jdom.Element} objects. So,
  * all non-transient data must be stored to and retrieved from JDom elements.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.10
  */
 
 public abstract class Activity extends Object implements Constants, Editable, Domable {
@@ -134,7 +131,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
      */
     public boolean absolutePositioned;
     
-    /** Position of the activity panel into the {@link ActivityContainer}.
+    /** Position of the activity panel into the {@link edu.xtec.jclic.Player}.
      */
     public Point absolutePosition;
     
@@ -144,7 +141,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     public boolean includeInReports=true;
     
     /**
-     * Whether to send action events to the {@link Reporter}.
+     * Whether to send action events to the {@link edu.xtec.jclic.report.Reporter}.
      */
     public boolean reportActions;
     
@@ -166,7 +163,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     
     /**
      * Specific set of {@link EventSounds} used in the activity. The default is <CODE>null</CODE>,
-     * meaning to use the {@link ActivityContainer} sounds.
+     * meaning to use the {@link edu.xtec.jclic.Player} sounds.
      */
     public EventSounds eventSounds=new EventSounds(null);
     
@@ -192,7 +189,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
      */
     public int maxTime;
     /**
-     * Whether the time counter should display a countdown when {@link maxTime} > 0.
+     * Whether the time counter should display a countdown when {@link #maxTime} &gt; 0.
      */
     public boolean countDownTime;
     /**
@@ -201,7 +198,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
      */
     public int maxActions;
     /**
-     * Whether the actions counter should display a countdown when {@link maxActions} > 0.
+     * Whether the actions counter should display a countdown when {@link #maxActions} &gt; 0.
      */
     public boolean countDownActions;
     /**
@@ -288,13 +285,15 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     
     
     // Constants for actions
-    public static final String ACTION_MATCH="MATCH", ACTION_PLACE="PLACE", 
+    public static final String ACTION_MATCH="MATCH", ACTION_PLACE="PLACE",
     ACTION_WRITE="WRITE", ACTION_SELECT="SELECT", ACTION_HELP="HELP";
     
     // Constants for XML fields
     public static final String ELEMENT_NAME="activity", NAME="name";
     public static final String BASE_CLASS="edu.xtec.jclic.activities.", BASE_CLASS_TAG="@";
-    public static final String ID="id", CODE="code", DESCRIPTION="description",
+    // Already defined in edu.xtec.jclic.Constants:
+    // public static final String ID="id", SKIN="skin";
+    public static final String CODE="code", DESCRIPTION="description",
     MESSAGES="messages", TYPE="type",
     //PREVIOUS="previous", INITIAL="initial", FINAL="final", FINAL_ERROR="finalError",
     SETTINGS="settings", LAYOUT="layout", MARGIN="margin",
@@ -307,7 +306,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     GRID="grid", ROW="row", CLUES="clues", CLUE="clue", RANDOM_CHARS="random_chars",
     SCRAMBLE="scramble", TIMES="times", REPORT="report", REPORT_ACTIONS="reportActions",
     HELP_WINDOW="helpWindow", HELP_SHOW_SOLUTION="showSolution", USE_ORDER="useOrder",
-    DRAG_CELLS="dragCells", SKIN="skin", FILE="file",
+    DRAG_CELLS="dragCells", FILE="file",
     MAX_TIME="maxTime", COUNT_DOWN_TIME="countDownTime",
     MAX_ACTIONS="maxActions", COUNT_DOWN_ACTIONS="countDownActions",
     INFO_URL="infoUrl", INFO_CMD="infoCmd";
@@ -372,10 +371,9 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     public String[] getSimilarActivityClasses(){
         String[] result=null;
         String cl=getShortClassName();
-        for(int i=0; i<COMPATIBLE_ACTIVITIES.length; i++){
-            String[] classGroup=COMPATIBLE_ACTIVITIES[i];
-            for(int j=0; j<classGroup.length; j++){
-                if(cl.equals(classGroup[j])){
+        for(String[] classGroup : COMPATIBLE_ACTIVITIES){
+            for(String s : classGroup){
+                if(cl.equals(s)){
                     result=classGroup;
                     break;
                 }
@@ -497,11 +495,10 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     }
     
     public static Activity getActivity(Object o, JClicProject project) throws Exception{
-        Activity act=null;
-        org.jdom.Element e=null;
-        Clic3Activity c3a=null;
+        Activity act;
+        org.jdom.Element e = null;
+        Clic3Activity c3a = null;
         String className;
-        String s;
         
         //if(o.getClass()==org.jdom.Element.class){
         if(o instanceof org.jdom.Element){
@@ -520,9 +517,9 @@ public abstract class Activity extends Object implements Constants, Editable, Do
         else
             throw new Exception("unknown data!!");
         
-        Class activityClass;
-        Constructor con;
-        Class[] cparams={JClicProject.class};
+        Class<?> activityClass;
+        Constructor<?> con;
+        Class<?>[] cparams={JClicProject.class};
         Object[] initArgs={project};
         if(className.startsWith(BASE_CLASS_TAG))
             className=BASE_CLASS+className.substring(1);
@@ -694,7 +691,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
         includeInReports=!c3a.noAv;
         
         if(c3a.custHlp==true && c3a.custHelpFile!=null && c3a.custHelpFile.length()>0){
-            StringBuffer sb=new StringBuffer();
+            StringBuilder sb=new StringBuilder();
             sb.append(c3a.custHelpFile);
             if(c3a.hlpTopic!=null && c3a.hlpTopic.length()>0)
                 sb.append(" ").append(c3a.hlpTopic);
@@ -736,7 +733,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
         }
     }
     
-    public static void listReferences(org.jdom.Element e, HashMap map){
+    public static void listReferences(org.jdom.Element e, Map<String, String> map){
         org.jdom.Element child, child2, child3;
         
         if((child=e.getChild(MESSAGES))!=null){
@@ -783,7 +780,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     }
     
     
-    public static void innerListReferences(org.jdom.Element e, HashMap map){
+    public static void innerListReferences(org.jdom.Element e, Map<String, String> map){
         Iterator it=e.getChildren(ActiveBoxContent.ELEMENT_NAME).iterator();
         while(it.hasNext())
             ActiveBoxContent.listReferences((org.jdom.Element)it.next(), map);
@@ -820,13 +817,13 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     
     public boolean prepareMedia(PlayStation ps){
         if(eventSounds!=null) eventSounds.realize(ps.getOptions(), project.mediaBag);
-        for(int i=0; i<NUM_MSG; i++)
-            if(messages[i]!=null)
-                messages[i].prepareMedia(ps);
+        for(ActiveBoxContent msg : messages)
+            if(msg!=null)
+                msg.prepareMedia(ps);
         if(abc!=null)
-            for(int i=0; i<abc.length; i++)
-                if(abc[i]!=null)
-                    abc[i].prepareMedia(ps);
+            for(ActiveBagContent b : abc)
+                if(b!=null)
+                    b.prepareMedia(ps);
         return true;
     }
     
@@ -864,6 +861,10 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     public boolean shuffleAlways(){
         return false;
     }
+
+    public boolean needsKeyboard(){
+        return false;
+    }
     
     public void end(){
         if(eventSounds!=null){
@@ -876,9 +877,13 @@ public abstract class Activity extends Object implements Constants, Editable, Do
     public void clear(){
     }
     
+    @Override
     public void finalize() throws Throwable{
-        end();
-        super.finalize();
+        try {
+            end();
+        } finally {
+            super.finalize();
+        }
     }
     
     /** Getter for property windowSize.
@@ -906,55 +911,22 @@ public abstract class Activity extends Object implements Constants, Editable, Do
         protected BoxConnector bc=null;
         public PlayStation ps;
         
-        /*
-         *Object that currently has the focus of user interaction
-         */
-        protected Object focusedItem=null;
         
         /** Creates new ActivityPanel */
         protected Panel(PlayStation ps) {
             super();
-            //this.act=act;
-            //ac=act.ac;
             this.ps=ps;
             setMinimumSize(new Dimension(100, 100));
             setPreferredSize(new Dimension(500, 400));
             enableEvents(AWTEvent.MOUSE_EVENT_MASK
             | AWTEvent.MOUSE_MOTION_EVENT_MASK
             | AWTEvent.KEY_EVENT_MASK);
-            //setBorder(javax.swing.BorderFactory.createBevelBorder(javax.swing.border.BevelBorder.RAISED));
             
             // 02-oct-2006: Added a call to initAutoContentProvider
             initAutoContentProvider();
             
-            //setFocusCycleRoot(false);
-            //setFocusTraversalPolicy(ftp);
-            
         }
-        
-        /*
-        FocusTraversalPolicy ftp=new FocusTraversalPolicy(){
-            public Component getComponentAfter(Container focusCycleRoot, Component aComponent){
-                return Panel.this;
-            }
-            public Component getComponentBefore(Container focusCycleRoot, Component aComponent){
-                return Panel.this;
-            }
-            public Component getDefaultComponent(Container focusCycleRoot){
-                return Panel.this;
-            }
-            public Component getFirstComponent(Container focusCycleRoot){
-                return Panel.this;
-            }
-            public Component getInitialComponent(Window window){
-                return Panel.this;
-            }
-            public Component getLastComponent(Container focusCycleRoot){
-                return Panel.this;
-            }
-        };  
-         */
-        
+                
         public Activity getActivity(){
             return Activity.this;
         }
@@ -1044,6 +1016,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
             setBounds(origin.x, origin.y, d.width, d.height);
         }
         
+        @Override
         public void paintComponent(Graphics g){
             Graphics2D g2=(Graphics2D)g;
             RenderingHints rh=g2.getRenderingHints();
@@ -1072,7 +1045,7 @@ public abstract class Activity extends Object implements Constants, Editable, Do
             
             if(bc!=null)
                 bc.end();
-            
+
             if(result){
                 setAndPlayMsg(END, EventSounds.FINISHED_OK);
                 //if(messages[END]==null || messages[END].mediaContent==null)
@@ -1112,8 +1085,13 @@ public abstract class Activity extends Object implements Constants, Editable, Do
         
         public abstract void clear();
         
+        @Override
         public void finalize() throws Throwable{
-            end();
+            try {
+                end();
+            } finally {
+                super.finalize();
+            }            
         }
         
         protected void enableCounters(){
@@ -1130,31 +1108,36 @@ public abstract class Activity extends Object implements Constants, Editable, Do
                 ps.setCountDown(ACTIONS_COUNTER, maxActions);
         }
         
+        @Override
         public void doLayout(){
         }
         
         
         protected void shuffle(ActiveBoxBag[] bg, boolean visible, boolean fitInArea){
-            //int steps=3;
+
             int steps=shuffles;
             
             //if(visible) ac.getComponent().paint(ac.getComponent().getGraphics());
             int i=shuffles;
             while(i>0){
                 int k=i>steps ? steps:i;
-                for(int j=0; j<bg.length; j++)
-                    if(bg[j]!=null)
-                        bg[j].scrambleCells(k, fitInArea);
+                for(ActiveBoxBag abb : bg)
+                    if(abb!=null)
+                        abb.scrambleCells(k, fitInArea);
                 //if(visible) ac.getComponent().paint(ac.getComponent().getGraphics());
                 i-=steps;
             }
         }
         
+        @Override
         protected void processEvent(AWTEvent e){
             if(playing && e instanceof MouseEvent){
                 if(e.getID()==MouseEvent.MOUSE_PRESSED && !hasFocus())
                     requestFocus();
-                if(playing)
+
+                // Modified 05-Aug-2010:
+                // Medium button must not be processed when "fressa" enabled
+                if(e.getID()!=MouseEvent.BUTTON3 || ps.getFressa()==null)
                     processMouse((MouseEvent)e);
             }
             else if(playing && e instanceof KeyEvent)
@@ -1162,53 +1145,32 @@ public abstract class Activity extends Object implements Constants, Editable, Do
             
             super.processEvent(e);
         }
-        
-        /**
-         * Getter for property focusedItem.
-         * @return Value of property focusedItem.
-         */
-        public Object getFocusedItem() {
-            return focusedItem;
-        }
-        
-        /**
-         * Setter for property focusedItem.
-         * @param focusedItem New value of property focusedItem.
-         */
-        public void setFocusedItem(Object focusedItem) {
-            unmarkFocusedItem();
-            this.focusedItem = focusedItem;
-            if(this.focusedItem!=null && focusedItem instanceof AbstractBox && ps.isFocusedItemMarked()){
-                AbstractBox bx=(AbstractBox)focusedItem;
-                bx.setFocused(true);                                
-                Robot robot=ps.getRobot();
-                if(robot!=null){
-                    Point2D pt=bx.getAbsoulteMiddleLocation();
-                    if(pt!=null){
-                        robot.mouseMove((int)pt.getX(), (int)pt.getY());
-                    }
-                }
-            }            
-        }
-        
-        /* Removes the visual marker of the currently focused item
-         */
-        public void unmarkFocusedItem(){
-            if(focusedItem!=null && focusedItem instanceof AbstractBox && ps.isFocusedItemMarked()){
-                ((AbstractBox)focusedItem).setFocused(false);                
+
+
+        public void calcScanPoints(){
+            if(ps.getFressa()!=null){
+                ps.getFressa().calcScanPoints();
             }
         }
-                
-        /* Moves the internal focus of user's interaction to the next element.
-         * default implementation does nothing.
-         * @return Object focused when the operation completes, or <CODE>null</CODE> if
-         * there are no more objects to be focused.
-         */
-        public Object nextFocusedItem(){
-            setFocusedItem(null);
-            return focusedItem;
+
+        public void calcInactivePoints(){
+            // does nothing by default
         }
-        
+
+        public void nextScanPosition() {
+            if(ps.getFressa()!=null){
+                ps.getFressa().nextScanPosition();
+            }
+        }
+
+        public void clickLeftButton(){
+            if(ps.getFressa()!=null){
+                ps.getFressa().clickLeftButton();
+                if(ps.getFressa().jumpWellPlaced)
+                    calcInactivePoints();
+            }
+        }
+
     }
     
 }
