@@ -44,13 +44,11 @@ import edu.xtec.jclic.report.Reporter;
 import edu.xtec.jclic.skins.AboutWindow;
 import edu.xtec.jclic.skins.Skin;
 import edu.xtec.util.BrowserLauncher;
-import edu.xtec.util.FontCheck;
 import edu.xtec.util.Html;
 import edu.xtec.util.Messages;
 import edu.xtec.util.Options;
 import edu.xtec.util.ResourceManager;
 import edu.xtec.util.StrUtils;
-import edu.xtec.util.SwingWorker;
 import java.applet.Applet;
 import java.awt.Color;
 import java.awt.Component;
@@ -58,7 +56,6 @@ import java.awt.Container;
 import java.awt.Cursor;
 import java.awt.Dialog;
 import java.awt.Dimension;
-import java.awt.Font;
 import java.awt.Frame;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
@@ -66,7 +63,6 @@ import java.awt.Image;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.RenderingHints;
-import java.awt.Robot;
 import java.awt.Toolkit;
 import java.awt.Window;
 import java.awt.event.ActionEvent;
@@ -77,8 +73,9 @@ import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.InputStream;
 import java.net.URL;
+import java.util.ArrayList;
+import java.util.List;
 import java.util.Locale;
-import java.util.Vector;
 import javax.swing.AbstractAction;
 import javax.swing.Action;
 import javax.swing.Icon;
@@ -101,8 +98,8 @@ import javax.swing.Timer;
  * display of system messages, etc.
  * Player is also a {@link edu.xtec.jclic.RunnableComponent}, so it can be
  * embedded in applets, frames and other containers.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.10
  */
 public class Player extends JPanel implements Constants, RunnableComponent, PlayStation, ActionListener {
     
@@ -126,13 +123,15 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
      */
     public static final String[] DEFAULT_EVENT_SOUNDS={
         
-        // MP3
-        /*START*/ "sounds/start.mp3",
-        /*CLICK*/ "sounds/click.mp3",
-        /*ACTION_ERROR*/ "sounds/action_error.mp3",
-        /*ACTION_OK*/ "sounds/action_ok.mp3",
-        /*FINISHED_ERROR*/ "sounds/finished_error.mp3",
-        /*FINISHED_OK*/ "sounds/finished_ok.mp3"
+        //
+        // CHANGED 01-Mar-2013: Use sounds in WAV format to avoid openJDK errors
+        //
+        /*START*/ "sounds/start.wav",
+        /*CLICK*/ "sounds/click.wav",
+        /*ACTION_ERROR*/ "sounds/action_error.wav",
+        /*ACTION_OK*/ "sounds/action_ok.wav",
+        /*FINISHED_ERROR*/ "sounds/finished_error.wav",
+        /*FINISHED_OK*/ "sounds/finished_ok.wav"
         
     };
     
@@ -167,8 +166,8 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
     protected Messages messages;
     
     /**
-     * The {@link edu.xtec.jclic.JClicProject} currently hosted by the
-     * <CODE>Player</CODE>.
+     * The {@link edu.xtec.jclic.project.JClicProject} currently hosted by the
+     * {@code Player}.
      */
     protected JClicProject project;
     
@@ -246,16 +245,6 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
      */
     protected String appName=DEFAULT_APP_NAME;
     
-    /**
-     * Determines if focused items of activities must be visually marked or not.
-     */
-    protected boolean focusedItemMarked=false;
-    
-    /**
-     * Object used for simulating mouse movements and keystrokes
-     */
-    protected Robot robot=null;
-    
     Timer delayedTimer;
     Action delayedAction;
     Object currentConstraints;
@@ -264,7 +253,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
     Options options;
     Image splashImg;
     Point bgImageOrigin=new Point();
-    private SwingWorker worker=null;
+    private edu.xtec.util.SwingWorker worker=null;
     
     /**
      * Creates a new <CODE>Player</CODE> object.
@@ -284,17 +273,6 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         this.options=options;
         this.project=project;
         init();
-
-        // TODO: Build robot and determine if focused items should be marked
-        /*
-        setFocusedItemMarked(true);
-        try{
-            robot=new Robot();
-        } catch(Exception ex){
-            System.err.println("Unable to create Robot");
-        }
-        */
-        
     }
     
     /**
@@ -337,7 +315,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
     }
     
     /**
-     * Starts off the player, loading a specific project if specified. This
+     * Starts the player, loading a specific project if specified. This
      * method is defined in the {@link RunnableComponent} interface.
      * @param fullPath Full path to the JClic project file to be loaded. Can be
      * <I>null</I>.
@@ -360,7 +338,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
     
     /**
      * This method is called when the container gains the focus for the first
-     * time or after have lost it. Not used in <CODE>Player</CODE>.
+     * time or when losts it. Not used in <CODE>Player</CODE>.
      */
     public void activate() {
     }
@@ -376,9 +354,13 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
      *
      * @throws Throwable
      */
+    @Override
     protected void finalize() throws Throwable {
-        end();
-        super.finalize();
+        try {
+            end();
+        } finally {
+            super.finalize();
+        }
     }
     
     /**
@@ -637,11 +619,12 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
             return;
         }
         
-        worker=new SwingWorker(){
+        worker=new edu.xtec.util.SwingWorker(){
             Activity.Panel actp;
             Exception exception=null;
             Player thisPlayer=Player.this;
             
+            @Override
             public Object construct(){
                 
                 if(skin!=null)
@@ -669,8 +652,14 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                             fullPath=fileSystem.getUrl(fullPath);
                             if(fullPath.startsWith("file://"))
                                 fullPath=fullPath.substring(7);
+                            // Added 03-Feb-2011
+                            // Remove trailing parameters of URLs
+                            else if(fullPath.indexOf('?')>0)
+                                fullPath=fullPath.substring(0, fullPath.indexOf('?'));
+                            // ----------
                         }
-                        String projectName=null;
+
+                        String projectName;
                         if(fullPath.endsWith(".jclic.zip")){
                             fileSystem=FileSystem.createFileSystem(fullPath, thisPlayer);
                             String[] projects=((ZipFileSystem)fileSystem).getEntries(".jclic");
@@ -772,7 +761,8 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                         project.mediaBag.waitForAllImages();
                         act.prepareMedia(thisPlayer);
                         activeMediaBag.realizeAll();
-                        project.activitySequence.checkCurrentActivity(abe.getName());
+                        if(abe!=null)
+                            project.activitySequence.checkCurrentActivity(abe.getName());
                         setSystemMessage(null, messages.get("msg_initializing"));
                         actp=act.getActivityPanel(thisPlayer);
                         actp.buildVisualComponents();
@@ -782,12 +772,13 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                     exception=ex;
                     if(project==null)
                         setProject(null);
-                    act=null;
+                    //act=null;
                     actp=null;
                 }
                 return actp;
             }
             
+            @Override
             public void finished(){
                 
                 setWaitCursor(false);
@@ -830,7 +821,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                             actions[ACTION_PREV].setEnabled((navBtnFlag & ActivitySequenceElement.NAV_BACK)!=0
                             && project.activitySequence.hasPrevAct(hasReturn));
                             actions[ACTION_RETURN].setEnabled(history.storedElementsCount()>0);
-                            actions[ACTION_HELP].setEnabled(actp.getActivity().helpWindowAllowed());
+                            actions[ACTION_HLP].setEnabled(actp.getActivity().helpWindowAllowed());
                             actions[ACTION_RESET].setEnabled(actp.getActivity().canReinit());
                             actions[ACTION_INFO].setEnabled(actp.getActivity().hasInfo());
                         }
@@ -841,7 +832,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                 }
                 else if(exception!=null){
                     String sType=null;
-                    Vector v=new Vector();
+                    List<Object> v=new ArrayList<Object>();
                     if(sFullPath!=null){
                         v.add(sFullPath);
                         sType="msg_error_loading_project";
@@ -938,6 +929,8 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                 timer.start();
                 if(!actPanel.getActivity().mustPauseSequence())
                     startAutoPassTimer();
+                if(getFressa()!=null)
+                    getFressa().initActivity(actPanel);
                 setSystemMessage(messages.get("msg_activity_running"), null);
             }
             if(skin!=null)
@@ -966,6 +959,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         }
     }
     
+    @Override
     public void doLayout(){
         if(trace)
             System.out.println(">>> layout!");
@@ -990,6 +984,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         }
     }
     
+    @Override
     public void paintComponent(Graphics g){
         Graphics2D g2=(Graphics2D)g;
         
@@ -1097,7 +1092,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
             }
         };
         
-        actions[ACTION_HELP]=new AbstractAction(){
+        actions[ACTION_HLP]=new AbstractAction(){
             public void actionPerformed(ActionEvent ev){
                 if(actPanel!=null)
                     actPanel.showHelp();
@@ -1144,8 +1139,8 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         };
         actions[ACTION_AUDIO].putValue(AbstractAction.DEFAULT, audioEnabled ? Boolean.TRUE : Boolean.FALSE);
         
-        for(int i=0; i<DYNAMIC_ACTIONS.length; i++){
-            actions[DYNAMIC_ACTIONS[i]].setEnabled(false);
+        for(int dynAct : DYNAMIC_ACTIONS){
+            actions[dynAct].setEnabled(false);
         }
         actions[ACTION_AUDIO].setEnabled(true);
     }
@@ -1232,7 +1227,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                 "about_window_systemInfo",
                 "about_window_lb_system", "icons/system_small.gif");
                 if(project!=null){
-                    StringBuffer sb=new StringBuffer(4096);
+                    StringBuilder sb=new StringBuilder(4096);
                     sb.append(project.settings.toHtmlString(messages));
                     if(actPanel!=null){
                         sb.append(Html.BR).append(actPanel.getActivity().toHtmlString(this));
@@ -1261,7 +1256,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         SwingUtilities.invokeLater(new Runnable(){
             public void run(){
                 String s=mediaContent.mediaFileName;
-                JumpInfo ji=null;
+                JumpInfo ji;
                 
                 switch(mediaContent.mediaType){
                     case MediaContent.RUN_CLIC_PACKAGE:
@@ -1290,7 +1285,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                         break;
                     case MediaContent.RUN_EXTERNAL:
                         if(mediaContent.mediaFileName!=null){
-                            StringBuffer sb=new StringBuffer(mediaContent.mediaFileName);
+                            StringBuilder sb=new StringBuilder(mediaContent.mediaFileName);
                             if(mediaContent.externalParam!=null)
                                 sb.append(" ").append(mediaContent.externalParam);
                             runCmd(sb.substring(0));
@@ -1344,6 +1339,10 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
     
     public void activityFinished(boolean completedOk) {
         closeHelpWindow();
+
+        if(getFressa()!=null)
+            getFressa().activityFinished();
+
         if(completedOk){
             setCursor(getCustomCursor(OK_CURSOR));
             actPanel.setCursor(null);
@@ -1392,7 +1391,19 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         if(counterId==ACTIONS_COUNTER && actPanel!=null
         && actPanel.getActivity().maxActions>0 && actPanel.isPlaying()
         && counterVal[ACTIONS_COUNTER]>=actPanel.getActivity().maxActions){
-            actPanel.finishActivity(false);
+            // 14-Mai-2010
+            // Correction of bug 1249: Incorrect reporting of activity results when maximum number of attempts achieved
+            // actPanel.finishActivity must be called when the action
+            // has been completely processed.
+            // The "solved" status should not be supposed to be always "false"
+
+            //actPanel.finishActivity(false);
+            SwingUtilities.invokeLater(
+              new Runnable(){
+                public void run(){
+                    actPanel.finishActivity(actPanel.solved);
+                }
+            });
         }
     }
     
@@ -1527,7 +1538,11 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         if(url==null) return;
         Applet applet=options.getApplet();
         try{
-            if(applet!=null){
+            // Modified 21-Feb-2011
+            // getAppletContext().showDocument seems not working on a Mac
+            // (tested with Firefox and Safari)
+            // Instead, launch a new browser:
+            if(applet!=null && !options.getBoolean(Options.MAC)){
                 if(inFrame){
                     String frame=(String)options.get(INFO_URL_FRAME);
                     if(frame==null)
@@ -1574,6 +1589,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         });
     }
     
+    @Override
     public void requestFocus(){
         if(actPanel!=null)
             actPanel.requestFocus();
@@ -1597,7 +1613,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                     load(param1, param2);
                 }
             });
-            result=true;;
+            result=true;
         }
         return result;
     }
@@ -1609,7 +1625,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
     public void setWindowTitle(String docTitle){
         Window w=Options.getWindowForComponent(this);
         if(w!=null){
-            StringBuffer sb=new StringBuffer();
+            StringBuilder sb=new StringBuilder();
             String s=StrUtils.nullableString(docTitle);
             if(s!=null)
                 sb.append(s).append(" - ");
@@ -1622,7 +1638,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
     }
     
     public void setWindowTitle(){
-        StringBuffer sb=new StringBuffer();
+        StringBuilder sb=new StringBuilder();
         String prjName=project==null ? null : StrUtils.nullableString(project.getPublicName());
         String actName=actPanel==null ? null : StrUtils.nullableString(actPanel.getActivity().getPublicName());
         if(actName!=null){
@@ -1636,30 +1652,17 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                 sb.append("]");
         }
         setWindowTitle(sb.substring(0));
-    }
+    }    
     
     /**
-     * Getter for property focusedItemsMarked.
-     * @return Value of property focusedItemsMarked.
+     * FressaFunctions offers special accessibility features
+     * like atomatic scanning and voice synthesis.
+     * @return The FressaFunctions object, or <CODE>null</CODE> if accessibility features are not enabled
      */
-    public boolean isFocusedItemMarked() {
-        return focusedItemMarked;
-    }
-    
-    /**
-     * Setter for property focusedItemsMarked.
-     * @param focusedItemsMarked New value of property focusedItemsMarked.
-     */
-    public void setFocusedItemMarked(boolean focusedItemMarked) {
-        this.focusedItemMarked = focusedItemMarked;
-    }
-    
-    /**
-     * Getter for property robot.
-     * @return Value of property robot.
-     */
-    public Robot getRobot() {
-        return robot;
+    public edu.xtec.jclic.accessibility.FressaFunctions getFressa(){
+        return null;
     }
+
+
        
 }
