@@ -39,8 +39,8 @@ import java.util.Random;
  * also the operation itself (like A ? B = C).
  * Activities must implement {@link edu.xtec.jclic.automation.ActiveBagContentKit.Compatible}
  * in order to use <CODE>Arith</CODE>.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.28
  */
 public class Arith extends AutoContentProvider {
     
@@ -63,7 +63,7 @@ public class Arith extends AutoContentProvider {
     private static final int RES=-12345;
     private static final int MAX_STR_LEN=100;
     
-    private static String S=new String("\u00A0");
+    private static String S="\u00A0";
     
     protected class Num {
         float vf;
@@ -124,6 +124,7 @@ public class Arith extends AutoContentProvider {
         return DF[index<=WILDCARD_DF ? index : WILDCARD_DF-1];
     }
     
+    @Override
     public org.jdom.Element getJDomElement() {
         
         org.jdom.Element e=super.getJDomElement();
@@ -204,12 +205,13 @@ public class Arith extends AutoContentProvider {
         }
     }
     
+    @Override
     public boolean setClic3Properties(byte[] ops) {
         int v;
         int i, lb, hb;
         boolean fromBlank=false;
         int p=0;
-        int arithVer=0;
+        int arithVer;
         
         p=opA.setClic3Properties(ops, p);
         
@@ -264,7 +266,7 @@ public class Arith extends AutoContentProvider {
     boolean genNum(Num n, Operator op, long limInf2, long limSup2){
         int r, exp, rang;
         long ls, li, k, v;
-        boolean resolt=false;
+        boolean resolt;
         
         n.c=op.numDec;
         exp= n.c==0 ? 1 : n.c==1 ? 10 : 100;
@@ -307,7 +309,7 @@ public class Arith extends AutoContentProvider {
             if (exp>1)
                 v+=random.nextInt(exp);
             n.vf=((float)v)/exp;
-            resolt=true;
+            //resolt=true;
         }
         return true;
     }
@@ -597,41 +599,41 @@ public class Arith extends AutoContentProvider {
             operator=OPSTR[op[i].op];
             
             if(tipInv)
-                strc[i]=new String(vc + S + "=" + S + va + S + operator + S + vb);
+                strc[i]=vc + S + "=" + S + va + S + operator + S + vb;
             else
-                strc[i]=new String(va + S + operator + S + vb + S + "=" + S + vc);
+                strc[i]=va + S + operator + S + vb + S + "=" + S + vc;
             
             switch(tipX){
                 case AXC:
-                    strb[i]=new String(vb);
+                    strb[i]=vb;
                     if(tipInv)
-                        stra[i]=new String(vc + S + "=" + S + va + S + operator + S + "?");
+                        stra[i]=vc + S + "=" + S + va + S + operator + S + "?";
                     else
-                        stra[i]=new String(va + S + operator + S + "?" + S + "=" + S + vc);
+                        stra[i]=va + S + operator + S + "?" + S + "=" + S + vc;
                     break;
                     
                 case XBC:
-                    strb[i]=new String(va);
+                    strb[i]=va;
                     if(tipInv)
-                        stra[i]=new String(vc + S + "=" + S + "?" + S + operator + S + vb);
+                        stra[i]=vc + S + "=" + S + "?" + S + operator + S + vb;
                     else
-                        stra[i]=new String("?" + S + operator + S + vb + S + "=" + S + vc);
+                        stra[i]="?" + S + operator + S + vb + S + "=" + S + vc;
                     break;
                     
                 case AXBC:
-                    strb[i]=new String(operator);
+                    strb[i]=operator;
                     if(tipInv)
-                        stra[i]=new String(vc + S + "=" + S + va + S + "?" + S + vb);
+                        stra[i]=vc + S + "=" + S + va + S + "?" + S + vb;
                     else
-                        stra[i]=new String(va + S + "?" + S + vb + S + "=" + S + vc);
+                        stra[i]=va + S + "?" + S + vb + S + "=" + S + vc;
                     break;
                     
                 default:
-                    strb[i]=new String(vc);
+                    strb[i]=vc;
                     if(tipInv)
-                        stra[i]=new String("?" + S + "=" + S + va + S + operator + S + vb);
+                        stra[i]="?" + S + "=" + S + va + S + operator + S + vb;
                     else
-                        stra[i]=new String(va + S + operator + S + vb + S + "=");
+                        stra[i]=va + S + operator + S + vb + S + "=";
                     break;
             }
             
