@@ -32,25 +32,27 @@ import edu.xtec.util.ExtendedByteArrayInputStream;
 import edu.xtec.util.FontCheck;
 import edu.xtec.util.JDomUtility;
 import edu.xtec.util.StreamIO;
-import java.awt.Font;
 import java.io.InputStream;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
-import java.util.Vector;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
 
 
 /**
  * This class stores and manages all the media components (images, sounds, animations,
  * video, MIDI files, etc.) needed to run the activities of a
  * {@link edu.xtec.jclic.project.JClicProject}. The main member of the class is a
- * {@link java.util.Vector} that stores {@link edu.xtec.jclic.bags.MediaBagElement}
+ * {@link java.util.ArrayList} that stores {@link edu.xtec.jclic.bags.MediaBagElement}
  * objects. It defines also a {@link edu.xtec.jclic.bags.MediaBag.Listener} interface
  * to allow other objects to be informed about changes in the media collection.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.10
  */
 public class MediaBag extends Object implements Editable, Domable, StreamIO.InputStreamProvider {
     
@@ -59,17 +61,17 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
      */    
     protected JClicProject project;
     /**
-     * Vector containing all the {@link edu.xtec.jclic.bags.MediaBagElement} objects of
+     * List containing all the {@link edu.xtec.jclic.bags.MediaBagElement} objects of
      * this <CODE>MediaBag</CODE>.
      */    
-    protected Vector elements;
-    protected HashSet listeners;
+    protected List<MediaBagElement> elements;
+    protected Set<Listener> listeners;
     
     /** Creates new MediaBag */
     public MediaBag(JClicProject project) {
         this.project=project;
-        elements=new Vector(30);
-        listeners=new HashSet(1);
+        elements=new ArrayList<MediaBagElement>(30);
+        listeners=new HashSet<Listener>(1);
     }
     
     public JClicProject getProject(){
@@ -78,43 +80,44 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
     
     public static String ELEMENT_NAME="mediaBag";
     
-    public Vector getElements(){
-        return new Vector(elements);
+    /**
+     * Provides a copy of the elements List
+     * @return a List (currently an ArrayList) of the elements
+     */
+    public List<MediaBagElement> getElements(){
+        return new ArrayList<MediaBagElement>(elements);
     }
     
     public void clear(){
         elements.clear();
     }
     
-    public Vector getElementsByName(){
-        Vector v=getElements();
-        Collections.sort(v, new Comparator(){
-            public int compare(Object o1, Object o2){
-                return ((MediaBagElement)o1).getName().compareToIgnoreCase(((MediaBagElement)o2).getName());
+    public List<MediaBagElement> getElementsByName(){
+        List<MediaBagElement> v=getElements();
+        Collections.sort(v, new Comparator<MediaBagElement>(){
+            public int compare(MediaBagElement o1, MediaBagElement o2){
+                return o1.getName().compareToIgnoreCase(o2.getName());
             }
         });
         return v;
     }
     
-    public Vector getElementsByType(){
-        final StringBuffer sb1=new StringBuffer(200);
-        final StringBuffer sb2=new StringBuffer(200);
-        Vector v=getElements();
-        Collections.sort(v, new Comparator(){
-            public int compare(Object o1, Object o2){
-                
+    public List<MediaBagElement> getElementsByType(){
+        final StringBuilder sb1=new StringBuilder(200);
+        final StringBuilder sb2=new StringBuilder(200);
+        List<MediaBagElement> v=getElements();
+        Collections.sort(v, new Comparator<MediaBagElement>(){
+            public int compare(MediaBagElement o1, MediaBagElement o2){                
                 sb1.setLength(0);
-                MediaBagElement mbe=(MediaBagElement)o1;
-                String fName=mbe.getFileName();
-                String name=mbe.getName();
+                String fName=o1.getFileName();
+                String name=o1.getName();
                 int dot=fName.lastIndexOf('.');
                 sb1.append(dot>0 ? fName.substring(dot) : ".zzz");
                 sb1.append(name);
                 
                 sb2.setLength(0);
-                mbe=(MediaBagElement)o2;
-                fName=mbe.getFileName();
-                name=mbe.getName();
+                fName=o2.getFileName();
+                name=o2.getName();
                 dot=fName.lastIndexOf('.');
                 sb2.append(dot>0 ? fName.substring(dot) : ".zzz");
                 sb2.append(name);
@@ -127,19 +130,16 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
     
     public org.jdom.Element getJDomElement(){
         org.jdom.Element e=new org.jdom.Element(ELEMENT_NAME);
-        org.jdom.Element child;
-        Iterator it=getElementsByType().iterator();
-        while(it.hasNext()){
-            e.addContent(((MediaBagElement)it.next()).getJDomElement());
-        }
+        Iterator<MediaBagElement> it=getElementsByType().iterator();
+        while(it.hasNext())
+            e.addContent(it.next().getJDomElement());
         return e;
     }
     
     public void clearData(){
-        Iterator it=elements.iterator();
-        while(it.hasNext()){
-            ((MediaBagElement)it.next()).clearData();
-        }
+        Iterator<MediaBagElement> it=elements.iterator();
+        while(it.hasNext())
+            it.next().clearData();
     }
     
     public void setProperties(org.jdom.Element e, Object aux) throws Exception{
@@ -161,7 +161,7 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
         MediaBagElement result=null;
         if(name!=null){
             for(int i=0; i<elements.size(); i++){
-                MediaBagElement mbe=(MediaBagElement)elements.get(i);
+                MediaBagElement mbe=elements.get(i);
                 if(name.equals(mbe.getName())){
                     result=mbe;
                     break;
@@ -175,7 +175,7 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
         MediaBagElement result=null;
         if(fileName!=null){
             for(int i=0; i<elements.size(); i++){
-                MediaBagElement mbe=(MediaBagElement)elements.get(i);
+                MediaBagElement mbe=elements.get(i);
                 if(fileName.equals(mbe.getFileName())){
                     result=mbe;
                     break;
@@ -237,7 +237,7 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
     }
     
     public MediaBagElement getImageElement(String name) throws Exception{
-        MediaBagElement result=null;
+        MediaBagElement result;
         String normalizedName=project.getFileSystem().getCanonicalNameOf(name);
         result=registerElement(normalizedName, null);
         if(result!=null)
@@ -248,67 +248,38 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
     public void buildFonts() {
         
         // count currently empty font elements
-        HashMap fonts=new HashMap();
-        Iterator it=elements.iterator();
+        Map<String,MediaBagElement> fonts=new HashMap<String,MediaBagElement>();
+        Iterator<MediaBagElement> it=elements.iterator();
         while(it.hasNext()){
-            MediaBagElement mbe=(MediaBagElement)it.next();
+            MediaBagElement mbe=it.next();
             String name=mbe.getName();
-            if(mbe!=null && mbe.getData()==null && mbe.getFileName().endsWith(".ttf")){
+            if(name!=null && mbe.getData()==null && mbe.getFileName().endsWith(".ttf")){
                 fonts.put(name, mbe);
             }
         }
         if(!fonts.isEmpty()){
-            //String[] fontList=GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames();
             String[] fontList=FontCheck.getFontList(false);
             int nFontsList=fontList.length;
-            it=fonts.keySet().iterator();
-            while(it.hasNext()){
-                String name=(String)it.next();
+            Iterator<String> itf=fonts.keySet().iterator();
+            while(itf.hasNext()){
+                String name=itf.next();
                 int i=0;
-                for(i=0; i<nFontsList; i++)
+                for(; i<nFontsList; i++)
                     if(fontList[i].equalsIgnoreCase(name))
                         break;
                 if(i==nFontsList){
-                    MediaBagElement mbe=(MediaBagElement)fonts.get(name);
+                    MediaBagElement mbe=fonts.get(name);
                     try{
                         mbe.setData(FontCheck.buildNewFont(mbe.getFileName(), this, name));
                     } catch(Exception ex){
                         System.err.println("Unable to create font:\n"+ex);
                     }
-                    /*
-                    // code adapted from java.awt.Font
-                    try{
-                        String tmpDir=System.getProperty("java.io.tmpdir");
-                        if(tmpDir==null){
-                            System.err.println("Unable to create fonts: Unknown temp dir");
-                            return;
-                        }
-                        File fontFile=new File(tmpDir+File.separator+TMP_FONT_PREFIX+mbe.getFileName());
-                        if(!fontFile.exists()){
-                            StreamIO.writeStreamToFile(getInputStream(name), fontFile);
-                        }
-                        sun.java2d.SunGraphicsEnvironment env =
-                        (sun.java2d.SunGraphicsEnvironment)GraphicsEnvironment
-                        .getLocalGraphicsEnvironment();
-                        String createName = env.createFont(fontFile);
-                        if(createName == null) {
-                            System.err.println("Unable to create font - bad font data");
-                            return;
-                        }
-                        Font fnt=new Font(createName, Font.PLAIN, 1);
-                        mbe.setData(fnt);
-                    } catch(Exception ex){
-                        System.err.println("Unable to create font:\n"+ex);
-                    }
-                     */
                 }
             }
         }
     }
     
     public Skin getSkinElement(String name, PlayStation ps){
-        Skin sk=null;
-        String normalizedName=name;
         if(name.startsWith(Skin.INTERNAL_SKIN_PREFIX)){
             try{
                 return Skin.getSkin(name, project.getFileSystem(), ps);
@@ -318,12 +289,12 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
             }
         }
         else{
-            normalizedName=project.getFileSystem().getCanonicalNameOf(name);
+            String normalizedName=project.getFileSystem().getCanonicalNameOf(name);
             MediaBagElement mbe=registerElement(normalizedName, null);
             if(mbe!=null){
                 if(mbe.getData()==null || !(mbe.getData() instanceof Skin)){
                     try{
-                        sk=Skin.getSkin(mbe.getFileName(), project.getFileSystem(), ps);
+                        Skin sk=Skin.getSkin(mbe.getFileName(), project.getFileSystem(), ps);
                         mbe.setData(sk);
                     }
                     catch(Exception e){
@@ -337,9 +308,9 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
     }
     
     public boolean isWaitingForImages(){
-        Iterator it=elements.iterator();
+        Iterator<MediaBagElement> it=elements.iterator();
         while(it.hasNext()){
-            MediaBagElement mbe=(MediaBagElement)it.next();
+            MediaBagElement mbe=it.next();
             if(mbe!=null && mbe.isWaitingForImage())
                 return true;
         }
@@ -349,7 +320,7 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
     public void waitForAllImages(){
         while(isWaitingForImages()){
             try{
-                Thread.currentThread().sleep(100);
+                Thread.sleep(100);
             } catch(Exception ex){
                 System.err.println("error waiting for images!\n"+ex);
                 return;
@@ -362,8 +333,8 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
     }
     
     public interface Listener{
-        public void listReferences(String type, HashMap map);
-        public void listReferencesTo(String name, String type, HashMap map);
+        public void listReferences(String type, Map<String, String> map);
+        public void listReferencesTo(String name, String type, Map<String, String> map);
     }
     
     public void addListener(Listener lst){
@@ -375,10 +346,10 @@ public class MediaBag extends Object implements Editable, Domable, StreamIO.Inpu
         listeners.remove(lst);
     }
     
-    public void listReferencesTo(String name, String type, HashMap map){
-        Iterator it=listeners.iterator();
+    public void listReferencesTo(String name, String type, Map<String, String> map){
+        Iterator<Listener> it=listeners.iterator();
         while(it.hasNext())
-            ((Listener)it.next()).listReferencesTo(name, type, map);
+            it.next().listReferencesTo(name, type, map);
     }
     
 }
\ No newline at end of file
