@@ -24,17 +24,16 @@ package edu.xtec.jclic.bags;
 import edu.xtec.jclic.edit.Editable;
 import edu.xtec.jclic.edit.Editor;
 import edu.xtec.jclic.fileSystem.FileSystem;
-//import edu.xtec.jclic.misc.Bmp;
-import net.sf.image4j.codec.bmp.BMPDecoder;
-import net.sf.image4j.codec.ico.ICODecoder;
 import edu.xtec.jclic.misc.Utils;
 import edu.xtec.util.Domable;
 import edu.xtec.util.JDomUtility;
 import java.awt.Image;
 import java.awt.Toolkit;
-import java.awt.image.ImageObserver;
 import java.awt.image.BufferedImage;
+import java.awt.image.ImageObserver;
 import javax.swing.ImageIcon;
+import net.sf.image4j.codec.bmp.BMPDecoder;
+import net.sf.image4j.codec.ico.ICODecoder;
 
 
 /**
@@ -44,8 +43,8 @@ import javax.swing.ImageIcon;
  * the media. They have also a flag indicating if the data must be saved into the
  * {@link edu.xtec.jclic.project.JClicProject} file or must be mantained as a single
  * reference to a external file.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.28
  */
 public class MediaBagElement extends Object implements Editable, Domable, Comparable{
     
@@ -58,6 +57,10 @@ public class MediaBagElement extends Object implements Editable, Domable, Compar
     public boolean animated;
     private boolean hasThumb;
     
+    // 10-Aug-2015
+    // Added to allow renaming of media files
+    private String metadata;
+    
     /** Creates new MediaBagElement */
     
     public MediaBagElement(String fileName) {
@@ -78,7 +81,7 @@ public class MediaBagElement extends Object implements Editable, Domable, Compar
     }
     
     public static final String ELEMENT_NAME="media";
-    public static final String FILE="file", NAME="name", SAVE="save", USAGE="usage";
+    public static final String FILE="file", NAME="name", SAVE="save", USAGE="usage", ANIMATED="animated";
     
     public org.jdom.Element getJDomElement(){
         org.jdom.Element e=new org.jdom.Element(ELEMENT_NAME);
@@ -88,6 +91,8 @@ public class MediaBagElement extends Object implements Editable, Domable, Compar
             e.setAttribute(SAVE, JDomUtility.BOOL_STR[JDomUtility.FALSE]);
         if(usageCount>0)
             e.setAttribute(USAGE, Integer.toString(usageCount));
+        if(animated)
+            e.setAttribute(ANIMATED, JDomUtility.BOOL_STR[JDomUtility.TRUE]);
         return e;
     }
     
@@ -103,6 +108,7 @@ public class MediaBagElement extends Object implements Editable, Domable, Compar
         setFileName(JDomUtility.getStringAttr(e, FILE, fileName, false));
         saveFlag=JDomUtility.getBoolAttr(e, SAVE, true);
         usageCount=JDomUtility.getIntAttr(e, USAGE, usageCount);        
+        animated=JDomUtility.getBoolAttr(e, ANIMATED, false);
     }
     
     public Editor getEditor(Editor parent) {
@@ -123,13 +129,22 @@ public class MediaBagElement extends Object implements Editable, Domable, Compar
         return fileName;
     }
     
+    public void setMetaData(String meta){
+        metadata=meta;
+    }
+    
+    public String getMetaData(){
+        return metadata;
+    }
+    
     public boolean isImage(){
         return Utils.getFileType(fileName)==Utils.TYPE_IMAGE;        
     }
     
     public void setData(Object sData){
         data=sData;
-        animated=false;
+     // CHANGED: 28/Apr/2016 - Don't clear animated flag!
+     // animated=false;
         if(data!=null && data instanceof Image)
             Toolkit.getDefaultToolkit().prepareImage((Image)data, -1, -1, null);
     }
@@ -162,6 +177,7 @@ public class MediaBagElement extends Object implements Editable, Domable, Compar
         return usageCount<=0;
     }
     
+    @Override
     protected void finalize() throws Throwable{
         Image img=getImage();
         if(img!=null)
@@ -197,7 +213,8 @@ public class MediaBagElement extends Object implements Editable, Domable, Compar
                             maxs=s;
                         }
                     }                    
-                    setData(Toolkit.getDefaultToolkit().createImage(img.getSource()));                    
+                    if(img!=null)
+                        setData(Toolkit.getDefaultToolkit().createImage(img.getSource()));                    
                 }
                 else
                     setData(fs.getImageFile(fileName));
@@ -223,7 +240,7 @@ public class MediaBagElement extends Object implements Editable, Domable, Compar
                 }
                 else if((imgStatus & imgReadyFlag)==imgReadyFlag)
                     break;
-                Thread.currentThread().sleep(50);
+                Thread.sleep(50);
             }
         
         if(data!=null && (imgStatus & ImageObserver.FRAMEBITS)!=0)
@@ -287,10 +304,11 @@ public class MediaBagElement extends Object implements Editable, Domable, Compar
      * @param name New value of property name.
      *
      */
-    public void setName(java.lang.String name) {
+    public void setName(String name) {
         this.name = FileSystem.stdFn(name);
     }
     
+    @Override
     public String toString(){
         return name;
     }
