@@ -52,14 +52,14 @@ import javax.swing.SwingUtilities;
  * Objects of this class are widely used in JClic activities: cells in puzzles and
  * associations, messages and other objects are active boxes. The specific
  * content, size and location of <CODE>ActiveBox</CODE> is determined by its
- * {@link edu.xtec.jclic.boxes.ActveBoxContent} members. Most ActiveBoxes have only
+ * {@link edu.xtec.jclic.boxes.ActiveBoxContent} members. Most ActiveBoxes have only
  * one content, but some of them can have a secondary or "alternative" content, indicated
  * by the <CODE>altContent</CODE> member. This content is used only when the <CODE>alternative</CODE>
  * flag of the <CODE>ActiveBox</CODE> is on.
  * Active boxes can host video and interactive media content (specified in the mediaContent member of
  * the {@link edu.xtec.jclic.boxes.ActiveBoxContent}) through the <CODE>hostedMediaPlayer</CODE> member.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.28
  */
 public class ActiveBox extends AbstractBox implements Cloneable {
     
@@ -174,8 +174,8 @@ public class ActiveBox extends AbstractBox implements Cloneable {
         // only plain text!
         if(tx==null) tx="";
         if(content==null) content=new ActiveBoxContent();
-        content.rawText=new String(tx);
-        content.text=new String(tx);
+        content.rawText=tx;
+        content.text=tx;
         content.mediaContent=null;
         content.img=null;
         
@@ -221,10 +221,10 @@ public class ActiveBox extends AbstractBox implements Cloneable {
     }
     
     public void checkAutoStartMedia(){
-        ActiveBoxContent content=getContent();
-        if(content!=null && content.mediaContent!=null 
-           && content.mediaContent.autoStart==true && content.amp!=null){
-            final ActiveMediaPlayer amp=content.amp;
+        ActiveBoxContent cnt=getContent();
+        if(cnt!=null && cnt.mediaContent!=null 
+           && cnt.mediaContent.autoStart==true && cnt.amp!=null){
+            final ActiveMediaPlayer amp=cnt.amp;
             SwingUtilities.invokeLater(new Runnable(){
                 public void run(){
                     amp.play(ActiveBox.this);
@@ -276,6 +276,7 @@ public class ActiveBox extends AbstractBox implements Cloneable {
         return true;
     }
     
+    @Override
     protected void checkHostedComponent(){
         if(hasHostedComponent) 
             return;
@@ -345,7 +346,7 @@ public class ActiveBox extends AbstractBox implements Cloneable {
                 // Method 1
                 if(USE_TRANSFORM){
                     if(r.width>0 && r.height>0){
-                        AffineTransform at=null;
+                        AffineTransform at;
                         if(r.width!=width || r.height!=height){
                             double sx=width/r.width;
                             double sy=height/r.height;
@@ -405,13 +406,13 @@ public class ActiveBox extends AbstractBox implements Cloneable {
             }
         }
         if(abc.text!=null && abc.text.length()>0){
-            double x=this.x;
-            double y=this.y;
-            double width=this.width;
-            double height=this.height;
+            double px=this.x;
+            double py=this.y;
+            double pWidth=this.width;
+            double pHeight=this.height;
             if(imgRect!=null){
-                double[] prx=new double[]{0, imgRect.x, imgRect.x+imgRect.width, width};
-                double[] pry=new double[]{0, imgRect.y, imgRect.y+imgRect.height, height};
+                double[] prx=new double[]{0, imgRect.x, imgRect.x+imgRect.width, pWidth};
+                double[] pry=new double[]{0, imgRect.y, imgRect.y+imgRect.height, pHeight};
                 Rectangle2D.Double[] rr=new Rectangle2D.Double[]{
                     new Rectangle2D.Double(prx[0], pry[0], prx[3], pry[1]),
                     new Rectangle2D.Double(prx[0], pry[2], prx[3], pry[3]-pry[2]),
@@ -442,13 +443,13 @@ public class ActiveBox extends AbstractBox implements Cloneable {
                             rmax=rr[i];
                         }
                     }
-                    x+=rmax.x;
-                    y+=rmax.y;
-                    width=rmax.width;
-                    height=rmax.height;                    
+                    px+=rmax.x;
+                    py+=rmax.y;
+                    pWidth=rmax.width;
+                    pHeight=rmax.height;                    
             }
             double w, wtl, h, hl, dx, dy;
-            double ww=Math.max(5.0, width-2*bb.textMargin);
+            double ww=Math.max(5.0, pWidth-2*bb.textMargin);
             AttributedString atext;
             TextLayout layout;
             int rt;
@@ -464,7 +465,7 @@ public class ActiveBox extends AbstractBox implements Cloneable {
                 w=0; h=0; hl=0;
                 lbm.setPosition(0);
                 rt=abc.text.indexOf('\n');
-                for(i=0; lbm.getPosition()<abc.text.length() && h<height ;i++){                    
+                for(i=0; lbm.getPosition()<abc.text.length() && h<pHeight ;i++){                    
                     if(rt>lbm.getPosition()){
                         layout=lbm.nextLayout((float)ww, rt, false);
                         rt=abc.text.indexOf('\n', lbm.getPosition());
@@ -479,16 +480,16 @@ public class ActiveBox extends AbstractBox implements Cloneable {
                     h+= layout.getAscent()+layout.getDescent()+hl;
                 }
                 h-=hl;
-                if((h<=height && i<=maxLines) || bb.reduceFont()==false)
+                if((h<=pHeight && i<=maxLines) || bb.reduceFont()==false)
                     break;
                 JComponent jc=getContainerResolve();
                 if(jc!=null)
                     RepaintManager.currentManager(jc).markCompletelyDirty(jc);
             }
-            dy= y + (abc.txtAlign[1]==JDomUtility.ALIGN_TOP 
+            dy= py + (abc.txtAlign[1]==JDomUtility.ALIGN_TOP 
                      ? 0 
                      : abc.txtAlign[1]==JDomUtility.ALIGN_BOTTOM 
-                       ? height-h : (height-h)/2);
+                       ? pHeight-h : (pHeight-h)/2);
             g2.setColor(isInverted() 
                         ? bb.backColor 
                         : isAlternative() 
@@ -497,7 +498,7 @@ public class ActiveBox extends AbstractBox implements Cloneable {
             lbm.setPosition(0);
             rt=abc.text.indexOf('\n');
             h=0;
-            while(lbm.getPosition()<abc.text.length() && h<height){
+            while(lbm.getPosition()<abc.text.length() && h<pHeight){
                 
                 if(rt>lbm.getPosition()){
                     layout=lbm.nextLayout((float)ww, rt, false);
@@ -508,7 +509,7 @@ public class ActiveBox extends AbstractBox implements Cloneable {
                 
                 if(layout==null) break;
                 wtl=layout.getVisibleAdvance();
-                dx= x + bb.textMargin + 
+                dx= px + bb.textMargin + 
                     (abc.txtAlign[0]==JDomUtility.ALIGN_LEFT 
                      ? 0 
                      : abc.txtAlign[0]==JDomUtility.ALIGN_RIGHT 
@@ -566,12 +567,14 @@ public class ActiveBox extends AbstractBox implements Cloneable {
         return content==null ? "" : content.getDescription();
     }
     
+    @Override
     public void setBounds(Rectangle2D r){
         super.setBounds(r);
         if(hostedMediaPlayer!=null)
             hostedMediaPlayer.checkVisualComponentBounds(this);
     }
     
+    @Override
     public void end(){
         clear();
         super.end();
