@@ -42,10 +42,10 @@ import javax.swing.RepaintManager;
 import javax.swing.Timer;
 
 /**
- * This class is a special {@link edu.xtec.jclic.boxes.ActiveBox} that displays a grid
+ * This class is a special {@link edu.xtec.jclic.boxes.AbstractBox} that displays a grid
  * of single characters. It is used in activities like crosswords and scrambled letters.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.08
  */
 public class TextGrid extends AbstractBox implements Cloneable, Resizable, ActionListener{
     
@@ -234,7 +234,7 @@ public class TextGrid extends AbstractBox implements Cloneable, Resizable, Actio
     }
     
     public boolean isIntoBlacks(Point pt, boolean checkHorizontal){
-        boolean result=false;
+        boolean result;
         if(checkHorizontal){
             result=(pt.x<=0 || getCellAttribute(pt.x-1, pt.y, LOCKED))
             && (pt.x>=nCols-1 || getCellAttribute(pt.x+1, pt.y, LOCKED));
@@ -247,7 +247,7 @@ public class TextGrid extends AbstractBox implements Cloneable, Resizable, Actio
     }
     
     public boolean isIntoWhites(Point pt, boolean checkHorizontal){
-        boolean result=false;
+        boolean result;
         if(checkHorizontal){
             result=(pt.x>0 && !getCellAttribute(pt.x-1, pt.y, LOCKED))
             && (pt.x<nCols-1 && !getCellAttribute(pt.x+1, pt.y, LOCKED));
@@ -307,7 +307,6 @@ public class TextGrid extends AbstractBox implements Cloneable, Resizable, Actio
             useCursor=true;
             if(skipLocked && getCellAttribute(px, py, LOCKED)){
                 moveCursor(1, 0, skipLocked);
-                return;
             }
             else{
                 if(cursorEnabled)
@@ -392,7 +391,7 @@ public class TextGrid extends AbstractBox implements Cloneable, Resizable, Actio
     }
     
     public String getStringBetween(int x0, int y0, int x1, int y1){
-        StringBuffer sb=new StringBuffer();
+        StringBuilder sb=new StringBuilder();
         if(isValidCell(x0, y0) && isValidCell(x1, y1)){
             int dx=x1-x0;
             int dy=y1-y0;
@@ -468,6 +467,7 @@ public class TextGrid extends AbstractBox implements Cloneable, Resizable, Actio
             jc.repaint(getCellBorderBounds(px, py));
     }
     
+    @Override
     public Object clone(){
         TextGrid tgb=(TextGrid)super.clone();
         tgb.nRows=nRows;
@@ -497,12 +497,14 @@ public class TextGrid extends AbstractBox implements Cloneable, Resizable, Actio
                              StrUtils.roundTo(scale*preferredBounds.getHeight(), nRows));
     }
     
+    @Override
     public void setBounds(Rectangle2D r){
         super.setBounds(r);
         cellWidth=width/nCols;
         cellHeight=height/nRows;
     }
     
+    @Override
     public boolean update(Graphics2D g2, Rectangle dirtyRegion, ImageObserver io){
         if(isEmpty() || !isVisible() || isTemporaryHidden()) 
             return false;
@@ -606,6 +608,7 @@ public class TextGrid extends AbstractBox implements Cloneable, Resizable, Actio
         }
     }
     
+    @Override
     public void end(){
         if(cursorTimer!=null){
             cursorTimer.stop();
@@ -614,7 +617,10 @@ public class TextGrid extends AbstractBox implements Cloneable, Resizable, Actio
     }
     
     public void finalize() throws Throwable{
-        end();
-        super.finalize();
+        try {
+            end();
+        } finally {
+            super.finalize();
+        }
     }
 }
