@@ -32,14 +32,14 @@ import edu.xtec.jclic.fileSystem.FileSystem;
 import edu.xtec.jclic.fileSystem.PCCFileSystem;
 import edu.xtec.jclic.project.JClicProject;
 import java.awt.Color;
-import java.util.Vector;
+import java.util.ArrayList;
 
 
 /**
  * Constants and miscellaneous functions useful to read Clic 3.0 files and import
  * it into JClic projects.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.08
  */
 public abstract class Clic3 {
     
@@ -248,7 +248,7 @@ public abstract class Clic3 {
             if((dest[d]=source[s])==null)
                 break;
             if(upper)
-                dest[d].toUpperCase();
+                dest[d]=dest[d].toUpperCase();
         }
         return (i==e);
     }
@@ -481,10 +481,9 @@ public abstract class Clic3 {
     }
     
     public static String[] dataToArray(byte[] data) {
-        Vector v=new Vector();
+        ArrayList<String> v=new ArrayList<String>();
         int i, j, k, l, l2;
         byte[] buffer;
-        String strBuff;
         String[] array;
         int nLines=0;
         
@@ -513,7 +512,7 @@ public abstract class Clic3 {
         if(nLines>0){
             array=new String[nLines];
             try {
-                array=(String[])v.toArray(array);
+                array=v.toArray(array);
             }
             catch(ArrayStoreException e){
                 array=null;
@@ -529,9 +528,8 @@ public abstract class Clic3 {
     public static String validFileName(String name, boolean strict, boolean remember){
         if(name==null)
             return null;
-        StringBuffer sb=new StringBuffer();
-        for(int i=0; i<name.length(); i++){
-            char ch=name.charAt(i);
+        StringBuilder sb=new StringBuilder();
+        for(char ch : name.toCharArray()){
             if(validFileChars.indexOf(ch, strict ? 3 : 0)<0){
                 if(ch>='A' && ch<='Z')
                     ch=Character.toLowerCase(ch);
@@ -559,7 +557,7 @@ public abstract class Clic3 {
     }
     
     
-    public static final String pacNameToLowerCase(String s){
+    public static String pacNameToLowerCase(String s){
         String result=s;
         if(s!=null){
             String l=s.toLowerCase();
