@@ -42,15 +42,15 @@ import java.util.StringTokenizer;
  * This class encapsulates the main properties of a Clic 3.0 activity, and provides
  * methods to load it from a data stream and to convert it to a JClic
  * {@link edu.xtec.jclic.Activity}.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.08
  */
 public class Clic3Activity extends Clic3 {
     
     public JClicProject project;
     
     public static final int TOO_MUCH_CELLS=14;
-    private static final Boolean BF=new Boolean(false);
+    private static final Boolean BF=false;
     
     public String rPath=null;
     public String className=null;
@@ -271,7 +271,7 @@ public class Clic3Activity extends Clic3 {
     
     public boolean load(String name, byte[] data) {
         String[] txt;
-        StringBuffer tmptx=new StringBuffer();
+        StringBuilder tmptx=new StringBuilder();
         String fn=BLANK;
         int  i, l, tipus, nLin, fLine, ver, ncas, k;
         boolean result=false;
@@ -279,7 +279,7 @@ public class Clic3Activity extends Clic3 {
         
         //clear();
         
-        fileName = FileSystem.getCanonicalNameOf(validFileName(name), new Boolean(false));
+        fileName = FileSystem.getCanonicalNameOf(validFileName(name), false);
         rPath=FileSystem.getPathPartOf(fileName);
         
         fLine=0;
@@ -293,7 +293,7 @@ public class Clic3Activity extends Clic3 {
             (ver=(ver=parseIntX(txt[fLine++]))>1000 ? ver-1000 : ver)>=100 &&
             ver<=CLICVER){
                 if(ver>107){
-                    StringBuffer sb=new StringBuffer();
+                    StringBuilder sb=new StringBuilder();
                     while(fLine<nLin){
                         if(txt[fLine].length()>0 && txt[fLine].charAt(0)==ENDDESC){
                             fLine++;
@@ -661,7 +661,7 @@ public class Clic3Activity extends Clic3 {
         boolean specialShape=false;
         boolean noAutoZones=false;
         boolean singleCells=false;
-        boolean border=false;
+        boolean border;
         
         if(num<0 || num>=3 || fileNameCont[num]==null)
             return abc;
@@ -680,14 +680,13 @@ public class Clic3Activity extends Clic3 {
         abc=new ActiveBagContent(cw, ch);
         abc.border=border;
         
-        int i=-1;
         Shaper sh=null;
         if(fileDesc!=null){
             if(fileDesc.indexOf("noAutoZones")>=0)
                 noAutoZones=true;
             if(fileDesc.indexOf("singleCells")>=0)
                 singleCells=true;
-            i=fileDesc.indexOf("SHAPER:");
+            int i=fileDesc.indexOf("SHAPER:");
             if(i>=0){
                 StringTokenizer st=new StringTokenizer(fileDesc.substring(i+7), "|");
                 if(st.hasMoreTokens()){
@@ -742,14 +741,16 @@ public class Clic3Activity extends Clic3 {
                 else{
                     int[] ids=new int[cw*ch];
                     if(num==0)
-                        for(i=0; i<cw*ch; i++)
-                            ids[i]=ass[i];
+                        //ATENCIÓ!!!!!!
+                        //for(int i=0; i<cw*ch; i++)
+                        //    ids[i]=ass[i];
+                        System.arraycopy(ass, 0, ids, 0, cw*ch);
                     else{
-                        for(i=0; i<cw*ch; i++)
+                        for(int i=0; i<cw*ch; i++)
                             ids[i]=-1;
                         int k=0;
                         int m=Math.min(ncw*nch, ass.length);
-                        for(i=0; i<m; i++){
+                        for(int i=0; i<m; i++){
                             int j=ass[i];
                             if(j>=0){
                                 if(ids[j]==-1){
@@ -777,20 +778,19 @@ public class Clic3Activity extends Clic3 {
     public void setActiveBoxTextContent(ActiveBoxContent abc, String tx) throws Exception{
         int i, j;
         String sub, subc;
-        String txPrev;
+        String txPrev2;
         
         abc.mediaContent=null;
         abc.img=null;
         abc.imgName=null;
         //abc.rawText=new String(tx);
         abc.rawText=tx;
-        //txPrev=new String(tx);
-        txPrev=tx;
-        while((i=txPrev.indexOf('{'))>=0){
-            j=txPrev.indexOf('}', i);
+        txPrev2=tx;
+        while((i=txPrev2.indexOf('{'))>=0){
+            j=txPrev2.indexOf('}', i);
             if(j<0) break;
-            sub=txPrev.substring(i+1, j);
-            txPrev=txPrev.substring(0, i)+txPrev.substring(j+1);
+            sub=txPrev2.substring(i+1, j);
+            txPrev2=txPrev2.substring(0, i)+txPrev2.substring(j+1);
             sub=sub.trim();
             subc=sub.toLowerCase();
             if(subc.endsWith(".gif") || subc.endsWith(".jpg") || 
@@ -906,7 +906,7 @@ public class Clic3Activity extends Clic3 {
                 }
             }
         }
-        abc.text=txPrev;
+        abc.text=txPrev2;
         abc.realizeContent(project.mediaBag);
     }
     
