@@ -47,12 +47,12 @@ import javax.swing.tree.TreePath;
  * object.
  * The class extends {@link javax.swing.tree.DefaultMutableTreeNode} in order to
  * make easy to implement a tree of dependences between editor classes.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.10
  */
 public abstract class Editor extends DefaultMutableTreeNode{
     
-    protected HashSet listeners;
+    protected HashSet<EditorListener> listeners;
     protected DefaultTreeModel treeModel;
     protected JTree currentTree;
     protected ListSelectionModel listSelectionModel;
@@ -65,7 +65,7 @@ public abstract class Editor extends DefaultMutableTreeNode{
     
     protected Editor(Object data){
         super(data);
-        listeners=new HashSet();
+        listeners=new HashSet<EditorListener>();
     }
     
     public static Editor createEditor(String className, Object data, Editor parent){
@@ -74,16 +74,21 @@ public abstract class Editor extends DefaultMutableTreeNode{
             Class cl=Class.forName(className);            
             Constructor[] constructors=cl.getDeclaredConstructors();
             Constructor cn=null;
-            for(int i=0; i<constructors.length; i++){
-                Class[] parameters=constructors[i].getParameterTypes();
+            for(Constructor constr : constructors){
+                Class[] parameters=constr.getParameterTypes();
                 if(parameters!=null && parameters.length==1 && 
                    parameters[0].isInstance(data)){
-                     cn=constructors[i];
+                     cn=constr;
                      break;
                 }
             }
             
-            result=(Editor)cn.newInstance(new Object[]{data});
+            if(cn==null)
+                throw new Exception();
+            
+            result=(Editor)cn.newInstance(new Object[]{data});            
+            if(result==null)
+                throw new Exception();
             if(parent!=null)
                 parent.add(result);
             result.createChildren();
@@ -143,6 +148,7 @@ public abstract class Editor extends DefaultMutableTreeNode{
     public JTree createJTree(){
         setCurrentTree(new JTree(getTreeModel()));
         currentTree.setCellRenderer(new DefaultTreeCellRenderer(){
+            @Override
             public Component getTreeCellRendererComponent(JTree tree, Object value, 
                                                           boolean sel, boolean expanded, boolean leaf, 
                                                           int row, boolean hasFocus){
@@ -177,25 +183,30 @@ public abstract class Editor extends DefaultMutableTreeNode{
             return getChildCount();
         } 
         
+        @Override
         public void fireIntervalAdded(Object src, int index0, int index1){
             super.fireIntervalAdded(src, index0, index1);
         }
         
+        @Override
         public void fireIntervalRemoved(Object src, int index0, int index1){
             super.fireIntervalRemoved(src, index0, index1);
         }
         
+        @Override
         public void fireContentsChanged(Object src, int index0, int index1){
             super.fireContentsChanged(src, index0, index1);
         }
     }            
     
+    @Override
     public void insert(MutableTreeNode newChild, int childIndex){
         super.insert(newChild, childIndex);
         if(listModel!=null)
             listModel.fireIntervalAdded(listModel, childIndex, childIndex);
     }
     
+    @Override
     public void remove(int childIndex){
         super.remove(childIndex);
         if(listModel!=null)
@@ -269,6 +280,12 @@ public abstract class Editor extends DefaultMutableTreeNode{
                     sel.select();
                 }
             }
+            // Added 03-Feb-2011
+            // Correct bug 172: when an editor loses its last element,
+            // set their parent owner of the basic actions
+            if(index<0)
+                p.setActionsOwner();
+
             result=true;
         }
         return result;
@@ -450,6 +467,7 @@ public abstract class Editor extends DefaultMutableTreeNode{
     public abstract Class getEditorPanelClass();
     public abstract EditorPanel createEditorPanel(Options options);
     
+    @Override
     public String toString(){
         return "generic Editor component";
     }
