@@ -21,14 +21,14 @@
 
 package edu.xtec.jclic.media;
 
-import edu.xtec.util.Options;
 import edu.xtec.jclic.Constants;
 import edu.xtec.util.Check;
+import edu.xtec.util.Options;
 
 /**
  *
- * @author  Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author  Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.28
  */
 public final class CheckMediaSystem {
     
@@ -63,7 +63,7 @@ public final class CheckMediaSystem {
                 // No quicktime 6.1 available
             }
         }
-        options.put(Constants.QT61, new Boolean(qt61));
+        options.put(Constants.QT61, qt61);
         
         // 27-Nov-2007: QuickTime 6.0 or previous is not yet supported by JClic
 		/*
@@ -80,7 +80,7 @@ public final class CheckMediaSystem {
             }
         }
 		*/
-        options.put(Constants.QT, new Boolean(qt));
+        options.put(Constants.QT, qt);
 
         boolean jmf=false;
         try{
@@ -93,7 +93,7 @@ public final class CheckMediaSystem {
         } catch(Exception ex){
             // no JMF available
         }
-        options.put(Constants.JMF, new Boolean(jmf));
+        options.put(Constants.JMF, jmf);
         
         String mediaSystem=(String)options.get(Constants.MEDIA_SYSTEM);
         if(mediaSystem!=null){
@@ -113,7 +113,7 @@ public final class CheckMediaSystem {
         if(mediaSystem==null)
             mediaSystem=qt61 ? Constants.QT61 : /*qt ? Constants.QT : */ jmf ? Constants.JMF : null;
             
-        if(mediaSystem==Constants.QT61 && qt61Lock==null){
+        if(mediaSystem!=null && mediaSystem.equals(Constants.QT61) && qt61Lock==null){
             try{
                 // 03-Apr-2008
                 // QT61Tools are now included in jclic.jar, so the direct constructor
@@ -121,7 +121,7 @@ public final class CheckMediaSystem {
                 //Class cl=Class.forName("edu.xtec.jclic.media.QT61Tools");
                 //qt61Lock=cl.newInstance();
                 qt61Lock=new edu.xtec.jclic.media.QT61Tools();
-                qt61=(qt61Lock!=null);
+                //qt61=(qt61Lock!=null);
                 options.put(QTLOCK, qt61Lock);
             } catch(Exception ex){
                 options.getMessages().showErrorWarning(options.getMainComponent(), "media_qt_error_initializing", ex);
