@@ -28,15 +28,12 @@ import java.awt.*;
 import java.awt.geom.Area;
 import java.awt.image.BufferedImage;
 import java.awt.image.ImageObserver;
-import java.io.File;
-import java.io.FilenameFilter;
-import javax.swing.filechooser.FileFilter;
 
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.28
  */
 public abstract class Utils implements Constants{
     
@@ -87,7 +84,7 @@ public abstract class Utils implements Constants{
         Constants.T_INST, Constants.T_TEXT, Constants.T_UNKNOWN_MEDIA
     };
     
-    public static final int getFileType(String fileName){
+    public static int getFileType(String fileName){
         int result=TYPE_UNKNOWN;
         if(fileName!=null){
             int dot=fileName.lastIndexOf('.');
@@ -442,7 +439,7 @@ public abstract class Utils implements Constants{
     // Low memory under 4Mb of free RAM
     public static final long LOW_MEMORY_THRESHOLD=0x400000L;
 
-    public static final boolean lowMemoryCondition(){
+    public static boolean lowMemoryCondition(){
         return getTotalFreeMemory()<LOW_MEMORY_THRESHOLD;
     }
     
