@@ -37,7 +37,9 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.util.Date;
 import java.util.HashMap;
-import java.util.Vector;
+import java.util.Iterator;
+import java.util.List;
+import java.util.concurrent.CopyOnWriteArrayList;
 import javax.swing.JButton;
 import javax.swing.JComponent;
 import javax.swing.JList;
@@ -50,8 +52,8 @@ import javax.swing.JTextField;
  * obtained by users playing JClic activities. These operations include
  * users identification, compilation of data coming from the activities, storage of
  * this data for a posterior use and presentation of summarized results.
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.10
  */
 public class Reporter extends Object {
     
@@ -62,7 +64,7 @@ public class Reporter extends Object {
     String userCodeFilter;
     String description;    
     Date started;
-    Vector sessions;
+    List<SessionReg> sessions;
     SessionReg currentSession;
     /**
      * <I>true</I> if the system was successfully initiated, <I>false</I> otherwise
@@ -84,7 +86,7 @@ public class Reporter extends Object {
     
     /** Creates new Reporter */
     public Reporter() {
-        sessions=new Vector();
+        sessions=new CopyOnWriteArrayList<SessionReg>();
         started=new Date();
         initiated=false;
     }
@@ -112,11 +114,11 @@ public class Reporter extends Object {
         return key==null ? defaultValue : Boolean.valueOf(s).booleanValue();
     }
     
-    public Vector getGroups() throws Exception{
+    public List<GroupData> getGroups() throws Exception{
         return null;
     }
     
-    public Vector getUsers(String groupId) throws Exception{
+    public List<UserData> getUsers(String groupId) throws Exception{
         return null;
     }
         
@@ -130,7 +132,7 @@ public class Reporter extends Object {
     
     public boolean userBased() throws Exception{
         if(bUserBased==null)
-            bUserBased=new Boolean(getBooleanProperty(USER_TABLES, true));
+            bUserBased=getBooleanProperty(USER_TABLES, true);
         return bUserBased.booleanValue();
     }
     
@@ -139,8 +141,8 @@ public class Reporter extends Object {
         JTextField gId=new JTextField(20);
         JComponent[] jc=new JComponent[]{gName, gId};
         String[] ps=new String[]{"report_name_prompt", "report_id_prompt"};
-        String name=null;
-        String id=null;
+        String name;
+        String id;
         GroupData result=null;
         while(result==null){
             boolean dlgResult=msg.showInputDlg(parent, new String[]{"report_new_group_data"}, ps, jc, "report_new_group");
@@ -175,9 +177,9 @@ public class Reporter extends Object {
         JPasswordField pwf2=new JPasswordField(Messages.MAX_PASSWORD_LENGTH);
         JComponent[] jc=new JComponent[]{gName, gId, pwf1, pwf2};
         String[] ps=new String[]{"report_name_prompt", "report_id_prompt", "report_pw_prompt", "report_pw_prompt_confirm"};
-        String name=null;
-        String id=null;
-        String pw=null;
+        String name;
+        String id;
+        String pw;
         UserData result=null;
         while(result==null){
             if(!msg.showInputDlg(parent, 
@@ -212,21 +214,19 @@ public class Reporter extends Object {
     
     protected String promptGroupId(Component parent, final Messages msg) throws Exception{
         String groupId=null;
-        Vector vg=getGroups();
-        if(vg.isEmpty()){
+        if(getGroups().isEmpty()){
             String s=msg.get("report_generic_group_name");
             newGroup(new GroupData(s, s, null, null));
-            vg=getGroups();
-            if(vg.isEmpty())
+            if(getGroups().isEmpty())
                 return groupId;
         }
-        final Vector v=vg;
+        final List<GroupData> vg=getGroups();        
         final JList list=new JList();
         list.setCellRenderer(new CompoundListCellRenderer());
-        list.setListData(v);
-        list.setSelectedValue(v.get(0), false);
+        list.setListData(vg.toArray());
+        list.setSelectedValue(vg.get(0), false);
         JScrollPane listScroll=new JScrollPane(list);
-        JComponent[] jc=null;
+        JComponent[] jc;
         if(getBooleanProperty(ALLOW_CREATE_GROUPS, false)){
             JButton btn=new JButton(msg.get("report_new_group"));
             btn.addActionListener(new ActionListener(){
@@ -237,8 +237,8 @@ public class Reporter extends Object {
                     try{
                         GroupData gd=promptForNewGroup(cmp, msg);
                         if(gd!=null){
-                            v.add(gd);
-                            list.setListData(v);
+                            vg.add(gd);
+                            list.setListData(vg.toArray());
                             list.setSelectedValue(gd, true);
                         }
                     } catch(Exception ex){
@@ -282,7 +282,7 @@ public class Reporter extends Object {
                         return null;
                 }
                 final String groupId=gi;
-                final Vector v=getUsers(groupId);
+                final List<UserData> v=getUsers(groupId);
                 boolean allow_create_users=getBooleanProperty(ALLOW_CREATE_USERS, false);
                 if(v.isEmpty() && !allow_create_users){
                     msg.showErrorWarning(parent, groupId==null ? "report_err_no_users" : "report_err_no_users_in_group", null);
@@ -290,11 +290,11 @@ public class Reporter extends Object {
                 }
                 final JList list=new JList();
                 list.setCellRenderer(new CompoundListCellRenderer());
-                list.setListData(v);
+                list.setListData(v.toArray());
                 if(!v.isEmpty())
                     list.setSelectedValue(v.get(0), false);
                 JScrollPane listScroll=new JScrollPane(list);
-                JComponent[] jc=null;
+                JComponent[] jc;
                 if(allow_create_users){
                     JButton btn=new JButton(msg.get("report_new_user"));
                     btn.setToolTipText(msg.get("report_new_user_tooltip"));
@@ -307,7 +307,7 @@ public class Reporter extends Object {
                                 UserData ud=promptForNewUser(cmp, msg, groupId);
                                 if(ud!=null){
                                     v.add(ud);
-                                    list.setListData(v);
+                                    list.setListData(v.toArray());
                                     list.setSelectedValue(ud, true);
                                 }
                             } catch(Exception ex){
@@ -376,7 +376,7 @@ public class Reporter extends Object {
                 if(!userOk)
                     msg.showErrorWarning(parent, "report_err_invalid_user", null);
                 else
-                    userId=ud.getId();
+                    userId = ud==null ? "" : ud.getId();
             }
         }
         return userId;
@@ -402,8 +402,9 @@ public class Reporter extends Object {
         int percentSolved=0;
         long tScore=0;
         long tTime=0L;
-        for(int i=0; i<sessions.size(); i++){
-            Info inf=getSessionReg(i).getInfo(true);
+        Iterator<SessionReg> it=sessions.iterator();
+        while(it.hasNext()){
+            Info inf=it.next().getInfo(true);
             if(inf.numSequences>0){
                 numSessions++;
                 numSequences+=inf.numSequences;
@@ -433,9 +434,10 @@ public class Reporter extends Object {
             }
             html.append(Html.table(tb.toString(), null, 0, 2, -1, null, false)).append(Html.NBSP);
             
-            StringBuffer tbs=new StringBuffer();
-            for(int i=0; i<sessions.size(); i++){
-                SessionReg sr=getSessionReg(i);
+            StringBuilder tbs=new StringBuilder();
+            it=sessions.iterator();
+            while(it.hasNext()){
+                SessionReg sr=it.next();
                 if(sr.getInfo(false).numSequences>0)
                     tbs.append(sr.toHtmlString(msg, false, numSessions>1));
             }
@@ -463,7 +465,7 @@ public class Reporter extends Object {
     }
     
     public static Reporter getReporter(HashMap properties, Component parent, Messages msg) throws Exception{
-        String className=null;
+        String className;
         if(properties==null)
             throw new IllegalArgumentException("Null properties passed to \"getReporter\"");
         if((className=(String)properties.get(JDomUtility.CLASS))==null)
@@ -481,15 +483,19 @@ public class Reporter extends Object {
         if(className.indexOf('.')<0){
             className="edu.xtec.jclic.report."+className;
         }
-        HashMap properties=new HashMap();
+        HashMap<String, Object> properties=new HashMap<String, Object>();
         properties.put(JDomUtility.CLASS, className);
         Options.strToMap(strProperties, properties, ";", '=', false);
         return getReporter(properties, parent, msg);
     }
     
+    @Override
     protected void finalize() throws Throwable{
-        end();
-        super.finalize();
+        try {
+            end();
+        } finally {
+            super.finalize();
+        }
     }
     
     public void end(){
@@ -540,10 +546,6 @@ public class Reporter extends Object {
             currentSession.newAction(type, source, dest, ok);
     }
     
-    public SessionReg getSessionReg(int index){
-        return index>=sessions.size() ? null : (SessionReg)sessions.get(index);
-    }
-    
     public edu.xtec.jclic.report.SequenceReg.Info getCurrentSequenceInfo(){
         return currentSession==null ? null : currentSession.getCurrentSequenceInfo();
     }
