@@ -22,22 +22,19 @@
 package edu.xtec.jclic.skins;
 
 import edu.xtec.jclic.*;
-import edu.xtec.jclic.misc.*;
-import edu.xtec.util.*;
 import edu.xtec.jclic.boxes.*;
 import edu.xtec.jclic.fileSystem.FileSystem;
+import edu.xtec.jclic.misc.*;
+import edu.xtec.util.*;
 import java.awt.*;
 import java.awt.image.*;
 import javax.swing.*;
 import javax.swing.border.*;
-import javax.swing.event.*;
-import java.util.Properties;
-import edu.xtec.jclic.boxes.AbstractBox;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.28
  */
 public class BasicSkin extends Skin {
     
@@ -298,6 +295,7 @@ public class BasicSkin extends Skin {
         return bb;
     }
     
+    @Override
     public void doLayout(){
         if(initiated<1){
             invalidate();
@@ -336,6 +334,7 @@ public class BasicSkin extends Skin {
             initiated=2;
     }
     
+    @Override
     public void startAnimation(){
         if(progressAnimation!=null){
             if(hideProgressAnim)
@@ -345,6 +344,7 @@ public class BasicSkin extends Skin {
         }
     }
     
+    @Override
     public void stopAnimation(){
         if(progressAnimation!=null){
             if(hideProgressAnim)
@@ -364,7 +364,7 @@ public class BasicSkin extends Skin {
         
         if(counters!=null)
             for(int i=0; i<Constants.NUM_COUNTERS; i++){
-                if(counters[i]!=null && counters[i].equals(clip)){
+                if(counters[i]!=null && counters[i].getBounds().equals(clip)){
                     Utils.drawImage(g2, img, counters[i].getBounds(), countersRect[i][0], this);
                     counters[i].update(g2, clip, this);
                     return;
@@ -382,13 +382,14 @@ public class BasicSkin extends Skin {
             for(int i=0; i<NUM_BOXES; i++){
                 if(boxes[i]!=null){
                     boxes[i].update(g2, clip, this);
-                    if(boxes[i].equals(clip)){
+                    if(boxes[i].getBounds().equals(clip)){
                         return;
                     }
                 }
             }
     }
     
+    @Override
     public void setLocale(java.util.Locale l){
         super.setLocale(l);
         if(ps!=null && countersLabel!=null)
@@ -489,12 +490,14 @@ public class BasicSkin extends Skin {
         return result;
     }
     
+    @Override
     public void setProgressMax(int max){
         super.setProgressMax(max);
         if(progressBar!=null)
             progressBar.setMaximum(max);
     }
     
+    @Override
     public void setProgressValue(int value){
         super.setProgressValue(value);
         if(progressBar!=null){
@@ -504,6 +507,7 @@ public class BasicSkin extends Skin {
         }
     }
     
+    @Override
     public void endProgress(){
         super.endProgress();
         if(progressBar!=null && hideProgressBar==true)
