@@ -22,25 +22,22 @@
 package edu.xtec.jclic.skins;
 
 import edu.xtec.jclic.*;
-import edu.xtec.util.*;
-import edu.xtec.jclic.misc.Utils;
 import edu.xtec.jclic.boxes.*;
 import edu.xtec.jclic.fileSystem.FileSystem;
-import javax.swing.*;
-import javax.swing.event.*;
+import edu.xtec.jclic.misc.Utils;
+import edu.xtec.util.*;
 import java.awt.*;
 import java.awt.event.*;
-import javax.swing.border.*;
 import java.io.InputStream;
-import java.io.FilterInputStream;
-import java.io.IOException;
+import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Iterator;
+import javax.swing.*;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.10
  */
 public abstract class Skin extends JPanel implements ProgressInputStream.ProgressInputStreamListener{
     
@@ -67,8 +64,8 @@ public abstract class Skin extends JPanel implements ProgressInputStream.Progres
     protected int progressMax, progress;
     protected boolean hasProgress, progressActive;
     protected long progressStartTime=0L;
-    
-    protected static HashSet skinStack=new HashSet();
+
+    protected static HashSet<Skin> skinStack=new HashSet<Skin>();
     
     /** Creates new Skin */
     protected Skin() {
@@ -88,10 +85,11 @@ public abstract class Skin extends JPanel implements ProgressInputStream.Progres
         progressActive=false;
         hasProgress=false;
         skinStack.add(this);
+        enableEvents(AWTEvent.MOUSE_EVENT_MASK);
     }
     
     public void emptySkinStack(){
-        skinStack=new HashSet();
+        skinStack=new HashSet<Skin>();
     }
     
     public void attach(Component setPlayer){
@@ -135,9 +133,7 @@ public abstract class Skin extends JPanel implements ProgressInputStream.Progres
     public static final String ELEMENT_NAME="skin";
     public static final String INTERNAL_SKIN_PREFIX="@";
     public static final String NAME="name";
-    public static Skin getSkin(String skinName, FileSystem fs, PlayStation ps) throws Exception{
-        Skin sk=null;
-        
+    public static Skin getSkin(String skinName, FileSystem fs, PlayStation ps) throws Exception{        
         Iterator it=skinStack.iterator();
         while(it.hasNext()){
             Skin s=(Skin)it.next();
@@ -155,7 +151,7 @@ public abstract class Skin extends JPanel implements ProgressInputStream.Progres
         
         JDomUtility.checkName(e, ELEMENT_NAME);
         Class skinClass=Class.forName(JDomUtility.getClassName(e));
-        sk=(Skin)skinClass.newInstance();
+        Skin sk=(Skin)skinClass.newInstance();
         sk.name=e.getAttributeValue(NAME);
         sk.fileName=skinName;
         sk.ps=ps;
@@ -165,6 +161,7 @@ public abstract class Skin extends JPanel implements ProgressInputStream.Progres
     
     protected abstract void setProperties(org.jdom.Element e, FileSystem fs) throws Exception;
     
+    @Override
     public void paintComponent(Graphics g){
         Graphics2D g2=(Graphics2D)g;
         RenderingHints rh=g2.getRenderingHints();
@@ -177,6 +174,36 @@ public abstract class Skin extends JPanel implements ProgressInputStream.Progres
     }
     
     public abstract void render(Graphics2D g2, Rectangle clip);
+
+    @Override
+    protected void processEvent(AWTEvent e) {
+        if (ps != null && e instanceof MouseEvent) {
+            if (e.getID() == MouseEvent.MOUSE_CLICKED) {
+                Iterator it = getActiveBoxes();
+                while (it.hasNext()) {
+                    ActiveBox ab = (ActiveBox) it.next();
+                    if (ab.contains(((MouseEvent) e).getPoint())
+                            && ab.getContent().mediaContent != null) {
+                        ps.stopMedia(ab.getContent().mediaContent.level);
+                        ab.playMedia(ps);
+                    }
+                }
+            }
+        }
+        super.processEvent(e);
+    }
+
+    protected Iterator<ActiveBox> getActiveBoxes(){
+
+        ArrayList<ActiveBox> v=new ArrayList<ActiveBox>();
+
+        if(msgBox!=null)
+            v.add(msgBox);
+
+        return v.iterator();
+
+    }
+
     
     public void setProgressMax(int max){
         progressMax=max;
@@ -201,7 +228,7 @@ public abstract class Skin extends JPanel implements ProgressInputStream.Progres
     }
     
     public InputStream getProgressInputStream(InputStream is, int expectedLength, String fName){
-        InputStream result=null;        
+        InputStream result;
         if(hasProgress && !progressActive){
             ProgressInputStream pi=new ProgressInputStream(is, expectedLength, fName);
             pi.addProgressInputStreamListener(this);
@@ -345,7 +372,7 @@ public abstract class Skin extends JPanel implements ProgressInputStream.Progres
     public void setMem(long newMem){
         mem=newMem;
         if(msgArea[MEM]!=null){
-            String s=new StringBuffer(Long.toString(mem/1000)).append(" Kb").substring(0);
+            String s=new StringBuilder(Long.toString(mem/1000)).append(" Kb").substring(0);
             msgArea[MEM].setTextContent(s);
         }
     }
@@ -446,13 +473,14 @@ public abstract class Skin extends JPanel implements ProgressInputStream.Progres
         requestFocus();
     }
     
+    @Override
     public void requestFocus(){
         if(player!=null)
             player.requestFocus();
     }
     
     public static String[] getSystemSkinList(boolean withEmptyEntry){
-        java.util.Vector v=new java.util.Vector();        
+        ArrayList<String> v=new ArrayList<String>();        
         java.util.Properties prop=new java.util.Properties();        
         try{
             prop.load(ResourceManager.getResourceAsStream(RESOURCE_FOLDER+"/"+RESOURCE_LIST_FILE));
