@@ -26,15 +26,15 @@ package edu.xtec.jclic;
  * this interface. It describes the necessary methods to make JClic
  * activities work. These methods are called by the activities to get resources, play
  * media or notify events.
- * @author Francesc Busquets (fbusquets@xtec.net)
+ * @author Francesc Busquets (fbusquets@xtec.cat)
  */
 public interface PlayStation extends edu.xtec.util.ResourceBridge {
     
     /**
-     * The action corresponding to this index. The indexes of actions are dfined as constants
+     * The action corresponding to this index. The indexes of actions are defined as constants
      * in <CODE>edu.xtec.jclic.Constants</CODE>.
      * @param id The index for the requested action.
-     * @return The action coresponding to this index, or null if does not exist.
+     * @return The action coresponding to this index, or null if it does not exist.
      */    
     public javax.swing.Action getAction(int id);    
     
@@ -61,7 +61,7 @@ public interface PlayStation extends edu.xtec.util.ResourceBridge {
     /**
      * Enables or disables the wait cursor (hourglass). This method uses a counter that
      * increments or decrements as called with <CODE>true</CODE> or <CODE>false</CODE> params.
-     * The hourglass is maintained while the counter remains >0.
+     * The hourglass is maintained while the counter remains &gt;0.
      * @param state To enable or disable the wait cursor.
      */    
     public void setWaitCursor(boolean state);
@@ -180,7 +180,7 @@ public interface PlayStation extends edu.xtec.util.ResourceBridge {
     /**
      * Instructs the Player to show a help dialog window displaying a content associated with the current
      * activity.
-     * @param hlpComponent The {@link JComponent} to be placed in the help dialog, or <CODE>null</CODE> if no special
+     * @param hlpComponent The {@link javax.swing.JComponent} to be placed in the help dialog, or <CODE>null</CODE> if no special
      * content must be used. Activities usually use {@link edu.xtec.jclic.HelpActivityComponent} objects for this param.
      * @param hlpMsg A message to be displayed on the help window, usually used in place of a
      * specific JComponent. This parameter can be <CODE>null</CODE>.
@@ -190,24 +190,11 @@ public interface PlayStation extends edu.xtec.util.ResourceBridge {
     public boolean showHelp(javax.swing.JComponent hlpComponent, String hlpMsg);
     
     /**
-     * Getter for property focusedItemsMarked. When this property is <CODE>true</CODE>, the item that has the focus
-     * of user's interaction is visually marked on screen.
-     * @return Value of property focusedItemsMarked.
+     * FressaFunctions offers special accessibility features
+     * like atomatic scanning and voice synthesis.
+     * @return The FressaFunctions object, or <CODE>null</CODE> if accessibility features are not enabled
      */
-    public boolean isFocusedItemMarked();
-    
-    /**
-     * Setter for property focusedItemsMarked. When this property is <CODE>true</CODE>, the item that has the focus
-     * of user's interaction is visually marked on screen.
-     * @param focusedItemsMarked New value of property focusedItemsMarked.
-     */
-    public void setFocusedItemMarked(boolean focusedItemMarked);
-    
-    
-    /**
-     * When not null, this java.awt.Robot object can be used by JClic components to move the mouse pointer
-     * and simulate clicks and keystrokes
-     */
-    public java.awt.Robot getRobot();
+    public edu.xtec.jclic.accessibility.FressaFunctions getFressa();
+
     
 }
