@@ -21,36 +21,29 @@
 
 package edu.xtec.jclic.project;
 
-import java.net.URL;
 import edu.xtec.jclic.activities.panels.*;
-import edu.xtec.jclic.fileSystem.FileSystem;
-import edu.xtec.util.*;
-import edu.xtec.jclic.misc.Utils;
-
-import java.awt.Component;
-import java.io.*;
-import java.util.Properties;
-import java.util.Map;
-import java.util.HashMap;
-import java.util.Vector;
-import javax.swing.event.ListSelectionListener;
-import javax.swing.event.ListSelectionEvent;
-import javax.swing.JComponent;
 import edu.xtec.jclic.edit.EditorTreePanel;
-import java.awt.BorderLayout;
-import javax.swing.event.TreeSelectionEvent;
-import java.awt.Font;
+import edu.xtec.jclic.fileSystem.FileBackup;
+import edu.xtec.jclic.fileSystem.FileSystem;
 import edu.xtec.jclic.misc.Gradient;
-import java.awt.Image;
+import edu.xtec.util.*;
+import java.awt.BorderLayout;
 import java.awt.Color;
+import java.awt.Component;
+import java.awt.Font;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
+import java.awt.Image;
 import java.awt.Rectangle;
-import edu.xtec.jclic.fileSystem.FileBackup;
+import java.io.*;
+import java.util.ArrayList;
+import javax.swing.event.ListSelectionEvent;
+import javax.swing.event.ListSelectionListener;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.08
  */
 public class ProjectInstallerDlg extends ExtendedJDialog implements ProgressInputStream.ProgressInputStreamListener, ListSelectionListener {
     
@@ -70,7 +63,7 @@ public class ProjectInstallerDlg extends ExtendedJDialog implements ProgressInpu
     File installDir;
     Options options;
     boolean workerRunning;
-    SwingWorker worker;
+    edu.xtec.util.SwingWorker worker;
     boolean copyComplete;
     private Font titleFont, mainFont, itemFont;
     private Image logo;
@@ -487,33 +480,33 @@ public class ProjectInstallerDlg extends ExtendedJDialog implements ProgressInpu
     
     private void goToStage(int stage){
         if(stage>=0 && stage<=NUM_STAGES){
-            boolean next=false, prev=false, cancel=false;
+            boolean bNext=false, bPrev=false, bCancel=false;
             currentStage=stage;
             switch(currentStage){
                 case STAGE_INFO:
-                    next=true; prev=false; cancel=true;
+                    bNext=true; bPrev=false; bCancel=true;
                     break;
                     
                 case STAGE_SELECT_LIB:
-                    next=(libraryPane.getCurrentSelected()!=null);
-                    prev=true; cancel=true;
+                    bNext=(libraryPane.getCurrentSelected()!=null);
+                    bPrev=true; bCancel=true;
                     break;
                     
                 case STAGE_COPY_FILES:
                     initCopyStage();
                     //prev=true; next=true; cancel=true;
                     copyFiles();
-                    prev=false; next=false; cancel=true;
+                    bPrev=false; bNext=false; bCancel=true;
                     break;
                     
                 case STAGE_SELECT_FOLDER:
-                    next=(etp!=null && etp.currentItem!=null && etp.currentItem instanceof MenuEditor);
-                    prev=false; cancel=true;
+                    bNext=(etp!=null && etp.currentItem!=null && etp.currentItem instanceof MenuEditor);
+                    bPrev=false; bCancel=true;
                     break;
                     
                 case STAGE_END:
                     initEndStage();
-                    next=true; prev=false; cancel=false;
+                    bNext=true; bPrev=false; bCancel=false;
                     break;
                     
                 case NUM_STAGES:
@@ -524,12 +517,12 @@ public class ProjectInstallerDlg extends ExtendedJDialog implements ProgressInpu
                     
             }
             
-            StringBuffer nbs=new StringBuffer("wizard_").append(currentStage<NUM_STAGES-1 ? "next" : "finish");
+            StringBuilder nbs=new StringBuilder("wizard_").append(currentStage<NUM_STAGES-1 ? "next" : "finish");
             nextBtn.setText(msg.get(nbs.substring(0)));
             nextBtn.setToolTipText(msg.get(nbs.append("_tooltip").substring(0)));
-            nextBtn.setEnabled(next);
-            prevBtn.setEnabled(prev);
-            cancelBtn.setEnabled(cancel);
+            nextBtn.setEnabled(bNext);
+            prevBtn.setEnabled(bPrev);
+            cancelBtn.setEnabled(bCancel);
             
             if(currentStage<NUM_STAGES){
                 java.awt.CardLayout cl=(java.awt.CardLayout)mainPane.getLayout();
@@ -550,6 +543,7 @@ public class ProjectInstallerDlg extends ExtendedJDialog implements ProgressInpu
                 if(etp!=null)
                     libFolderPanel.remove(etp);
                 etp=new EditorTreePanel(pl.getEditor(null), options, true, Menu.class){
+                    @Override
                     protected void currentItemChanged(){
                         if(currentStage==STAGE_SELECT_FOLDER){
                             nextBtn.setEnabled(currentItem!=null && currentItem instanceof MenuEditor);
@@ -619,7 +613,7 @@ public class ProjectInstallerDlg extends ExtendedJDialog implements ProgressInpu
     }
     
     private void copyFiles(){
-        final String PAUSED="PAUSED", ERROR="ERROR", OK="OK", CANCEL="CANCEL";
+        final String PAUSED="PAUSED", ERR="ERROR", OK="OK", CANCEL="CANCEL";
         final ProjectInstallerDlg cmp=ProjectInstallerDlg.this;
         
         // fer backup dels fitxers
@@ -628,10 +622,12 @@ public class ProjectInstallerDlg extends ExtendedJDialog implements ProgressInpu
         nextBtn.setEnabled(false);
         statusLb.setText(msg.get("install_msg_waiting"));
         
-        worker=new SwingWorker(){
+        worker=new edu.xtec.util.SwingWorker(){
+            
+            @Override
             public Object construct(){
                 workerRunning=true;
-                Vector fileBackups=new Vector();
+                ArrayList<FileBackup> fileBackups=new ArrayList<FileBackup>();
                 Exception ex=null;
                 String srcFolder=FileSystem.stdFn(storeFileSystem.getFullFileNamePath(null));
                 String destFolder=FileSystem.stdFn(installDir.getAbsolutePath());
@@ -677,7 +673,7 @@ public class ProjectInstallerDlg extends ExtendedJDialog implements ProgressInpu
                             //if(msg.confirmOverwriteFile(cmp, f, "yn")!=Messages.YES)
                             //    continue;
                             InputStream is=storeFileSystem.getInputStream(pi.getFile(i));
-                            ProgressInputStream pis=null;
+                            ProgressInputStream pis;
                             if(is instanceof ProgressInputStream)
                                 pis=(ProgressInputStream)is;
                             else{
@@ -723,6 +719,7 @@ public class ProjectInstallerDlg extends ExtendedJDialog implements ProgressInpu
                 return cancel ? CANCEL : OK;
             }
             
+            @Override
             public void finished(){
                 
                 Object result=get();
