@@ -21,18 +21,19 @@
 
 package edu.xtec.jclic.report;
 
-import java.sql.*;
-
-import edu.xtec.jclic.misc.Utils;
+import edu.xtec.util.StrUtils;
 import edu.xtec.util.db.ConnectionBean;
 import edu.xtec.util.db.ConnectionBeanProvider;
-import java.util.Vector;
+import java.sql.*;
+import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.23
  */
 public class BasicJDBCBridge extends Object {
     
@@ -70,7 +71,7 @@ public class BasicJDBCBridge extends Object {
     }
     
     public String getTableName(String tableName, String alias){
-        StringBuffer result=new StringBuffer();
+        StringBuilder result=new StringBuilder();
         if(tablePrefix!=null && tablePrefix.length()>0)
             result.append(tablePrefix);
         result.append(tableName);
@@ -177,11 +178,10 @@ public class BasicJDBCBridge extends Object {
                 rsx.close();
                 if(!tableExists){
                     Statement stmt=con.createStatement();
-                    StringBuffer sb=new StringBuffer("CREATE TABLE ");
+                    StringBuilder sb=new StringBuilder("CREATE TABLE ");
                     sb.append(tName).append("(");
                     String[] fields=(String[])TABLE_DEFS[i][1];
-                    for(int j=0; j<fields.length; j++){                        
-                        String sf=fields[j];
+                    for(String sf : fields){                        
                         if(DBMSType==ACCESS){
                             // Change INTEGER(x) for INTEGER
                             int intP=sf.indexOf("INTEGER(");
@@ -208,11 +208,11 @@ public class BasicJDBCBridge extends Object {
                     //System.out.println("CREATING TABLE "+tName);
                     stmt.executeUpdate(sb.substring(0));
                     if(i==0){
-                        for(int j=0; j<DEFAULT_SETTINGS.length; j++){
+                        for(String[] setting : DEFAULT_SETTINGS){
                             sb.setLength(0);
                             sb.append("INSERT INTO ").append(tName).append(" VALUES(")
-                            .append("'").append(DEFAULT_SETTINGS[j][0])
-                            .append("','").append(DEFAULT_SETTINGS[j][1]).append("')");
+                            .append("'").append(setting[0])
+                            .append("','").append(setting[1]).append("')");
                             stmt.executeUpdate(sb.substring(0));
                         }
                     }
@@ -236,6 +236,7 @@ public class BasicJDBCBridge extends Object {
         cbp=null;
     }
     
+    @Override
     protected void finalize() throws Throwable{
         end();
         super.finalize();
@@ -267,8 +268,8 @@ public class BasicJDBCBridge extends Object {
         return result;
     }
     
-    public HashMap getProperties() throws Exception{
-        HashMap result=new HashMap();
+    public Map<String, String> getProperties() throws Exception{
+        Map<String, String> result=new HashMap<String, String>();
         Exception ex=null;
         ConnectionBean cb=cbp.getConnectionBean();
         PreparedStatement stmt=null;
@@ -291,8 +292,8 @@ public class BasicJDBCBridge extends Object {
         return result;
     }
     
-    public Vector getGroups() throws Exception{
-        Vector result=new Vector();
+    public List<GroupData> getGroups() throws Exception{
+        ArrayList<GroupData> result=new ArrayList<GroupData>();
         Exception ex=null;
         ConnectionBean cb=cbp.getConnectionBean();
         PreparedStatement stmt=null;
@@ -327,13 +328,13 @@ public class BasicJDBCBridge extends Object {
         return result;
     }
     
-    public Vector getUsers(String groupId) throws Exception{
-        Vector result=new Vector();
+    public List<UserData> getUsers(String groupId) throws Exception{
+        ArrayList<UserData> result=new ArrayList<UserData>();
         Exception ex=null;
         ConnectionBean cb=cbp.getConnectionBean();
         PreparedStatement stmt=null;
         try{
-            StringBuffer sb=new StringBuffer(
+            StringBuilder sb=new StringBuilder(
             "SELECT USER_NAME,USER_ICON,USER_ID,USER_PWD,GROUP_ID");
             sb.append(" FROM ").append(getTableName("USERS"));
             if(groupId!=null)
@@ -437,7 +438,7 @@ public class BasicJDBCBridge extends Object {
             throw new Exception("Invalid UserId");
         if(projectName==null)
             throw new Exception("Invalid ProjectName");
-        sessionId=userId.concat("_").concat(Long.toString(time));
+        sessionId=StrUtils.limitStrLen(userId, 36).concat("_").concat(Long.toString(time));
         ConnectionBean cb=cbp.getConnectionBean();
         PreparedStatement stmt=null;
         try{
@@ -448,10 +449,10 @@ public class BasicJDBCBridge extends Object {
             stmt.setString(1, sessionId);
             stmt.setString(2, userId);
             stmt.setTimestamp(3, new Timestamp(time));
-            stmt.setString(4, projectName);
-            stmt.setString(5, sessionKey);
-            stmt.setString(6, sessionCode);
-            stmt.setString(7, sessionContext);
+            stmt.setString(4, StrUtils.limitStrLen(projectName,100));
+            stmt.setString(5, StrUtils.limitStrLen(sessionKey,50));
+            stmt.setString(6, StrUtils.limitStrLen(sessionCode,50));
+            stmt.setString(7, StrUtils.limitStrLen(sessionContext,50));
             stmt.executeUpdate();
         } catch(Exception e){
             ex=e;
@@ -485,13 +486,13 @@ public class BasicJDBCBridge extends Object {
             " VALUES(?,?,?,?,?,?,?,?,?)");
             stmt.setString(1, sessionId);
             stmt.setInt(2, activityId);
-            stmt.setString(3, name);
+            stmt.setString(3, StrUtils.limitStrLen(name,50));
             stmt.setInt(4, actions);
             stmt.setInt(5, score);
             stmt.setInt(6, solved ? 1 : 0);
             stmt.setInt(7, precision);
             stmt.setInt(8, time);
-            stmt.setString(9, activityCode);
+            stmt.setString(9, StrUtils.limitStrLen(activityCode,50));
             stmt.executeUpdate();
         } catch(Exception e){
             ex=e;
@@ -529,8 +530,8 @@ public class BasicJDBCBridge extends Object {
             stmt.setInt(2, activityId);
             stmt.setInt(3, actionId);
             stmt.setString(4, type);
-            stmt.setString(5, source);
-            stmt.setString(6, dest);
+            stmt.setString(5, StrUtils.limitStrLen(source,255));
+            stmt.setString(6, StrUtils.limitStrLen(dest,255));
             stmt.setInt(7, isOk ? 1 : 0);
             stmt.executeUpdate();
         } catch(Exception e){
@@ -546,7 +547,7 @@ public class BasicJDBCBridge extends Object {
     
     public String newGroup(GroupData gd) throws Exception{
         Exception ex=null;
-        StringBuffer sb=new StringBuffer(
+        StringBuilder sb=new StringBuilder(
         "INSERT INTO "+getTableName("GROUPS")+
         " (GROUP_ID,GROUP_NAME");
         int n=0;
@@ -568,12 +569,12 @@ public class BasicJDBCBridge extends Object {
         try{
             stmt=cb.getPreparedStatement(sb.substring(0));
             n=1;
-            stmt.setString(n++, gd.getId());
-            stmt.setString(n++, gd.getText());
+            stmt.setString(n++, StrUtils.limitStrLen(gd.getId(),50));
+            stmt.setString(n++, StrUtils.limitStrLen(gd.getText(),80));
             if(gd.hasIcon())
-                stmt.setString(n++, gd.getIconUrl());
+                stmt.setString(n++, StrUtils.limitStrLen(gd.getIconUrl(),255));
             if(gd.description!=null && gd.description.length()>0)
-                stmt.setString(n++, gd.description);
+                stmt.setString(n++, StrUtils.limitStrLen(gd.description,255));
             stmt.executeUpdate();
         } catch(Exception e){
             ex=e;
@@ -588,7 +589,7 @@ public class BasicJDBCBridge extends Object {
     
     public String newUser(UserData ud) throws Exception{
         Exception ex=null;
-        StringBuffer sb=new StringBuffer(
+        StringBuilder sb=new StringBuilder(
         "INSERT INTO "+getTableName("USERS")+
         " (GROUP_ID,USER_ID,USER_NAME");
         int n=0;
@@ -611,12 +612,12 @@ public class BasicJDBCBridge extends Object {
             stmt=cb.getPreparedStatement(sb.substring(0));
             n=1;
             stmt.setString(n++, ud.groupId);
-            stmt.setString(n++, ud.getId());
-            stmt.setString(n++, ud.getText());
+            stmt.setString(n++, StrUtils.limitStrLen(ud.getId(),50));
+            stmt.setString(n++, StrUtils.limitStrLen(ud.getText(),80));
             if(ud.hasIcon())
-                stmt.setString(n++, ud.getIconUrl());
+                stmt.setString(n++, StrUtils.limitStrLen(ud.getIconUrl(),255));
             if(ud.pwd!=null && ud.pwd.length()>0)
-                stmt.setString(n++, ud.pwd);
+                stmt.setString(n++, StrUtils.limitStrLen(ud.pwd,255));
             stmt.executeUpdate();
         } catch(Exception e){
             ex=e;
