@@ -19,28 +19,23 @@
  * GNU General Public License for more details (see the LICENSE file).
  */
 
-import edu.xtec.util.*;
-import edu.xtec.jclic.report.*;
-
-import java.net.Socket;
-import java.util.*;
-import java.text.*;
-import javax.swing.*;
-import javax.swing.border.*;
-import javax.swing.table.*;
-import edu.xtec.util.Options;
-import java.io.File;
-import java.io.FileInputStream;
 import edu.xtec.jclic.ReportServerConstants;
-import java.io.FileOutputStream;
+import edu.xtec.jclic.report.*;
 import edu.xtec.jclic.report.rp.JClicReportService;
 import edu.xtec.jclic.skins.AboutWindow;
+import edu.xtec.util.*;
 import edu.xtec.util.db.ConnectionBeanProvider;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileOutputStream;
+import java.text.*;
+import java.util.*;
+import javax.swing.*;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.17
  */
 public class ReportServer extends javax.swing.JFrame implements ReportServerConstants, ResourceBridge {
     
@@ -76,7 +71,7 @@ public class ReportServer extends javax.swing.JFrame implements ReportServerCons
                 cfgFile=new File(System.getProperty("user.dir"), args[0]);
         }
         if(cfgFile==null || !cfgFile.exists())
-            cfgFile=new File(edu.xtec.util.PersistentSettings.getFilePath(edu.xtec.jclic.Constants.PROGRAM, CFG_FILE, options));
+            cfgFile=new File(edu.xtec.util.PersistentSettings.getFilePath(edu.xtec.jclic.Constants.PROGRAM, CFG_FILE, options, true));
         
         Properties prop=new Properties();
         try{
@@ -113,7 +108,7 @@ public class ReportServer extends javax.swing.JFrame implements ReportServerCons
             startWebServer();
     }
     
-    protected void loadSettings() throws Exception{
+    private void loadSettings() throws Exception{
         
         edu.xtec.jclic.report.rp.ReportsRequestProcessor.setProperties(options.toProperties());
         msg=edu.xtec.util.PersistentSettings.getMessages(options, MSG_BUNDLE);        
@@ -147,7 +142,7 @@ public class ReportServer extends javax.swing.JFrame implements ReportServerCons
         }
     }
     
-    protected void startWebServer(){
+    private void startWebServer(){
         
         if(httpServer.startServer(httpPort, httpTimeOut)){
             startWebServerBtn.setEnabled(false);
@@ -408,9 +403,8 @@ public class ReportServer extends javax.swing.JFrame implements ReportServerCons
         if(dlg.result){
             if(cfgFile!=null){
                 try{
-                    String pwd=null;
                     Properties prop=options.toProperties();
-                    pwd=prop.getProperty(ConnectionBeanProvider.DB_PASSWORD, "");
+                    String pwd=prop.getProperty(ConnectionBeanProvider.DB_PASSWORD, "");
                     if(pwd!=null && pwd.length()>0)
                         prop.put(ConnectionBeanProvider.DB_PASSWORD, Encryption.Encrypt(pwd));
                     FileOutputStream os=new FileOutputStream(cfgFile);
@@ -481,7 +475,7 @@ public class ReportServer extends javax.swing.JFrame implements ReportServerCons
         
         public void reportEventPerformed(ReportServerEvent ev) {
             if(webVerbose || ev.type==ReportServerEvent.SYSTEM){
-                StringBuffer sb=new StringBuffer(100);
+                StringBuilder sb=new StringBuilder(100);
                 sb.append(dateFormat.format(new Date()));
                 sb.append(" ").append(ev.toString());
                 if(writer!=null)
