@@ -21,16 +21,18 @@
 
 package edu.xtec.jclic.report;
 
+import edu.xtec.util.StrUtils;
 import edu.xtec.util.db.ConnectionBean;
 import edu.xtec.util.db.ConnectionBeanProvider;
 import java.sql.*;
+import java.util.ArrayList;
 import java.util.Calendar;
-import java.util.Vector;
-import java.util.HashMap;
+import java.util.List;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.23
  */
 public class ReportServerJDBCBridge extends BasicJDBCBridge{
     
@@ -42,22 +44,26 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
     
     public ReportServerJDBCBridge(ConnectionBeanProvider cbp, boolean createTables, String tablePrefix) throws Exception{
         super(cbp, createTables, tablePrefix);
-        ConnectionBean cb=cbp.getConnectionBean();        
+        ConnectionBean cb=cbp.getConnectionBean();
+
+        // Changed 20-Dec-2010: Set default behavior to MySQL instead of MS-Access
+        // TODO: Check code with PostgreSQL
         switch (DBMSType){
-            case MYSQL:
-                GROUP_SESSION_DATE_STRING="s.SESSION_DATETIME";
-                ORDER_QUALIFICATION_1_STRING="sum(QUALIFICATION)/count(*) AS qf"; //std as in Oracle
-                ORDER_QUALIFICATION_2_STRING="qf";
+            case ACCESS:
+                GROUP_SESSION_DATE_STRING="Format(s.SESSION_DATETIME,'yyyy/mm/dd')";
+                ORDER_QUALIFICATION_1_STRING="sum(QUALIFICATION)/count(*)";
+                ORDER_QUALIFICATION_2_STRING=ORDER_QUALIFICATION_1_STRING;
                 break;
             case ORACLE:
                 GROUP_SESSION_DATE_STRING="trunc(s.SESSION_DATETIME)";
                 ORDER_QUALIFICATION_1_STRING="sum(QUALIFICATION)/count(*) AS qf";
                 ORDER_QUALIFICATION_2_STRING="qf";
                 break;
-            default: //MS-Access & Other
-                GROUP_SESSION_DATE_STRING="Format(s.SESSION_DATETIME,'yyyy/mm/dd')";
-                ORDER_QUALIFICATION_1_STRING="sum(QUALIFICATION)/count(*)";
-                ORDER_QUALIFICATION_2_STRING=ORDER_QUALIFICATION_1_STRING;
+            case MYSQL:
+            default: //MYSQL & Other
+                GROUP_SESSION_DATE_STRING="s.SESSION_DATETIME";
+                ORDER_QUALIFICATION_1_STRING="sum(QUALIFICATION)/count(*) AS qf"; //std as in Oracle
+                ORDER_QUALIFICATION_2_STRING="qf";
                 break;
         }
     }
@@ -98,7 +104,7 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
     }
     
     private String getFilteringStringQuery(String[] kcc, boolean and){
-        StringBuffer sb=new StringBuffer(200);
+        StringBuilder sb=new StringBuilder(200);
         if(kcc!=null){
             for(int i=0; i<KCC.length; i++){
                 if(kcc[i]!=null && kcc[i].length()>0){
@@ -118,13 +124,13 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
         return n;
     }
     
-    public Vector getInfoSessionUser(String userId, String projectName, java.util.Date dateFrom, java.util.Date dateTo, String[] kcc, boolean groupByDate) throws Exception{
+    public List<SessionData> getInfoSessionUser(String userId, String projectName, java.util.Date dateFrom, java.util.Date dateTo, String[] kcc, boolean groupByDate) throws Exception{
         Exception ex=null;
-        Vector vInfoSessions=new Vector();
+        List<SessionData> vInfoSessions=new ArrayList<SessionData>();
         String proj=null;
         if(projectName!=null && projectName.length()>0 && !projectName.equals("-1"))
             proj=projectName;
-        StringBuffer sb=new StringBuffer(300);
+        StringBuilder sb=new StringBuilder(300);
         sb.append("SELECT ").append(GROUP_SESSION_DATE_STRING)
         .append(", s.SESSION_ID, s.PROJECT_NAME, count(*)")
         .append(", sum(QUALIFICATION), sum(a.ACTIVITY_SOLVED), sum(a.TOTAL_TIME)")
@@ -166,8 +172,10 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
                 rs.getInt(5), // totalPrec
                 Math.max(0, rs.getInt(7))); // totalTime
                 if(groupByDate){
-                    if(sd.sameDate(sdx))
-                        sdx.acumula(sd);
+                    if(sd.sameDate(sdx)){
+                        if(sdx!=null)
+                            sdx.acumula(sd);
+                    }
                     else{
                         if(sdx!=null)
                             vInfoSessions.add(sdx);
@@ -191,14 +199,14 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
         return vInfoSessions;
     }
     
-    public Vector getInfoSessionGroup(String groupId, String projectName, java.util.Date dateFrom, java.util.Date dateTo, String[] kcc, boolean groupByDate) throws Exception{
+    public List<SessionData> getInfoSessionGroup(String groupId, String projectName, java.util.Date dateFrom, java.util.Date dateTo, String[] kcc, boolean groupByDate) throws Exception{
         Exception ex=null;
-        Vector vInfoSessions=new Vector();
+        List<SessionData> vInfoSessions=new ArrayList<SessionData>();
         String proj=null;
         if(projectName!=null && projectName.length()>0 && !projectName.equals("-1"))
             proj=projectName;
         
-        StringBuffer sb=new StringBuffer(300);
+        StringBuilder sb=new StringBuilder(300);
         sb.append("SELECT ").append(GROUP_SESSION_DATE_STRING)
         .append(", s.SESSION_ID, s.PROJECT_NAME, count(*), sum(QUALIFICATION), sum(a.ACTIVITY_SOLVED), sum(a.TOTAL_TIME), s.USER_ID")
         .append(" FROM ")
@@ -239,8 +247,10 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
                 rs.getInt(5), // totalPrec
                 Math.max(0, rs.getInt(7))); // totalTime
                 if(groupByDate){
-                    if(sd.sameDate(sdx))
-                        sdx.acumula(sd);
+                    if(sd.sameDate(sdx)){
+                        if(sdx!=null)
+                            sdx.acumula(sd);
+                    }
                     else{
                         if(sdx!=null)
                             vInfoSessions.add(sdx);
@@ -264,14 +274,14 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
         return vInfoSessions;
     }
     
-    public Vector getInfoSessionAct(String projectName, String activityName, java.util.Date dateFrom, java.util.Date dateTo, String[] kcc, boolean groupByDate) throws Exception{
+    public List<SessionData> getInfoSessionAct(String projectName, String activityName, java.util.Date dateFrom, java.util.Date dateTo, String[] kcc, boolean groupByDate) throws Exception{
         Exception ex=null;
-        Vector vInfoSessions=new Vector();
+        List<SessionData> vInfoSessions=new ArrayList<SessionData>();
         String act=null;
         if(activityName!=null && activityName.length()>0 && !activityName.equals("-1"))
             act=activityName;
         
-        StringBuffer sb=new StringBuffer(300);
+        StringBuilder sb=new StringBuilder(300);
         sb.append("SELECT ").append(GROUP_SESSION_DATE_STRING)
         .append(", s.SESSION_ID, s.PROJECT_NAME, count(*), sum(QUALIFICATION), sum(a.ACTIVITY_SOLVED), sum(a.TOTAL_TIME), s.USER_ID")
         .append(" FROM ").append(getTableName("SESSIONS", "s"))
@@ -310,8 +320,10 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
                 rs.getInt(5), // totalPrec
                 Math.max(0, rs.getInt(7))); // totalTime
                 if(groupByDate){
-                    if(sd.sameDate(sdx))
-                        sdx.acumula(sd);
+                    if(sd.sameDate(sdx)){
+                        if(sdx!=null)
+                            sdx.acumula(sd);
+                    }
                     else{
                         if(sdx!=null)
                             vInfoSessions.add(sdx);
@@ -336,17 +348,16 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
     }
         
     public boolean hasUserTables() throws Exception{
-        boolean result=true;
         String s = getProperty("USER_TABLES", null);
-        result = s==null || !s.trim().toLowerCase().equals("false");
+        boolean result = s==null || !s.trim().toLowerCase().equals("false");
         return result;
     }
     
-    public Vector getProjList(String userId,  java.util.Date dateFrom, java.util.Date dateTo, String[] kcc) throws Exception{
+    public List<String> getProjList(String userId,  java.util.Date dateFrom, java.util.Date dateTo, String[] kcc) throws Exception{
         Exception ex=null;
-        Vector pl=new Vector();
+        List<String> pl=new ArrayList<String>();
         
-        StringBuffer sb=new StringBuffer(300);
+        StringBuilder sb=new StringBuilder(300);
         sb.append("SELECT distinct(PROJECT_NAME)")
         .append(" FROM ").append(getTableName("SESSIONS", "s"))
         .append(" WHERE s.SESSION_DATETIME>=? AND s.SESSION_DATETIME<=?");
@@ -364,7 +375,7 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
             stmt.setTimestamp(n++, new Timestamp(dateTo.getTime()));
             if(userId!=null)
                 stmt.setString(n++, userId);
-            n=updateFiltering(stmt, kcc, n);
+            updateFiltering(stmt, kcc, n);
             
             ResultSet result=stmt.executeQuery();
             while (result.next())
@@ -381,14 +392,14 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
         return pl;
     }
     
-    public Vector getProjListGrup(String groupId,  java.util.Date dateFrom, java.util.Date dateTo, String[] kcc) throws Exception{
+    public List<String> getProjListGrup(String groupId,  java.util.Date dateFrom, java.util.Date dateTo, String[] kcc) throws Exception{
         /* Returns a ProjList containing the list of the names of all projects made by the users of the
          group 'groupName' in the time interval indicated. Information is only returned if
          validated==true or if the projects wher made in sessions where sessionKey==pass. */
         Exception ex=null;
-        Vector pl=new Vector();
+        List<String> pl=new ArrayList<String>();
         
-        StringBuffer sb=new StringBuffer(300);
+        StringBuilder sb=new StringBuilder(300);
         sb.append("SELECT distinct(PROJECT_NAME)")
         .append(" FROM ").append(getTableName("SESSIONS", "s"))
         .append(", ").append(getTableName("GROUPS", "g"))
@@ -409,7 +420,7 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
             stmt.setTimestamp(n++, new Timestamp(dateTo.getTime()));
             if(groupId!=null)
                 stmt.setString(n++, groupId);
-            n=updateFiltering(stmt, kcc, n);
+            updateFiltering(stmt, kcc, n);
             
             ResultSet result=stmt.executeQuery();
             while (result.next())
@@ -426,11 +437,11 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
         return pl;
     }
     
-    public Vector getActList(String prj,  java.util.Date dateFrom, java.util.Date dateTo, String[] kcc) throws Exception{
+    public List<String> getActList(String prj,  java.util.Date dateFrom, java.util.Date dateTo, String[] kcc) throws Exception{
         Exception ex=null;
-        Vector pl=new Vector();
+        List<String> pl=new ArrayList<String>();
         
-        StringBuffer sb=new StringBuffer(300);
+        StringBuilder sb=new StringBuilder(300);
         sb.append("SELECT distinct(ACTIVITY_NAME)")
         .append(" FROM ").append(getTableName("ACTIVITIES", "a"))
         .append(", ").append(getTableName("SESSIONS", "s"))
@@ -450,7 +461,7 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
             stmt.setTimestamp(n++, new Timestamp(dateTo.getTime()));
             if(prj!=null)
                 stmt.setString(n++, prj);
-            n=updateFiltering(stmt, kcc, n);
+            updateFiltering(stmt, kcc, n);
             
             ResultSet result=stmt.executeQuery();
             while (result.next())
@@ -467,14 +478,14 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
         return pl;
     }
     
-    public Vector getPacSessionList(String userId, String proj, String sessionId, java.util.Date dFrom, java.util.Date dTo, String[] kcc) throws Exception{
+    public List<ActivityData> getPacSessionList(String userId, String proj, String sessionId, java.util.Date dFrom, java.util.Date dTo, String[] kcc) throws Exception{
         /* Returns a PacSessionList with all the info needed to show the table with information about the activities
          made in the session 'sessionId' corresponding to the user 'userId' in the indicated date interval . Data ara only returned
 	when validated==true or when the invloucrated sessions where created with sessionKey==pass. */
         
         Exception ex=null;
-        Vector v=new Vector();
-        StringBuffer sb=new StringBuffer(300);
+        List<ActivityData> v=new ArrayList<ActivityData>();
+        StringBuilder sb=new StringBuilder(300);
         sb.append("SELECT s.PROJECT_NAME, a.ACTIVITY_ID, a.ACTIVITY_NAME, a.NUM_ACTIONS")
         .append(" ,a.SCORE, a.ACTIVITY_SOLVED, a.QUALIFICATION, a.TOTAL_TIME")
         .append(" FROM ").append(getTableName("ACTIVITIES", "a"))
@@ -544,12 +555,12 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
             create
             ? "INSERT INTO "+tn+" (USER_NAME,USER_ICON,USER_PWD,USER_ID,GROUP_ID) VALUES (?,?,?,?,?)"
             : "UPDATE "+tn+" SET USER_NAME=?, USER_ICON=?, USER_PWD=? WHERE USER_ID=?");
-            stmt.setString(1, ud.getText());
+            stmt.setString(1, StrUtils.limitStrLen(ud.getText(),80));
             if(ud.getIconUrl()!=null && ud.getIconUrl().length()==0)
                 ud.setIconUrl(null);
-            stmt.setString(2, ud.getIconUrl());
-            stmt.setString(3, ud.pwd);
-            stmt.setString(4, ud.getId());
+            stmt.setString(2, StrUtils.limitStrLen(ud.getIconUrl(),255));
+            stmt.setString(3, StrUtils.limitStrLen(ud.pwd,255));
+            stmt.setString(4, StrUtils.limitStrLen(ud.getId(),50));
             if(create)
                 stmt.setString(5, ud.groupId);
             result=stmt.executeUpdate()>0;            
@@ -576,11 +587,11 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
             create
             ? "INSERT INTO "+tn+" (GROUP_NAME,GROUP_ICON,GROUP_ID) VALUES (?,?,?)"
             : "UPDATE "+tn+" SET GROUP_NAME=?, GROUP_ICON=? WHERE GROUP_ID=?");
-            stmt.setString(1, gd.getText());
+            stmt.setString(1, StrUtils.limitStrLen(gd.getText(),80));
             if(gd.getIconUrl()!=null && gd.getIconUrl().length()==0)
                 gd.setIconUrl(null);
-            stmt.setString(2, gd.getIconUrl());
-            stmt.setString(3, gd.getId());
+            stmt.setString(2, StrUtils.limitStrLen(gd.getIconUrl(),255));
+            stmt.setString(3, StrUtils.limitStrLen(gd.getId(),50));
             result=stmt.executeUpdate()>0;
         } catch(Exception e){
             ex=e;
@@ -596,7 +607,7 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
     
     public void clearUserReportData(String userId, java.util.Date dFrom, java.util.Date dTo) throws Exception{
         Exception ex=null;
-        StringBuffer sb=new StringBuffer(300);
+        StringBuilder sb=new StringBuilder(300);
         sb.append("SELECT SESSION_ID")
         .append(" FROM ").append(getTableName("SESSIONS"))
         .append(" WHERE USER_ID=?"); //Index for GROUP_ID into users. It will be faster with groups, but MySQL doesn't have foreign keys...
@@ -629,7 +640,7 @@ public class ReportServerJDBCBridge extends BasicJDBCBridge{
     
     public void clearGroupReportData(String groupId, java.util.Date dFrom, java.util.Date dTo) throws Exception{
         Exception ex=null;
-        StringBuffer sb=new StringBuffer(300);
+        StringBuilder sb=new StringBuilder(300);
         sb.append("SELECT SESSION_ID")
         .append(" FROM ").append(getTableName("SESSIONS", "s"))
         .append(", ").append(getTableName("USERS", "u"))
