@@ -21,22 +21,28 @@
 
 package edu.xtec.jclic.report.rp;
 
-import java.awt.*;
-import java.awt.image.BufferedImage;
-import java.util.ResourceBundle;
-import java.util.Vector;
-import java.util.Enumeration;
-import java.awt.font.LineMetrics;
-import edu.xtec.jclic.report.SessionData;
-import java.util.Iterator;
-import java.util.Date;
-import java.text.DecimalFormat;
 import edu.xtec.jclic.report.ActivityData;
+import edu.xtec.jclic.report.SessionData;
+import static edu.xtec.servlet.RequestProcessor.CONTENT_TYPE;
+import java.awt.BasicStroke;
+import java.awt.Color;
+import java.awt.Font;
+import java.awt.FontMetrics;
+import java.awt.Graphics2D;
+import java.awt.Rectangle;
+import java.awt.Stroke;
+import java.awt.image.BufferedImage;
+import java.text.DecimalFormat;
+import java.util.Date;
+import java.util.Iterator;
+import java.util.List;
+import java.util.ResourceBundle;
 import javax.imageio.ImageIO;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.17
  */
 public class Img extends BasicReport {
     
@@ -48,7 +54,7 @@ public class Img extends BasicReport {
     public static final String USER_GRAPH="userGraph", GROUP_GRAPH="groupGraph",
     PROJECT_GRAPH="projectGraph";
     
-    public static int DEFAULT_WIDTH, DIST_WIDTH, DEFAULT_HEIGHT, 
+    public static int DEFAULT_WIDTH=0, DIST_WIDTH, DEFAULT_HEIGHT, 
     DEFAULT_HEADER_HEIGHT, MRG;
     
     public static Color BG_COLOR, TEXT_COLOR, BORDER_COLOR,
@@ -87,6 +93,7 @@ public class Img extends BasicReport {
         return URL;
     }
     
+    @Override
     public boolean noCache(){
         return false;
     }
@@ -128,6 +135,7 @@ public class Img extends BasicReport {
         M_Y_DIST=Integer.parseInt(prop.getProperty(GRAPH_MARGIN_DIST_Y, "20"));        
     }
     
+    @Override
     public boolean init() throws Exception{
         
         if(!super.init())
@@ -168,16 +176,19 @@ public class Img extends BasicReport {
         return true;
     };
     
-    public void header(java.util.Vector v){
+    @Override
+    public void header(List<String[]> v){
         //super.header(v);
         //v.add(new String[]{CONTENT_TYPE, "image/gif"});
         v.add(new String[]{CONTENT_TYPE, "image/png"});
     }
     
+    @Override
     public boolean usesWriter(){
         return false;
     }
     
+    @Override
     public void process(java.io.OutputStream out) throws Exception {
         
         BufferedImage bi=new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
@@ -248,7 +259,7 @@ public class Img extends BasicReport {
         g2.drawString(bundle.getString(titleKey), box.x+MRG, box.y+dy+fm.getAscent());
     }
     
-    public void dibuixaImatge(Graphics2D g2, Vector v, Rectangle box) throws Exception{
+    public void dibuixaImatge(Graphics2D g2, List<SessionData> v, Rectangle box) throws Exception{
         
         g2.setColor(TEXT_COLOR);
         g2.setStroke(THIN_STROKE);
@@ -300,8 +311,8 @@ public class Img extends BasicReport {
             Date dataFinal=null;
             boolean validat=true; //De moment mostrem les dades, quan trobem una a la que no te acces pararem.
             for(i=0; i<columnesArgs && validat; i++){
-                SessionData sd1=(SessionData)v.get(i);
-                SessionData sd2=(SessionData)v.get(i+1);
+                SessionData sd1=v.get(i);
+                SessionData sd2=v.get(i+1);
                 
                 if (puntsDePas[j]==i){ //mostrem punt i columna
                     g2.setColor(TEXT_COLOR);
@@ -339,7 +350,7 @@ public class Img extends BasicReport {
     }
     
     public static final int N_DIST_ELEMENTS=5;
-    public void dibuixaDistribucio(Graphics2D g2, Vector v, Rectangle box){
+    public void dibuixaDistribucio(Graphics2D g2, List v, Rectangle box){
   
         int[] dist=new int[N_DIST_ELEMENTS];
         Iterator it=v.iterator();
@@ -412,7 +423,7 @@ public class Img extends BasicReport {
                 g2.drawLine(
                 box.x+leftMargin+(int)(i*longColumnaX), box.y+topMargin,
                 box.x+leftMargin+(int)(i*longColumnaX), box.y+topMargin+gHeight);
-                StringBuffer sb=new StringBuffer(Integer.toString(i*20));
+                StringBuilder sb=new StringBuilder(Integer.toString(i*20));
                 sb.append("%");
                 g2.drawString(sb.substring(0),
                 box.x+leftMargin+(int)(i*longColumnaX),
