@@ -21,18 +21,20 @@
 
 package edu.xtec.jclic.report.rp;
 
-import java.util.Vector;
+import edu.xtec.jclic.report.ActivityData;
+import edu.xtec.jclic.report.GroupData;
 import edu.xtec.jclic.report.ReportUtils;
+import edu.xtec.jclic.report.SessionData;
+import edu.xtec.jclic.report.UserData;
 import java.util.HashSet;
 import java.util.Iterator;
-import edu.xtec.jclic.report.SessionData;
-import edu.xtec.util.Html;
-import edu.xtec.jclic.report.ActivityData;
-import edu.xtec.jclic.report.UserData;
+import java.util.List;
+import java.util.Set;
 
 /**
  *
- * @author  Francesc Busquets (fbusquets@xtec.net)
+ * @author  Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.17
  */
 public abstract class Report extends BasicReport {
     
@@ -45,8 +47,11 @@ public abstract class Report extends BasicReport {
     protected String change;
     protected String opcioDefecte;
     protected Object[] session;
-    protected Vector groups, users, projects;
+    protected List<GroupData> groups;
+    protected List<UserData> users;
+    protected List projects;
     
+    @Override
     public boolean init() throws Exception{
         
         if(!super.init())
@@ -57,10 +62,8 @@ public abstract class Report extends BasicReport {
         
         if(userTables){	  
         	groups=bridge.getGroups();
-        	//groupList=vToArray(bridge.getGroups(), 2, 0);        
         	if(groupId.length()>0)
-            	users=bridge.getUsers(groupId);
-            	//userList=vToArray(bridge.getUsers(groupId), 2, 0);
+            	   users=bridge.getUsers(groupId);
 	  }
         
         session=getParams(SESSION);        
@@ -92,18 +95,20 @@ public abstract class Report extends BasicReport {
         return true;
     }
     
+    @Override
     public void head(java.io.PrintWriter out) throws Exception{
         super.head(out);
-        StringBuffer sb=new StringBuffer(300);
+        StringBuilder sb=new StringBuilder(300);
         writeGoScript(sb);
         dm.writeDateScript(sb);
         out.println(sb.substring(0));
     }
     
+    @Override
     public void body(java.io.PrintWriter out) throws Exception{
         
         super.body(out);
-        StringBuffer sb=new StringBuffer(2000);
+        StringBuilder sb=new StringBuilder(2000);
         
         if(isEditable)
             sb.append(linkTo(urlParam(Main.URL, LANG, lang), bundle.getString(Main.TITLE), null));
@@ -127,7 +132,7 @@ public abstract class Report extends BasicReport {
         out.println(sb.substring(0));
     }
     
-    protected void writeGoScript(StringBuffer sb){
+    protected void writeGoScript(StringBuilder sb){
         sb.append("<script language=\"JavaScript\" type=\"text/javascript\">\n");
         sb.append("<!--\n");
         sb.append(" function go(canvi){\n");
@@ -138,7 +143,7 @@ public abstract class Report extends BasicReport {
         sb.append("</script>\n");
     }
     
-    protected void writeSessionScript(StringBuffer sb){
+    protected void writeSessionScript(StringBuilder sb){
         sb.append("<script language=\"JavaScript\" type=\"text/javascript\">\n");
         sb.append("<!--\n");
         sb.append(" function session(id,v){\n");
@@ -149,7 +154,7 @@ public abstract class Report extends BasicReport {
         sb.append("</script>\n");
     }
         
-    protected void llista(StringBuffer sb, String selectName, boolean submitOnChange,
+    protected void llista(StringBuilder sb, String selectName, boolean submitOnChange,
     String defaultOption, String[][] values, String selectedValue, int width){
         /* Mostra una llista desplegable (objecte SELECT) amb opcions
          */
@@ -182,7 +187,7 @@ public abstract class Report extends BasicReport {
         sb.append("</select>\n");
     }
     
-    protected void zona(StringBuffer sb, String descKey, String selectName,
+    protected void zona(StringBuilder sb, String descKey, String selectName,
     boolean submitOnChange, String defaultOption, String[][] values,
     String selectedValue, boolean showList, int width){
         sb.append("<p>").append(filter(getMsg(descKey))).append("&nbsp;");
@@ -205,16 +210,16 @@ public abstract class Report extends BasicReport {
         sb.append("</p>\n");
     }
     
-    protected void zonaData(StringBuffer sb){
+    protected void zonaData(StringBuilder sb){
 
-        StringBuffer sb2=new StringBuffer(100);
+        StringBuilder sb2=new StringBuilder(100);
         sb2.append("go('").append(DATE).append("')");
         dm.zonaData(sb, buttonAction(sb2.substring(0), getMsg("submit"), null));
     }
     
     
     public static final String[] KCC_LABELS={"report_key", "report_code", "report_context"};
-    protected void zonaParams(StringBuffer sb){
+    protected void zonaParams(StringBuilder sb){
         sb.append("<div class=\"inputForm\" id=\"compact\">\n");
         for(int i=0; i<KCC.length; i++){
             sb.append("<p>");
@@ -231,26 +236,12 @@ public abstract class Report extends BasicReport {
         sb.append("</div>\n");
     }
 
-    /*
-    protected void zonaParam(StringBuffer sb, String key, String value, String descKey, boolean hidden){
-        //sb.append("<TD ALIGN=\"right\">");
-        if(!hidden)
-            sb.append(filter(getMsg(descKey))).append("&nbsp;");
-        sb.append("<input name=\"").append(key).append("\" size=\"8\"");
-        if(value!=null)
-            sb.append(" value=\"").append(filter(value)).append("\"");
-        if(hidden)
-            sb.append(" type=\"hidden\"");
-        sb.append(">\n");
-    }
-     */
-    
-    protected void grafic(StringBuffer sb, String type, boolean dist, boolean withHeader) throws Exception{
+    protected void grafic(StringBuilder sb, String type, boolean dist, boolean withHeader) throws Exception{
         
         int w=dist ? Img.DIST_WIDTH : Img.DEFAULT_WIDTH;
         int h=Img.DEFAULT_HEIGHT+Img.DEFAULT_HEADER_HEIGHT;
         
-        StringBuffer urlG=new StringBuffer(300);
+        StringBuilder urlG=new StringBuilder(300);
         urlG.append(Img.URL);
         urlParamSb(urlG, Img.TYPE, type, true);
         if(dist)
@@ -271,13 +262,13 @@ public abstract class Report extends BasicReport {
             urlParamSb(urlG, ACTIVITY, activityName, false);
         for(int i=0; i<KCC.length; i++)
             urlParamSb(urlG, KCC[i], kcc[i], false);
-        urlParamSb(urlG, dm.FROM, ReportUtils.dateToStr(dm.dFrom), false);
-        urlParamSb(urlG, dm.TO, ReportUtils.dateToStr(dm.dTo), false);
+        urlParamSb(urlG, DateManager.FROM, ReportUtils.dateToStr(dm.dFrom), false);
+        urlParamSb(urlG, DateManager.TO, ReportUtils.dateToStr(dm.dTo), false);
         
         sb.append("<img src=\"").append(urlG).append("\" width=\"").append(w).append("\" height=\"").append(h).append("\">");
     }
     
-    protected void llistaSessions(StringBuffer sb, Vector v, boolean expandable, String className, String style) throws Exception{
+    protected void llistaSessions(StringBuilder sb, List<SessionData> v, boolean expandable, String className, String style) throws Exception{
         
         //String cl=" CLASS=\"T1\"";
         //String clh=" CLASS=\"T1header\"";
@@ -313,17 +304,19 @@ public abstract class Report extends BasicReport {
         sb.append("</tr>\n");
         //html.tr(false);
         
-        StringBuffer sb2=new StringBuffer(500);
-        StringBuffer sb3=new StringBuffer(100);
-        for(int i=0; i<v.size(); i++){
-            SessionData sd=(SessionData)v.get(i);            
+        StringBuilder sb2=new StringBuilder(500);
+        StringBuilder sb3=new StringBuilder(100);
+        int numSess=0;
+        Iterator<SessionData> it=v.iterator();
+        while(it.hasNext()){
+            SessionData sd=it.next();            
             sb.append("<tr>\n");
             sb2.setLength(0);
             boolean link = expandable && sd.id!=null && sd.id.length()>0;
             boolean status = link && sd.actData!=null;
             if(expandable){
                 if(link){              
-                    sb2.append("<a href=\"javascript:session(").append(i).append(",'").append(status ? FALSE : TRUE).append("')\">");
+                    sb2.append("<a href=\"javascript:session(").append(numSess).append(",'").append(status ? FALSE : TRUE).append("')\">");
                     sb2.append("<img src=\"").append(resourceUrl(status ? "menys.gif" : "mes.gif"));
                     sb2.append("\" width=\"9\" height=\"9\" border=\"0\" alt=\"");
                     sb2.append(getMsg("report_session_detail_" + (status ? "hide" : "show"))).append("\" id=\"noPrint\">");
@@ -369,11 +362,12 @@ public abstract class Report extends BasicReport {
             if(status){
                 llistaActivitats(sb, sd.actData);
             }
+            numSess++;
         }
         sb.append("</table>");        
     }
     
-    protected void llistaActivitats(StringBuffer sb, Vector v) throws Exception{
+    protected void llistaActivitats(StringBuilder sb, List<ActivityData> v) throws Exception{
         
         //String cl=" CLASS=\"T2\"";
         //String clh=" CLASS=\"T2header\"";
@@ -407,8 +401,9 @@ public abstract class Report extends BasicReport {
         sb.append("</tr>\n");
         //html.tr(false);
         
-        for(int i=0; i<v.size(); i++){
-            ActivityData ad=(ActivityData)v.get(i);
+        Iterator<ActivityData> it=v.iterator();
+        while(it.hasNext()){
+            ActivityData ad=it.next();
             sb.append("<tr id=\"t2x\">\n");
             //html.tr(true);
             sb.append("<td>").append(filter(ad.activityName)).append("</td>\n");
@@ -438,9 +433,9 @@ public abstract class Report extends BasicReport {
         }
     }
     
-    protected void resumGlobal(StringBuffer sb, Vector v, String className, String style) throws Exception{
+    protected void resumGlobal(StringBuilder sb, List<SessionData> v, String className, String style) throws Exception{
         
-        int sessions=0, users=0, numProjects=0, 
+        int sess=0, usrs, numProjects=0, 
         act_fetes=0, act_res=0, temps=0, precisio=0;
         
         if(!projectName.equals(WILDCARD))
@@ -451,31 +446,31 @@ public abstract class Report extends BasicReport {
                 numProjects--;
         }
         
-        HashSet hs=new HashSet();
-        Iterator it=v.iterator();
+        Set<String> hs=new HashSet<String>();
+        Iterator<SessionData> it=v.iterator();
         while(it.hasNext()){
-            SessionData sd=(SessionData)it.next();
+            SessionData sd=it.next();
             act_fetes+=sd.numActs;
             act_res+=sd.actsSolved;
             temps+=sd.totalTime;
             precisio+=sd.totalPrec;
-            sessions+=sd.sessionCount;
+            sess+=sd.sessionCount;
             hs.addAll(sd.users);
         }
-        users=hs.size();
+        usrs=hs.size();
         
         sb.append("<table class=\"").append(className).append("\"");
         if(style!=null)
             sb.append(" style=\"").append(style).append("\"");
         sb.append(">\n");
         sb.append("<tr><th colspan=2>").append(filter(getMsg("report_globalSummary"))).append("</th></tr>\n");
-        if(users>1)
-            resumTD(sb, getMsg("report_users"), numberFormat.format(users));
-        resumTD(sb, getMsg("report_sessions"), numberFormat.format(sessions));
+        if(usrs>1)
+            resumTD(sb, getMsg("report_users"), numberFormat.format(usrs));
+        resumTD(sb, getMsg("report_sessions"), numberFormat.format(sess));
         if(type!=PRJ)
             resumTD(sb, getMsg("report_projects"), numberFormat.format(numProjects));
         resumTD(sb, getMsg("report_actDone"), numberFormat.format(act_fetes));
-        StringBuffer sb2=new StringBuffer(200);
+        StringBuilder sb2=new StringBuilder(200);
         sb2.append(numberFormat.format(act_res)).append(" (").append(numberFormat.format(act_fetes==0 ? 0 : 100*act_res/act_fetes)).append("%)");
         resumTD(sb, getMsg("report_actSolved"), sb2.substring(0));
         resumTD(sb, getMsg("report_totalTime"), formatTime(temps));
@@ -485,7 +480,7 @@ public abstract class Report extends BasicReport {
         sb.append("</table>\n");
     }
     
-    protected void resumTD(StringBuffer sb, String td1, String td2){
+    protected void resumTD(StringBuilder sb, String td1, String td2){
         sb.append("<tr><td>").append(toNbsp(td1));        
         sb.append("</td><td align=\"right\">").append(toNbsp(td2)).append("</td></tr>\n");
     }
@@ -496,11 +491,10 @@ public abstract class Report extends BasicReport {
         int h=secs/(60*60);
         int m=(secs-(h*60*60))/60;
         int s=secs%60;
-        StringBuffer sb=new StringBuffer(8);
+        StringBuilder sb=new StringBuilder(8);
         if(h>0)
             sb.append(h).append(":");
         sb.append(n[m]).append(":").append(n[s]);
         return sb.substring(0);        
-    }
-    
+    }    
 }
