@@ -21,19 +21,21 @@
 
 package edu.xtec.jclic.report.rp;
 
-import edu.xtec.jclic.Constants;
-import edu.xtec.servlet.RequestProcessor;
 import edu.xtec.jclic.ReportServerConstants;
+import static edu.xtec.jclic.ReportServerConstants.CFG_FILE;
 import edu.xtec.jclic.report.BasicJDBCBridge;
 import edu.xtec.jclic.report.ReportServerJDBCBridge;
+import edu.xtec.servlet.RequestProcessor;
+import edu.xtec.util.Options;
 import edu.xtec.util.db.*;
-import java.util.Properties;
 import java.io.File;
 import java.io.FileInputStream;
+import java.util.Properties;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.16
  */
 public abstract class ReportsRequestProcessor extends RequestProcessor implements ReportServerConstants{
     
@@ -85,13 +87,14 @@ public abstract class ReportsRequestProcessor extends RequestProcessor implement
         if(prop==null)
             loadProperties(propFile);
         if(bridge==null){                                    
-            ConnectionBeanProvider cbp=ConnectionBeanProvider.getConnectionBeanProvider(true, prop);
+            ConnectionBeanProvider cbp=ConnectionBeanProvider.getConnectionBeanProvider(true, Options.toStringMap(prop));
             boolean createTables=!"false".equalsIgnoreCase((String)prop.get(BasicJDBCBridge.CREATE_TABLES_KEY));
             String tablePrefix=(String)prop.get(BasicJDBCBridge.TABLE_PREFIX_KEY);
             bridge=new ReportServerJDBCBridge(cbp, createTables, tablePrefix);
         }
     }
     
+    @Override
     public boolean init() throws Exception{
         
         if(!super.init())
