@@ -21,22 +21,31 @@
 
 package edu.xtec.jclic.shapers;
 
-import edu.xtec.util.Options;
-import java.awt.*;
-import javax.swing.*;
-import javax.swing.event.*;
-import edu.xtec.jclic.boxes.ActiveBoxGrid;
 import edu.xtec.jclic.Constants;
-import edu.xtec.util.Messages;
-import java.util.Vector;
 import edu.xtec.jclic.boxes.BoxBase;
-import edu.xtec.jclic.edit.EditorPanel;
+import edu.xtec.util.Messages;
+import edu.xtec.util.Options;
+import java.awt.Color;
+import java.awt.Component;
+import java.awt.Dimension;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.Image;
+import java.awt.Rectangle;
+import java.awt.RenderingHints;
+import java.awt.Shape;
+import java.awt.Stroke;
 import java.awt.event.*;
 import java.beans.PropertyChangeListener;
+import java.util.ArrayList;
+import java.util.List;
+import javax.swing.*;
+import javax.swing.event.*;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.17
  */
 public class HolesEditorPanel extends javax.swing.JPanel implements PointListener, ActionListener, PropertyChangeListener{
     
@@ -47,7 +56,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
     Image img;
     Rectangle previewArea;
     BoxBase previewBb;
-    ListModel listModel;
+    ShapeListModel listModel;
     ListSelectionListener listSelectionListener;
     boolean modified;
     int currentShape;
@@ -94,6 +103,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         shapeChanged();
     }
     
+    @Override
     public void setCursor(java.awt.Cursor c){
         if (previewPanel!=null)
             ((PreviewPanel)previewPanel).vp.setCursor(c);
@@ -103,17 +113,46 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         if (previewPanel!=null)
             ((PreviewPanel)previewPanel).vp.setCursor(c);
     }
-    
+
+    class ShapeListModel extends AbstractListModel {
+
+        public int getSize() {
+            return shaper.shapeData.length;
+        }
+
+        public Object getElementAt(int index) {
+            ShapeData sd = shaper.shapeData[index];
+            return (sd.comment == null || sd.comment.length() == 0) ?
+                Integer.toString(index) : sd.comment;
+        }
+
+        public void switchShapes(int index1, int index2) {
+            if (shaper != null
+                    && index1 >= 0 && index1 < shaper.shapeData.length
+                    && index2 >= 0 && index2 < shaper.shapeData.length) {
+
+                /*
+                pdp.deSelectAll();
+                setCurrentShape(-1);
+                ShapeData sd1 = shaper.shapeData[index1];
+                ShapeData sd2 = shaper.shapeData[index2];
+                shaper.shapeData[index1] = sd2;
+                shaper.shapeData[index2] = sd1;
+                setCurrentShape(index1);
+                updateList();
+                 *
+                 */
+
+                //shapeChanged();
+
+                //listSelectionListener.valueChanged(new ListSelectionEvent(listModel, index1, index2, false));
+            }
+        }
+    }
+
     private void initMembers(){
-        listModel=new AbstractListModel(){
-            public int getSize(){
-                return shaper.shapeData.length;
-            }
-            public Object getElementAt(int index){
-                ShapeData sd=shaper.shapeData[index];
-                return (sd.comment==null || sd.comment.length()==0) ? Integer.toString(index) : sd.comment;
-            }
-        };
+
+        listModel=new ShapeListModel();
         
         listSelectionListener=new ListSelectionListener(){
             public void valueChanged(ListSelectionEvent ev){
@@ -131,6 +170,9 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
                 }
                 else
                     tfName.setText("");
+
+                upBtn.setEnabled(v>0);
+                downBtn.setEnabled(v < shapesList.getModel().getSize()-1);
             }
         };
     }
@@ -178,66 +220,49 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
      * WARNING: Do NOT modify this code. The content of this method is
      * always regenerated by the Form Editor.
      */
-    private void initComponents() {//GEN-BEGIN:initComponents
+    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
+    private void initComponents() {
         java.awt.GridBagConstraints gridBagConstraints;
-        javax.swing.JPanel leftPanel;
-        javax.swing.JPanel listPanel;
-        javax.swing.JSeparator sep0;
-        javax.swing.JSeparator sep1;
-        javax.swing.JSeparator sep2;
-        javax.swing.JSeparator sep4;
-        javax.swing.JSeparator sept1;
-        javax.swing.JSeparator sept2;
-        javax.swing.JSeparator sept3;
-        javax.swing.JSeparator sept4;
-        javax.swing.JLabel spacerLeft;
-        javax.swing.JLabel spacerTop;
-        javax.swing.JSplitPane splitPane;
-        javax.swing.JToolBar tbLeft1;
-        javax.swing.JToolBar tbTop1;
-        javax.swing.JPanel topPanel;
-        javax.swing.JLabel zoomLb;
-        javax.swing.JPanel zoomPanel;
 
         bgMode = new javax.swing.ButtonGroup();
-        topPanel = new javax.swing.JPanel();
-        tbTop1 = new javax.swing.JToolBar();
+        javax.swing.JPanel topPanel = new javax.swing.JPanel();
+        javax.swing.JToolBar tbTop1 = new javax.swing.JToolBar();
         btShowDrawnPoints = new javax.swing.JToggleButton();
         btShowDrawnPoints.addActionListener(this);
-        sept1 = new JToolBar.Separator();
+        javax.swing.JSeparator sept1 = new JToolBar.Separator();
         btGrid = new javax.swing.JToggleButton();
         btGrid.addActionListener(this);
         gridSizeEdit = new edu.xtec.jclic.beans.SmallIntEditor();
         gridSizeEdit.addPropertyChangeListener(this);
-        sept2 = new JToolBar.Separator();
+        javax.swing.JSeparator sept2 = new JToolBar.Separator();
         btDelete = new javax.swing.JButton();
         btDelete.addActionListener(this);
         btCopy = new javax.swing.JButton();
         btCopy.addActionListener(this);
         btPaste = new javax.swing.JButton();
         btPaste.addActionListener(this);
-        sept3 = new JToolBar.Separator();
+        javax.swing.JSeparator sept3 = new JToolBar.Separator();
         btMagnet = new javax.swing.JToggleButton();
         btMagnet.addActionListener(this);
         magnetRadiusEdit = new edu.xtec.jclic.beans.SmallIntEditor();
         magnetRadiusEdit.addPropertyChangeListener(this);
-        sept4 = new JToolBar.Separator();
-        zoomPanel = new javax.swing.JPanel();
-        zoomLb = new javax.swing.JLabel();
+        javax.swing.JSeparator sept4 = new JToolBar.Separator();
+        javax.swing.JPanel zoomPanel = new javax.swing.JPanel();
+        javax.swing.JLabel zoomLb = new javax.swing.JLabel();
         btZoomOut = new javax.swing.JButton();
         btZoomOut.addActionListener(this);
         lbZoom = new javax.swing.JTextField();
         btZoomIn = new javax.swing.JButton();
         btZoomIn.addActionListener(this);
-        spacerTop = new javax.swing.JLabel();
-        sep0 = new javax.swing.JSeparator();
-        leftPanel = new javax.swing.JPanel();
-        tbLeft1 = new javax.swing.JToolBar();
+        javax.swing.JLabel spacerTop = new javax.swing.JLabel();
+        javax.swing.JSeparator sep0 = new javax.swing.JSeparator();
+        javax.swing.JPanel leftPanel = new javax.swing.JPanel();
+        javax.swing.JToolBar tbLeft1 = new javax.swing.JToolBar();
         btSelect = new javax.swing.JToggleButton();
         btSelect.addActionListener(this);
         btDivide = new javax.swing.JToggleButton();
         btDivide.addActionListener(this);
-        sep1 = new JToolBar.Separator();
+        javax.swing.JSeparator sep1 = new JToolBar.Separator();
         btRect = new javax.swing.JToggleButton();
         btRect.addActionListener(this);
         btEllipse = new javax.swing.JToggleButton();
@@ -250,21 +275,24 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         btBezier.addActionListener(this);
         btQuad = new javax.swing.JButton();
         btQuad.addActionListener(this);
-        sep2 = new JToolBar.Separator();
+        javax.swing.JSeparator sep2 = new JToolBar.Separator();
         btExpand = new javax.swing.JButton();
         btExpand.addActionListener(this);
         btContract = new javax.swing.JButton();
         btContract.addActionListener(this);
-        sep4 = new JToolBar.Separator();
+        javax.swing.JSeparator sep4 = new JToolBar.Separator();
         btRotateRight = new javax.swing.JButton();
         btRotateRight.addActionListener(this);
         btRotateLeft = new javax.swing.JButton();
         btRotateLeft.addActionListener(this);
-        spacerLeft = new javax.swing.JLabel();
-        splitPane = new javax.swing.JSplitPane();
+        javax.swing.JLabel spacerLeft = new javax.swing.JLabel();
+        javax.swing.JSplitPane splitPane = new javax.swing.JSplitPane();
         previewPanel = new PreviewPanel();
         previewPanel.addPropertyChangeListener(this);
-        listPanel = new javax.swing.JPanel();
+        javax.swing.JPanel listPanel = new javax.swing.JPanel();
+        orderBtnPanel = new javax.swing.JPanel();
+        upBtn = new javax.swing.JButton();
+        downBtn = new javax.swing.JButton();
         listScroll = new javax.swing.JScrollPane();
         shapesList = new javax.swing.JList();
         tfName = new javax.swing.JTextField();
@@ -275,15 +303,16 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         topPanel.setLayout(new java.awt.GridBagLayout());
 
         tbTop1.setFloatable(false);
-        btShowDrawnPoints.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/vertex_off.gif")));
+
+        btShowDrawnPoints.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/vertex_off.gif"))); // NOI18N
         btShowDrawnPoints.setToolTipText(options.getMsg("edit_shape_showPoints_tooltip"));
-        btShowDrawnPoints.setSelectedIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/vertex_on.gif")));
+        btShowDrawnPoints.setSelectedIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/vertex_on.gif"))); // NOI18N
         tbTop1.add(btShowDrawnPoints);
 
         sept1.setOrientation(javax.swing.SwingConstants.VERTICAL);
         tbTop1.add(sept1);
 
-        btGrid.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/grid.gif")));
+        btGrid.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/grid.gif"))); // NOI18N
         btGrid.setToolTipText(options.getMsg("edit_shape_hideGrid"));
         tbTop1.add(btGrid);
 
@@ -298,24 +327,24 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         sept2.setOrientation(javax.swing.SwingConstants.VERTICAL);
         tbTop1.add(sept2);
 
-        btDelete.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/delete.gif")));
+        btDelete.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/delete.gif"))); // NOI18N
         btDelete.setToolTipText(options.getMsg("edit_shape_deletePoint"));
         btDelete.setMaximumSize(new java.awt.Dimension(32, 32));
         btDelete.setMinimumSize(new java.awt.Dimension(32, 32));
         tbTop1.add(btDelete);
 
-        btCopy.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/copy.gif")));
+        btCopy.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/copy.gif"))); // NOI18N
         btCopy.setToolTipText(options.getMsg("COPY"));
         tbTop1.add(btCopy);
 
-        btPaste.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/paste.gif")));
+        btPaste.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/paste.gif"))); // NOI18N
         btPaste.setToolTipText(options.getMsg("PASTE"));
         tbTop1.add(btPaste);
 
         sept3.setOrientation(javax.swing.SwingConstants.VERTICAL);
         tbTop1.add(sept3);
 
-        btMagnet.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/imant.gif")));
+        btMagnet.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/imant.gif"))); // NOI18N
         btMagnet.setToolTipText(options.getMsg("edit_shape_aproxPoints"));
         tbTop1.add(btMagnet);
 
@@ -330,14 +359,14 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         sept4.setOrientation(javax.swing.SwingConstants.VERTICAL);
         tbTop1.add(sept4);
 
-        zoomPanel.setLayout(new javax.swing.BoxLayout(zoomPanel, javax.swing.BoxLayout.X_AXIS));
-
         zoomPanel.setOpaque(false);
-        zoomLb.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/zoom.gif")));
-        zoomLb.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(1, 3, 1, 3)));
+        zoomPanel.setLayout(new javax.swing.BoxLayout(zoomPanel, javax.swing.BoxLayout.LINE_AXIS));
+
+        zoomLb.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/zoom.gif"))); // NOI18N
+        zoomLb.setBorder(javax.swing.BorderFactory.createEmptyBorder(1, 3, 1, 3));
         zoomPanel.add(zoomLb);
 
-        btZoomOut.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/minus.gif")));
+        btZoomOut.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/minus.gif"))); // NOI18N
         btZoomOut.setToolTipText(options.getMsg("edit_shape_zoomOut"));
         btZoomOut.setPreferredSize(new java.awt.Dimension(16, 16));
         zoomPanel.add(btZoomOut);
@@ -348,7 +377,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         lbZoom.setText("1x");
         zoomPanel.add(lbZoom);
 
-        btZoomIn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/plus.gif")));
+        btZoomIn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/plus.gif"))); // NOI18N
         btZoomIn.setToolTipText(options.getMsg("edit_shape_zoomIn"));
         btZoomIn.setPreferredSize(new java.awt.Dimension(16, 16));
         zoomPanel.add(btZoomIn);
@@ -356,7 +385,6 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         tbTop1.add(zoomPanel);
 
         topPanel.add(tbTop1, new java.awt.GridBagConstraints());
-
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
         gridBagConstraints.weightx = 1.0;
@@ -367,7 +395,6 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
         gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
         add(topPanel, gridBagConstraints);
-
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
         gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
@@ -377,85 +404,82 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
 
         tbLeft1.setFloatable(false);
         tbLeft1.setOrientation(1);
-        btSelect.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/selectionMode.gif")));
-        btSelect.setToolTipText(options.getMsg("edit_shape_select"));
+
         bgMode.add(btSelect);
+        btSelect.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/selectionMode.gif"))); // NOI18N
+        btSelect.setToolTipText(options.getMsg("edit_shape_select"));
         btSelect.setMaximumSize(new java.awt.Dimension(32, 32));
         btSelect.setMinimumSize(new java.awt.Dimension(32, 32));
         tbLeft1.add(btSelect);
 
-        btDivide.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/add_point.gif")));
-        btDivide.setToolTipText(options.getMsg("edit_shape_addPoint"));
         bgMode.add(btDivide);
+        btDivide.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/add_point.gif"))); // NOI18N
+        btDivide.setToolTipText(options.getMsg("edit_shape_addPoint"));
         btDivide.setMaximumSize(new java.awt.Dimension(32, 32));
         btDivide.setMinimumSize(new java.awt.Dimension(32, 32));
         tbLeft1.add(btDivide);
-
         tbLeft1.add(sep1);
 
-        btRect.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/rect.gif")));
-        btRect.setToolTipText(options.getMsg("edit_shape_drawRect"));
         bgMode.add(btRect);
+        btRect.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/rect.gif"))); // NOI18N
+        btRect.setToolTipText(options.getMsg("edit_shape_drawRect"));
         btRect.setMaximumSize(new java.awt.Dimension(32, 32));
         btRect.setMinimumSize(new java.awt.Dimension(32, 32));
         tbLeft1.add(btRect);
 
-        btEllipse.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/rodona.gif")));
-        btEllipse.setToolTipText(options.getMsg("edit_shape_drawEllipse"));
         bgMode.add(btEllipse);
+        btEllipse.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/rodona.gif"))); // NOI18N
+        btEllipse.setToolTipText(options.getMsg("edit_shape_drawEllipse"));
         btEllipse.setMaximumSize(new java.awt.Dimension(32, 32));
         btEllipse.setMinimumSize(new java.awt.Dimension(32, 32));
         tbLeft1.add(btEllipse);
 
-        btPolygon.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/pent.gif")));
-        btPolygon.setToolTipText(options.getMsg("edit_shape_drawPoly"));
         bgMode.add(btPolygon);
+        btPolygon.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/pent.gif"))); // NOI18N
+        btPolygon.setToolTipText(options.getMsg("edit_shape_drawPoly"));
         btPolygon.setMaximumSize(new java.awt.Dimension(32, 32));
         btPolygon.setMinimumSize(new java.awt.Dimension(32, 32));
         tbLeft1.add(btPolygon);
 
-        btLine.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/line.gif")));
+        btLine.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/line.gif"))); // NOI18N
         btLine.setToolTipText(options.getMsg("edit_shape_toLine"));
         btLine.setMaximumSize(new java.awt.Dimension(32, 32));
         btLine.setMinimumSize(new java.awt.Dimension(32, 32));
         tbLeft1.add(btLine);
 
-        btBezier.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/bezier.gif")));
+        btBezier.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/bezier.gif"))); // NOI18N
         btBezier.setToolTipText(options.getMsg("edit_shape_toBezier"));
         btBezier.setMaximumSize(new java.awt.Dimension(32, 32));
         btBezier.setMinimumSize(new java.awt.Dimension(32, 32));
         tbLeft1.add(btBezier);
 
-        btQuad.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/quad.gif")));
+        btQuad.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/quad.gif"))); // NOI18N
         btQuad.setToolTipText(options.getMsg("edit_shape_toQuad"));
         btQuad.setMaximumSize(new java.awt.Dimension(32, 32));
         btQuad.setMinimumSize(new java.awt.Dimension(32, 32));
         tbLeft1.add(btQuad);
-
         tbLeft1.add(sep2);
 
-        btExpand.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/expand.gif")));
+        btExpand.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/expand.gif"))); // NOI18N
         btExpand.setToolTipText(options.getMsg("edit_shape_expand"));
         tbLeft1.add(btExpand);
 
-        btContract.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/contract.gif")));
+        btContract.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/contract.gif"))); // NOI18N
         btContract.setToolTipText(options.getMsg("edit_shape_contract"));
         tbLeft1.add(btContract);
-
         tbLeft1.add(sep4);
 
-        btRotateRight.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/rotate_right.gif")));
+        btRotateRight.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/rotate_right.gif"))); // NOI18N
         btRotateRight.setToolTipText(options.getMsg("edit_shape_rRight"));
         tbLeft1.add(btRotateRight);
 
-        btRotateLeft.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/rotate_left.gif")));
+        btRotateLeft.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/rotate_left.gif"))); // NOI18N
         btRotateLeft.setToolTipText(options.getMsg("edit_shape_rLeft"));
         tbLeft1.add(btRotateLeft);
 
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
         leftPanel.add(tbLeft1, gridBagConstraints);
-
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.weighty = 1.0;
         leftPanel.add(spacerLeft, gridBagConstraints);
@@ -466,14 +490,40 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         add(leftPanel, gridBagConstraints);
 
         splitPane.setResizeWeight(1.0);
-        previewPanel.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS);
-        previewPanel.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
+
+        previewPanel.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS);
+        previewPanel.setVerticalScrollBarPolicy(javax.swing.ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS);
         splitPane.setLeftComponent(previewPanel);
 
         listPanel.setLayout(new java.awt.BorderLayout(10, 8));
 
+        upBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/up.gif")));
+        upBtn.setToolTipText(options.getMsg("edit_list_upBtn_tooltip"));
+        upBtn.setEnabled(false);
+        upBtn.setPreferredSize(new java.awt.Dimension(16, 16));
+        upBtn.addActionListener(new java.awt.event.ActionListener() {
+            public void actionPerformed(java.awt.event.ActionEvent evt) {
+                upBtnActionPerformed(evt);
+            }
+        });
+        orderBtnPanel.add(upBtn);
+
+        downBtn.setIcon(new javax.swing.ImageIcon(getClass().getResource("/edu/xtec/resources/icons/down.gif")));
+        downBtn.setToolTipText(options.getMsg("edit_list_downBtn_tooltip"));
+        downBtn.setEnabled(false);
+        downBtn.setPreferredSize(new java.awt.Dimension(16, 16));
+        downBtn.addActionListener(new java.awt.event.ActionListener() {
+            public void actionPerformed(java.awt.event.ActionEvent evt) {
+                downBtnActionPerformed(evt);
+            }
+        });
+        orderBtnPanel.add(downBtn);
+
+        listPanel.add(orderBtnPanel, java.awt.BorderLayout.NORTH);
+
         listScroll.setToolTipText(options.getMsg("edit_shape_elements"));
         listScroll.setPreferredSize(new java.awt.Dimension(80, 100));
+
         shapesList.setModel(listModel);
         shapesList.addListSelectionListener(listSelectionListener);
         listScroll.setViewportView(shapesList);
@@ -492,14 +542,39 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         gridBagConstraints.weighty = 1.0;
         gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
         add(splitPane, gridBagConstraints);
+    }// </editor-fold>//GEN-END:initComponents
 
-    }//GEN-END:initComponents
+    private void upBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_upBtnActionPerformed
+
+        if (listModel != null) {
+            int sel = shapesList.getSelectedIndex();
+            if (sel > 0 && sel < listModel.getSize() - 1) {
+                listModel.switchShapes(sel, sel-1);
+                shapesList.setSelectedIndex(sel - 1);
+                modified = true;
+                repaint(0);
+            }
+        }
+    }//GEN-LAST:event_upBtnActionPerformed
+
+    private void downBtnActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_downBtnActionPerformed
+
+        if (listModel != null) {
+            int sel = shapesList.getSelectedIndex();
+            if (sel >= 0 && sel < listModel.getSize() - 2) {
+                listModel.switchShapes(sel, sel+1);
+                shapesList.setSelectedIndex(sel + 1);
+                modified = true;
+                repaint(0);
+            }
+        }
+    }//GEN-LAST:event_downBtnActionPerformed
     
                 
     private void setDrawingRectangleMode(){
         deselectAll();
         btRect.setSelected(true);
-        pdp.setDrawingMode(pdp.DRAWING_RECT);
+        pdp.setDrawingMode(PolygonDrawPanel.DRAWING_RECT);
         pdp.deSelectAll();
         repaint(0);
     }
@@ -540,7 +615,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
             clean();
         }
         if (!btDivide.isSelected()){
-            pdp.setDrawingMode(pdp.SELECTING);
+            pdp.setDrawingMode(PolygonDrawPanel.SELECTING);
             deselectAll();
             btSelect.setSelected(true);
         }
@@ -550,15 +625,15 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
     }
     
     protected void updateTransformingButtons(){
-        java.util.Vector v=pdp.getSelectedShapes();
+        List<EditableShape> v=pdp.getSelectedShapes();
         if (v.size()==1){
-            java.util.Enumeration e=v.elements();
-            EditableShape shape=(EditableShape)e.nextElement(); //El te segur: size==1
+            EditableShape shape=v.get(0); //El te segur: size==1
             if (!(shape instanceof EditableRectangle)){
                 btBezier.setEnabled(true);
                 btQuad.setEnabled(true);
             }
-            if (!(shape instanceof EditableEllipse2D)) btLine.setEnabled(true);
+            if (!(shape instanceof EditableEllipse2D))
+                btLine.setEnabled(true);
         }
         else{
             btBezier.setEnabled(false);
@@ -568,8 +643,8 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         }
     }
     
-    public PreviewPanel getPreviewPanel(){
-        return (PreviewPanel)previewPanel;
+    public JComponent getPreviewPanel(){
+        return previewPanel;
     }
     
     private void clean(){
@@ -606,13 +681,16 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
     private javax.swing.JToggleButton btShowDrawnPoints;
     private javax.swing.JButton btZoomIn;
     private javax.swing.JButton btZoomOut;
+    private javax.swing.JButton downBtn;
     private edu.xtec.jclic.beans.SmallIntEditor gridSizeEdit;
     private javax.swing.JTextField lbZoom;
     private javax.swing.JScrollPane listScroll;
     private edu.xtec.jclic.beans.SmallIntEditor magnetRadiusEdit;
+    private javax.swing.JPanel orderBtnPanel;
     private javax.swing.JScrollPane previewPanel;
     private javax.swing.JList shapesList;
     private javax.swing.JTextField tfName;
+    private javax.swing.JButton upBtn;
     // End of variables declaration//GEN-END:variables
     
     public void updateView(){
@@ -639,7 +717,11 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         
         private int xBak=-1, yBak=-1, wBak=-1, hBak=-1;
         
-        Vector shapes=new Vector();
+        List<Shape> shapes;
+
+        VP() {
+            this.shapes = new ArrayList<Shape>();
+        }
         
         public void updateView(){
             setSize(getSize());
@@ -648,7 +730,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         }
         
         public void updateComponentsView(){
-            shapes.removeAllElements();
+            shapes.clear();
             for(int i=0; i<shaper.getNumCells(); i++){
                 shapes.add(shaper.getShape(i, previewArea));
             }
@@ -659,6 +741,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
             
         }
         
+        @Override
         public void paintComponent(Graphics g){
             super.paintComponent(g);
             Graphics2D g2=(Graphics2D)g;
@@ -702,6 +785,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
             g.fillRect(0,0,(int)previewArea.getX(),getHeight());
         }
         
+        @Override
         public void doLayout(){
             
             previewArea.x=(getBounds().width-previewArea.width)/2;
@@ -721,6 +805,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
             updateComponentsView();
         }
         
+        @Override
         public Dimension getSize(){
             return new Dimension(previewArea.x+(int)previewArea.getBounds().getWidth(),previewArea.y+(int)previewArea.getBounds().getHeight());
         }
@@ -749,7 +834,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
         if(initialShaper==null || !(initialShaper instanceof Holes))
             return null;
         
-        Holes sh=null;
+        Holes sh;
         try{
             sh=(Holes)initialShaper.clone();
         } catch(CloneNotSupportedException ex){
@@ -794,11 +879,11 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
     
     protected void modifyDrawingArea(double newWidth, double newHeight){
         if(newWidth>0 && newHeight>0){
-            double xFactor=newWidth/previewArea.width;
-            double yFactor=newHeight/previewArea.height;
+            double xFactorMod=newWidth/previewArea.width;
+            double yFactorMod=newHeight/previewArea.height;
             for(int i=0; i<shaper.getNumCells(); i++){
                 ShapeData sd=shaper.getShapeData(i);
-                sd.scaleTo(xFactor, yFactor);
+                sd.scaleTo(xFactorMod, yFactorMod);
             }
             previewArea.setSize((int)newWidth, (int)newHeight);
             previewDim.setSize(previewArea.getSize());
@@ -820,7 +905,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
                 deselectAll();
                 requestFocus();
                 btDivide.setSelected(true);
-                pdp.setDrawingMode(pdp.NEW_POINT);
+                pdp.setDrawingMode(PolygonDrawPanel.NEW_POINT);
                 pdp.deSelectAll();
                 repaint(0);
             }
@@ -831,11 +916,11 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
             }
             else if(obj==btEllipse){
                 requestFocus();
-                pdp.setDrawingMode(pdp.DRAWING_ELLIPSE);
+                pdp.setDrawingMode(PolygonDrawPanel.DRAWING_ELLIPSE);
             }
             else if(obj==btRect){
                 requestFocus();
-                pdp.setDrawingMode(pdp.DRAWING_RECT);
+                pdp.setDrawingMode(PolygonDrawPanel.DRAWING_RECT);
             }
             else if(obj==btLine){
                 requestFocus();
@@ -854,11 +939,11 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
             }
             else if(obj==btPolygon){
                 requestFocus();
-                pdp.setDrawingMode(pdp.DRAWING_POLYGON);
+                pdp.setDrawingMode(PolygonDrawPanel.DRAWING_POLYGON);
             }
             else if(obj==btSelect){
                 requestFocus();
-                pdp.setDrawingMode(pdp.SELECTING);
+                pdp.setDrawingMode(PolygonDrawPanel.SELECTING);
             }
             else if(obj==btShowDrawnPoints){
                 EditableShapeConstants.showDrawnPoints=btShowDrawnPoints.isSelected();
@@ -903,7 +988,7 @@ public class HolesEditorPanel extends javax.swing.JPanel implements PointListene
                 updateView();
             }
             else if(obj==tfName){
-                ShapeData sd=null;
+                ShapeData sd;
                 if (currentShape>=0){
                     sd=getHoles().getShapeData(currentShape);
                     String txt=tfName.getText().trim();
