@@ -22,25 +22,30 @@
 package edu.xtec.jclic.shapers;
 
 import edu.xtec.util.StrUtils;
+import java.awt.Cursor;
+import java.awt.Graphics2D;
+import java.awt.Point;
+import java.awt.Rectangle;
+import java.awt.Shape;
+import java.awt.Toolkit;
+import java.awt.event.*;
+import java.awt.geom.*;
+import java.util.ArrayList;
+import java.util.List;
+import javax.swing.JComponent;
 
 /**
  *
- * @author  allastar
- * @version 1.0
+ * @author allastar
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.17
  */
-
-import java.awt.*;
-import java.awt.geom.*;
-import java.awt.event.*;
-import java.util.Vector;
-import javax.swing.*;
-
 public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, java.awt.event.MouseListener{
     
-    private Vector vShapes; //Vector that contains the polygon currently being modified
-    private static Vector vCopied;
-    private Vector vRedrawingLines,vRedrawingLinesBeforeModify,vShapeBeforeModify;
-    private Vector vPointListeners;
+    private List<EditableShape> vShapes; //List that contains the polygon currently being modified
+    private static List<EditableShape> vCopied;
+    private List<EditableShape> vRedrawingLines,vRedrawingLinesBeforeModify,vShapeBeforeModify;
+    private List<PointListener> vPointListeners;
     private double iniX,iniY,finX,finY,lastFinX,lastFinY;
     private Point2D iniPoint=null,lastPoint=null;
     private boolean bSelectedPoint=false;
@@ -54,7 +59,7 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     private int drawingMode=SELECTING;
     static double defaultSensibility=1.5;
     private AffineTransform at;
-    private Vector vDrawnBorders=null;
+    private List<Rectangle> vDrawnBorders=null;
     private Shape current=null;
     
     private JComponent container;
@@ -91,13 +96,13 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     public PolygonDrawPanel(int width, int height, HolesEditorPanel hep, boolean canResize) {
         this.hep=hep;
         this.canResize=canResize;
-        vShapes=new Vector();
+        vShapes=new ArrayList<EditableShape>();
         if(vCopied==null)
-            vCopied=new Vector();
+            vCopied=new ArrayList<EditableShape>();
         
-        vRedrawingLines=new Vector();
-        vRedrawingLinesBeforeModify=new Vector();
-        vPointListeners=new Vector();
+        vRedrawingLines=new ArrayList<EditableShape>();
+        vRedrawingLinesBeforeModify=new ArrayList<EditableShape>();
+        vPointListeners=new ArrayList<PointListener>();
         at=new AffineTransform();
         initDrawnBorders();
         
@@ -134,7 +139,7 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
         if(vDrawnBorders!=null)
             vDrawnBorders.clear();
         else
-            vDrawnBorders=new Vector();
+            vDrawnBorders=new ArrayList<Rectangle>();
         for(int i=0;i<hep.getNumShapes();i++){
             if(i!=hep.currentShape){
                 Shape s=hep.getHoles().getShape(i,hep.previewArea);
@@ -144,13 +149,13 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
         }
     }
     
-    private java.util.Vector getBorders(Shape s){
+    private List<Rectangle> getBorders(Shape s){
         // Utility function that returns the points that define the "segments" of the polygon 's'.
         int xIni=0; int yIni=0;
         
         if(s==null)
             return null;
-        java.util.Vector vPoints=new java.util.Vector();
+        List<Rectangle> vPoints=new ArrayList<Rectangle>();
         double x,y;
         if(s instanceof GeneralPath){
             GeneralPath gp=(GeneralPath)s;
@@ -188,18 +193,15 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     public void paint(java.awt.Graphics2D g){
         
         Graphics2D g2d=(Graphics2D)g;
-        EditableShape current=null;
         
         if(EditableShapeConstants.showDrawnPoints)
             paintDrawnBorders(g);
         
-        java.util.Enumeration e=vShapes.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            if(bSpecialLine && current==specialLine)
-                current.paintWithColor(g,drawingMode,EditableShapeConstants.CUT_COLOR);
+        for(EditableShape esh : vShapes){
+            if(bSpecialLine && esh==specialLine)
+                esh.paintWithColor(g,drawingMode,EditableShapeConstants.CUT_COLOR);
             else
-                current.paintWithColor(g,drawingMode,EditableShapeConstants.ACTIVE_COLOR);
+                esh.paintWithColor(g,drawingMode,EditableShapeConstants.ACTIVE_COLOR);
         }
         if(bMoving)
             paintMoved(g);        
@@ -239,9 +241,7 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     protected void paintDrawnBorders(java.awt.Graphics2D g){
-        java.util.Enumeration eDr=vDrawnBorders.elements();
-        while (eDr.hasMoreElements()){
-            Rectangle r=(Rectangle)eDr.nextElement();
+        for(Rectangle r : vDrawnBorders){
             double x=r.getX();
             double y=r.getY();
             double w=r.getWidth();
@@ -256,18 +256,15 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     private void paintMoved(java.awt.Graphics2D g){
-        EditableShape current;
-        java.util.Enumeration e=vCopied.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            EditableShape copied=(EditableShape)current.clone();
+        for(EditableShape esh : vCopied){
+            EditableShape copied=(EditableShape)esh.clone();
             copied.transform(AffineTransform.getTranslateInstance(finX-iniX,finY-iniY));
             copied.paintWithColor(g,drawingMode,EditableShapeConstants.movingColor);
         }
     }
     
     public void updateView(){
-        Vector v=getGeneralPath();
+        List v=getGeneralPath();
         if(lastPreviewArea==null)
             lastPreviewArea=hep.previewArea;
         if(v.size()>0){
@@ -286,8 +283,8 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
         clean();
         current=(sd!=null)?sd.getShape(hep.previewArea):null;
         double firstX=-1,firstY=-1;
-        if(sd.primitiveType>=0 && sd.primitivePoints!=null && sd.primitivePoints.length>3){
-            EditableShape es=null;
+        if(sd!=null && sd.primitiveType>=0 && sd.primitivePoints!=null && sd.primitivePoints.length>3){
+            EditableShape es;
             double xTr=(sd.primitivePoints[0]*hep.previewArea.getWidth())+hep.previewArea.getX();
             double yTr=(sd.primitivePoints[1]*hep.previewArea.getHeight())+hep.previewArea.getY();
             double wSc=sd.primitivePoints[2]*hep.previewArea.getWidth();
@@ -303,7 +300,7 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
                     break;
             }
         }
-        else{
+        else if(sd!=null){
             Shape s=sd.getShape(hep.previewArea);
             if(s instanceof GeneralPath){
                 GeneralPath gp=(GeneralPath)s;
@@ -352,9 +349,9 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     public void clean(){
-        vShapes=new Vector();
-        vRedrawingLines=new Vector();
-        vRedrawingLinesBeforeModify=new Vector();
+        vShapes=new ArrayList<EditableShape>();
+        vRedrawingLines=new ArrayList<EditableShape>();
+        vRedrawingLinesBeforeModify=new ArrayList<EditableShape>();
     }
     
     
@@ -386,16 +383,17 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
         return aproximationToLine(x,y,null);
     }
     
-    private EditableShape aproximationToLine(double x, double y, Vector vRedrawingLines){
+    private EditableShape aproximationToLine(double x, double y, List<EditableShape> vRedrawingLines){
         //returns an EditableShape when there is a corner at (x,y) that not belongs to the lines in
-        //the Vector vRedrawingLines. Otherwise returns null
-        EditableShape current=null;
-        java.util.Enumeration e=vShapes.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            if(vRedrawingLines==null || !vRedrawingLines.contains(current))
-                if(current.hasClickedBorder((int)x,(int)y,false))
-                    return current;
+        //the Rectangle List vRedrawingLines. Otherwise returns null
+        if (vRedrawingLines != null) {
+            for (EditableShape esh : vRedrawingLines) {
+                if (!vRedrawingLines.contains(esh)) {
+                    if (esh.hasClickedBorder((int) x, (int) y, false)) {
+                        return esh;
+                    }
+                }
+            }
         }
         return null;
     }
@@ -439,9 +437,7 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     
     public Point2D aproximationToDrawnBorder(double x, double y){
         // Returns true if a rectangle in vDrawnBorders contains the point (x,y)
-        java.util.Enumeration e=vDrawnBorders.elements();
-        while (e.hasMoreElements()){
-            Rectangle2D r=(Rectangle2D)e.nextElement();
+        for(Rectangle2D r : vDrawnBorders){
             if(r.contains(x,y))
                 return new Point2D.Double(r.getX()+(r.getWidth()/2),r.getY()+(r.getHeight()/2));
         }
@@ -450,12 +446,8 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     
     
     protected void redrawingLines(double x, double y){ //moves all the selected shapes containing (x,y) in one of its corners
-        EditableShape current=null;
-        java.util.Enumeration e=vRedrawingLines.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            current.changeBorder(x,y);
-        }
+        for(EditableShape esh : vRedrawingLines)
+            esh.changeBorder(x,y);
     }
     
     private void cleanZoom(){
@@ -490,12 +482,10 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     
     public void copy(boolean needSelected){
         vCopied.clear();
-        EditableShape current=null;
-        java.util.Enumeration e=vShapes.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)((EditableShape)e.nextElement()).clone();
-            if(!needSelected || current.isSelected()){
-                vCopied.add(current);
+        for(EditableShape esh : vShapes){
+            esh=(EditableShape)esh.clone();
+            if(!needSelected || esh.isSelected()){
+                vCopied.add(esh);
             }
         }
     }
@@ -507,13 +497,10 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     public void paste(double x, double y){
-        Vector newCopied=new Vector();
+        List<EditableShape> newCopied=new ArrayList<EditableShape>();
         deSelectAll();
-        EditableShape current=null;
-        java.util.Enumeration e=vCopied.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            EditableShape copied=(EditableShape)current.clone();
+        for(EditableShape esh : vCopied){
+            EditableShape copied=(EditableShape)esh.clone();
             copied.transform(AffineTransform.getTranslateInstance(x,y));
             copied.setSelected(true);
             vShapes.add(copied);
@@ -523,11 +510,8 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     public void deSelectAll(){
-        EditableShape current=null;
-        java.util.Enumeration e=vShapes.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            current.setSelected(false);
+        for(EditableShape esh : vShapes){
+            esh.setSelected(false);
         }
         bSelectedPoint=false;
         hep.repaint(0);
@@ -535,16 +519,13 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     
     private EditableShape nearestLine(double x, double y){
         EditableShape nearest=null;
-        EditableShape current=null;
         double distance=0;
         double currentDistance;
-        java.util.Enumeration e=vShapes.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            currentDistance=current.distanceTo(x,y);
+        for(EditableShape esh : vShapes){
+            currentDistance=esh.distanceTo(x,y);
             if(nearest==null || (currentDistance<distance)){
                 distance=currentDistance;
-                nearest=current;
+                nearest=esh;
             }
         }
         return nearest;
@@ -554,29 +535,24 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
         //With needSelected=false it's not necessary to have selected a shape in order to drag it
         // leaves in vRedrawingLines the selected lines with one point near the supplied co-ordinates (x,y)
         Point2D redrawingPoint=null;
-        EditableShape current=null;
         vRedrawingLines.clear();
-        java.util.Enumeration e=vShapes.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            if((!needSelected || current.isSelected()) && current.hasClickedBorder(x,y,needSelected)){
-                Point2D p=current.getNearestBorder(x,y);
+        for(EditableShape esh : vShapes){
+            if((!needSelected || esh.isSelected()) && esh.hasClickedBorder(x,y,needSelected)){
+                Point2D p=esh.getNearestBorder(x,y);
                 if(redrawingPoint==null || redrawingPoint.equals(p)){
                     redrawingPoint=p;
-                    vRedrawingLines.add(current);
+                    vRedrawingLines.add(esh);
                 }
             }
         }
         vRedrawingLinesBeforeModify=cloneVector(vRedrawingLines);
     }
     
-    private Vector cloneVector(Vector v){
-        Vector vClone=new Vector();
+    private List<EditableShape> cloneVector(List<EditableShape> v){
+        List<EditableShape> vClone=new ArrayList<EditableShape>();
         if(v!=null){
-            java.util.Enumeration e=v.elements();
-            while (e.hasMoreElements()){
-                EditableShape es=(EditableShape)e.nextElement();
-                vClone.add(es.clone());
+            for(EditableShape es : v){
+                vClone.add((EditableShape)es.clone());
             }
         }
         return vClone;
@@ -588,7 +564,7 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
             if(shapes!=null){
                 // -> The two following lines are necessary in order to grant the connection of the resulting shape
                 // Dividing two times in the same point can create an independent line out of the shape
-                Vector vCheckPoint=new Vector();
+                List<EditableShape> vCheckPoint=new ArrayList<EditableShape>();
                 vCheckPoint.addAll(vShapes);
                 vShapes.remove(specialLine);
                 for (int i=0;i<shapes.length;i++){
@@ -608,32 +584,32 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
         return (getGeneralPath().size()==1);
     }
     
-    public Vector getGeneralPath(){
-        Vector vGpaths=new Vector();
+    public List<GeneralPath> getGeneralPath(){
+        List<GeneralPath> vGpaths=new ArrayList<GeneralPath>();
         GeneralPath currentPolygon=new GeneralPath();
-        Vector shapes=new Vector();
+        List<EditableShape> shapes=new ArrayList<EditableShape>();
         shapes.addAll(vShapes);
         if(!(shapes.size()>0)) 
             return vGpaths;
-        EditableShape current=(EditableShape)shapes.get(0);
-        shapes.remove(current);
-        currentPolygon.append(current,true);
+        EditableShape esh=shapes.get(0);
+        shapes.remove(esh);
+        currentPolygon.append(esh,true);
         short notUsedPoint=END; //indicates the side of the last shape non-adjacent to anyone
         while (shapes.size()>0){
-            EditableShape shape=getAdjacent(shapes,current,notUsedPoint);
+            EditableShape shape=getAdjacent(shapes,esh,notUsedPoint);
             if(shape!=null){
                 currentPolygon.append(shape,true);
-                notUsedPoint=getNotUsed(current,shape); //returns the point of the shape non-adjacent to "current"
+                notUsedPoint=getNotUsed(esh,shape); //returns the point of the shape non-adjacent to "current"
                 shapes.remove(shape);
-                current=shape;
+                esh=shape;
             }
             else{
                 vGpaths.add(currentPolygon);
                 currentPolygon=new GeneralPath();
                 notUsedPoint=END;
-                current=(EditableShape)shapes.get(0);
-                shapes.remove(current);
-                currentPolygon.append(current,true);
+                esh=(EditableShape)shapes.get(0);
+                shapes.remove(esh);
+                currentPolygon.append(esh,true);
             }
         }
         vGpaths.add(currentPolygon);
@@ -647,15 +623,13 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
             return INITIAL;
     }
     
-    private EditableShape getAdjacent(Vector shapes, EditableShape sh, short notUsedPoint){
-        java.util.Enumeration e=shapes.elements();
+    private EditableShape getAdjacent(List<EditableShape> shapes, EditableShape sh, short notUsedPoint){
         Point2D p;
         if(notUsedPoint==INITIAL)
             p=sh.getInitialPoint();
         else
             p=sh.getEndPoint();
-        while(e.hasMoreElements()){
-            EditableShape shape=(EditableShape)e.nextElement();
+        for(EditableShape shape : shapes){
             if(shape.isAdjacentTo(p))
                 return shape;
         }
@@ -686,21 +660,18 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
             bSelectedPoint=false;
         }
         else{
-            EditableShape current=null;
-            Vector vShapesCopy=new Vector();
+            List<EditableShape> vShapesCopy=new ArrayList<EditableShape>();
             boolean allSelected=true, noneSelected=true;
             vShapesCopy.addAll(vShapes);
-            java.util.Enumeration e=vShapesCopy.elements();
-            while (e.hasMoreElements()){
-                current=(EditableShape)e.nextElement();
-                if(!current.isSelected())
+            for(EditableShape esh : vShapesCopy){
+                if(!esh.isSelected())
                     allSelected=false;
                 else{
                     noneSelected=false;
                     if(isCut || vShapes.size()>=4){ //Avoid to delete objects when there are only 3 or less elements, unless is a "cut"
-                        vShapes.remove(current);
+                        vShapes.remove(esh);
                         if(!isCut)
-                            joinAdjacentsTo(current,vShapes);
+                            joinAdjacentsTo(esh,vShapes);
                     }
                 }
             }
@@ -714,7 +685,7 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
         }
     }
     
-    private void joinAdjacentsTo(EditableShape current, Vector vShapes){
+    private void joinAdjacentsTo(EditableShape current, List<EditableShape> vShapes){
         //All the shapes in vShapes will converge in one of the "current" points.
         EditableShape s1=getAdjacent(vShapes,current,INITIAL);
         if(s1!=null){ //Always
@@ -726,31 +697,30 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     private void joinAdjacentsToSelectedPoint(){
-        EditableShape current=null, other=null;
+        
         if(vShapes.size()!=1 && vShapes.size()<=3)
             return;
-        java.util.Enumeration e=vShapes.elements();
+        
+        EditableShape other=null;
         int count=0;
-        boolean bFinish=false;
-        while (e.hasMoreElements() && !bFinish){
-            current=(EditableShape)e.nextElement();
-            if(current.hasSelectedBorder()){
-                if(current instanceof EditableRectangle){
-                    Point2D p=current.getNotSelectedBorder();
+        for(EditableShape esh : vShapes){
+            if(esh.hasSelectedBorder()){
+                if(esh instanceof EditableRectangle){
+                    Point2D p=esh.getNotSelectedBorder();
                     convertToSimpleShapes();
                     selectBorder(p.getX(),p.getY());
                     joinAdjacentsToSelectedPoint();
-                    bFinish=true;
+                    break;
                 }
                 else{
                     count++;
                     if(count==1)
-                        other=current;
-                    else{
-                        Point2D p1=current.getNotSelectedBorder();
+                        other=esh;
+                    else if(other!=null){
+                        Point2D p1=esh.getNotSelectedBorder();
                         Point2D p2=other.getNotSelectedBorder();
                         vShapes.add(new EditableLine2D(p1,p2));
-                        vShapes.remove(current);
+                        vShapes.remove(esh);
                         vShapes.remove(other);
                     }
                 }
@@ -759,28 +729,21 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
         hep.repaint(0);
     }
     
-    private void setEndToVector(double finX, double finY, Vector vRedrawingLines){
+    private void setEndToVector(double finX, double finY, List<EditableShape> vRedrawingLines){
         //approach of all the lines of vRedrawingLines to the point finX, finY
-        EditableShape current=null;
-        java.util.Enumeration e=vRedrawingLines.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            current.aproximateNearestBorder(finX,finY);
-        }
+        for(EditableShape esh : vRedrawingLines)
+            esh.aproximateNearestBorder(finX,finY);
     }
     
     public boolean hasSelectedPoint(){
         return bSelectedPoint;
     }
     
-    public Vector getSelectedShapes(){
-        Vector v=new Vector();
-        java.util.Enumeration e=vShapes.elements();
-        EditableShape current;
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            if(current.isSelected())
-                v.add(current);
+    public List<EditableShape> getSelectedShapes(){
+        List<EditableShape> v=new ArrayList<EditableShape>();
+        for(EditableShape esh : vShapes){
+            if(esh.isSelected())
+                v.add(esh);
         }
         return v;
     }
@@ -796,11 +759,11 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     
     public ShapeData getShapeData(){
         ShapeData sd=null;
-        AffineTransform at=AffineTransform.getScaleInstance((1/hep.previewArea.getWidth()),(1/hep.previewArea.getHeight()));
-        at.concatenate(AffineTransform.getTranslateInstance(-hep.previewArea.x,-hep.previewArea.y));
+        AffineTransform aft=AffineTransform.getScaleInstance((1/hep.previewArea.getWidth()),(1/hep.previewArea.getHeight()));
+        aft.concatenate(AffineTransform.getTranslateInstance(-hep.previewArea.x,-hep.previewArea.y));
         if(getNumShapes()==1){ //Is a rectangle or a ellipse
-            EditableShape es=(EditableShape)((EditableShape)vShapes.elements().nextElement()).clone();
-            es.transform(at);
+            EditableShape es = (EditableShape)vShapes.get(0).clone();            
+            es.transform(aft);
             Shape s;
             if(es instanceof EditableEllipse2D)
                 s=((EditableEllipse2D)es).getEllipse();
@@ -809,10 +772,10 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
             sd=ShapeData.getShapeData(s, null, false);
         }
         else{
-            Vector v=getGeneralPath(); //Get only the first polygon found (should be unique)
+            List<GeneralPath> v=getGeneralPath(); //Get only the first polygon found (should be unique)
             if(v.size()>0){
-                GeneralPath gp=(GeneralPath)(v.elements().nextElement());
-                Shape s=gp.createTransformedShape(at);
+                GeneralPath gp=(v.get(0));
+                Shape s=gp.createTransformedShape(aft);
                 sd=ShapeData.getShapeData(s, null);
             }
         }
@@ -845,7 +808,7 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     
     private void removeDrawnBorders(ShapeData sd){
         Shape s=sd.getShape(hep.previewArea);
-        vDrawnBorders.removeAll(getBorders(s)); //removeAll removes all the instances of the elements passed over the Vector (only one instance is needed)
+        vDrawnBorders.removeAll(getBorders(s)); //removeAll removes all the instances of the elements passed over the shapedata (only one instance is needed)
     }
     
     public void endPolygon(ShapeData sd, boolean changeShape, boolean updateList,int iNextShape){
@@ -878,12 +841,9 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     private void aplicateTransformation(AffineTransform aTransf, boolean needSelected){
-        EditableShape current=null;
-        java.util.Enumeration e=vShapes.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            if(!needSelected || current.isSelected()){
-                current.transform(aTransf);
+        for(EditableShape esh : vShapes){
+            if(!needSelected || esh.isSelected()){
+                esh.transform(aTransf);
             }
         }
     }
@@ -914,13 +874,9 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     private Point2D getCenter(boolean cellCenter){
         //Returns the central point of the edited shape when cellCenter==false, otherwise, returns the center of the cell
         if(!cellCenter){
-            EditableShape current=null;
             GeneralPath gp=new GeneralPath();
-            java.util.Enumeration e=vShapes.elements();
-            while (e.hasMoreElements()){
-                current=(EditableShape)e.nextElement();
-                gp.append(current,false);
-            }
+            for(EditableShape esh: vShapes)
+                gp.append(esh,false);
             Rectangle2D r=gp.getBounds(); //to calculate the central point
             return new Point2D.Double(r.getCenterX(),r.getCenterY());
         }
@@ -929,13 +885,10 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     
     private void convertToSimpleShapes(){
         //If the edited shape is a rectangle or a ellipse, transform it to a set of segments or cubic lines
-        EditableShape current=null;
-        java.util.Enumeration e=vShapes.elements();
-        while (e.hasMoreElements()){
-            current=(EditableShape)e.nextElement();
-            if(current instanceof EditableRectangle){ //Rectangular shapes must be converted to simple shapes in order to rotate it
-                vShapes.remove(current);
-                EditableShape[] lines=((EditableRectangle)current).divide(-1,-1,false); //Do no add any point
+        for(EditableShape esh: vShapes){
+            if(esh instanceof EditableRectangle){ //Rectangular shapes must be converted to simple shapes in order to rotate it
+                vShapes.remove(esh);
+                EditableShape[] lines=((EditableRectangle)esh).divide(-1,-1,false); //Do no add any point
                 for (int i=0;i<lines.length;i++)
                     if(lines[i]!=null)
                         vShapes.add(lines[i]);
@@ -944,20 +897,20 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     private EditableShape getSelectedShape(boolean hasToBeALine){ //Returns the selected line when there is only one
-        java.util.Enumeration e=vShapes.elements();
-        EditableShape current, selected=null;
+        EditableShape selected=null;
         int i=0;
-        while (e.hasMoreElements() && i<2){
-            current=(EditableShape)e.nextElement();
-            if(current.isSelected()){
-                if(!hasToBeALine || current instanceof EditableLine2D){
-                    selected=current;
+        for(EditableShape esh : vShapes){
+            if(esh.isSelected()){
+                if(!hasToBeALine || esh instanceof EditableLine2D){
+                    selected=esh;
                     i++;
                 }
                 else{
                     i=2; //Do nothing
                 }
             }
+            if(i>=2)
+                break;            
         }
         if(i==1)
             return selected;
@@ -1017,9 +970,7 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     public void notifyShapeChanged(){
-        java.util.Enumeration e=vPointListeners.elements();
-        while (e.hasMoreElements()){
-            PointListener pl=(PointListener)e.nextElement();
+        for(PointListener pl : vPointListeners){
             pl.shapeChanged();
         }
     }
@@ -1028,23 +979,24 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
         vPointListeners.add(listener);
     }
     
-    public void undoLastMove(Vector vRedrawingLines, Vector vRedrawingLinesBeforeModify){
+    public void undoLastMove(List<EditableShape> vRedrawingLines, List<EditableShape> vRedrawingLinesBeforeModify){
         vShapes.removeAll(vRedrawingLines);
         vShapes.addAll(vRedrawingLinesBeforeModify);
         vRedrawingLines.clear();
     }
     
-    private boolean isIntoArea(Vector vShapes, boolean move){
+    private boolean isIntoArea(List<EditableShape> vShapes, boolean move){
         boolean isInto=true;
         Rectangle2D r=new Rectangle2D.Double(hep.previewArea.getX()-1,hep.previewArea.getY()-1,hep.previewArea.getWidth()+2,hep.previewArea.getHeight()+2);
-        java.util.Enumeration e=vShapes.elements();
         Point2D[] borders;
-        while (e.hasMoreElements() && isInto){
+        for(EditableShape esh : vShapes){
+            if(!isInto)
+                break;
             EditableShape es;
             if(!move)
-                es=(EditableShape)e.nextElement();
+                es=esh;
             else{
-                es=(EditableShape)((EditableShape)e.nextElement()).clone();
+                es=(EditableShape)esh.clone();
                 es.transform(AffineTransform.getTranslateInstance(finX-iniX,finY-iniY));
             }
             
@@ -1236,8 +1188,8 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
         Rectangle r=hep.getPreviewArea();
         double width=r.getWidth();
         double height=r.getHeight();
-        AffineTransform at=AffineTransform.getTranslateInstance(-hep.previewArea.x,-hep.previewArea.y);
-        at.transform(mousePoint,mousePoint);
+        AffineTransform aft=AffineTransform.getTranslateInstance(-hep.previewArea.x,-hep.previewArea.y);
+        aft.transform(mousePoint,mousePoint);
         if(mousePoint.getX()==(width-1) && mousePoint.getY()==(height-1))
             return SOUTH_EAST;
         else if(mousePoint.getX()==(width-1))
@@ -1258,27 +1210,21 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     protected void selectBorder(double x, double y){
-        java.util.Enumeration e=vShapes.elements();
-        while (e.hasMoreElements()){
-            EditableShape s=(EditableShape)e.nextElement();
+        for(EditableShape s : vShapes)
             s.selectBorder(x,y);
-        }
     }
     
     protected void deselectBorder(){
-        java.util.Enumeration e=vShapes.elements();
-        while (e.hasMoreElements()){
-            EditableShape s=(EditableShape)e.nextElement();
+        for(EditableShape s : vShapes)
             s.deselectBorder();
-        }
     }
     
-    protected boolean removeNullLines(java.util.Vector vRedrawingLines){
+    protected boolean removeNullLines(List<EditableShape> vRedrawingLines){
         //Removes from vRedrawingLines all the lines having the two points in (approximately) the same co-ordinates
         boolean canRemove=false;
-        java.util.Enumeration e=vRedrawingLines.elements();
-        while (e.hasMoreElements() && !canRemove){
-            EditableShape s=(EditableShape)e.nextElement();
+        for(EditableShape s : vRedrawingLines){
+            if(canRemove)
+                break;
             if(s instanceof EditableLine2D){
                 Point2D [] p=s.getBorders();
                 if(p.length>1){
@@ -1550,8 +1496,9 @@ public class PolygonDrawPanel implements java.awt.event.MouseMotionListener, jav
     }
     
     public class KeyHandler extends KeyAdapter{
+        @Override
         public void keyPressed(KeyEvent e){
-            if(e.getKeyCode()==e.VK_DELETE){
+            if(e.getKeyCode()==KeyEvent.VK_DELETE){
                 deleteSelected(false);
                 hep.shapeChanged();
             }
