@@ -21,15 +21,25 @@
 
 package edu.xtec.util;
 
-import java.awt.*;
-import java.util.*;
-import java.text.DateFormat;
+import java.awt.Color;
+import java.awt.Dimension;
+import java.awt.Font;
+import java.awt.Point;
+import java.awt.Rectangle;
 import java.io.OutputStream;
+import java.text.DateFormat;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Date;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Locale;
+import java.util.StringTokenizer;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.09.16
  */
 public class JDomUtility {
     
@@ -49,7 +59,7 @@ public class JDomUtility {
         if(v==null)
             return false;
         
-        Class cl=v.getClass();        
+        Class<?> cl=v.getClass();        
         if(e.getAttribute(key)!=null) return false;        
         if(cl.isArray()) return false;
         
@@ -154,8 +164,8 @@ public class JDomUtility {
     
     public static final String LEFT="left", RIGHT="right", TOP="top", BOTTOM="bottom", WIDTH="width", HEIGHT="height", UP="up", DOWN="down";
     
-    public static final org.jdom.Element getChildWithId(org.jdom.Element e, String name, String id){
-        org.jdom.Element result=null;
+    public static org.jdom.Element getChildWithId(org.jdom.Element e, String name, String id){
+        org.jdom.Element result;
         if(e!=null && id!=null && name!=null){
             Iterator it=e.getChildren(name).iterator();
             while(it.hasNext()){
@@ -168,7 +178,7 @@ public class JDomUtility {
     }
     
     public static final String RECTANGLE="rectangle";    
-    public static final Rectangle getRectangle(org.jdom.Element e, String id, Rectangle defaultValue) {
+    public static Rectangle getRectangle(org.jdom.Element e, String id, Rectangle defaultValue) {
         if(id!=null)
             e=getChildWithId(e, RECTANGLE, id);
         else if(e!=null && !e.getName().equals(RECTANGLE))
@@ -185,7 +195,7 @@ public class JDomUtility {
     }
     
     public static final String POINT="point";
-    public static final Point getPoint(org.jdom.Element e, String id, Point defaultValue) {
+    public static Point getPoint(org.jdom.Element e, String id, Point defaultValue) {
         if(id!=null)
             e=getChildWithId(e, POINT, id);
         else if(e!=null && !e.getName().equals(POINT))
@@ -199,7 +209,7 @@ public class JDomUtility {
     }
     
     public static final String DIMENSION="dimension";
-    public static final Dimension getDimension(org.jdom.Element e, String id, Dimension defaultValue) {
+    public static Dimension getDimension(org.jdom.Element e, String id, Dimension defaultValue) {
         if(id!=null)
             e=getChildWithId(e, DIMENSION, id);
         else if(e!=null && !e.getName().equals(DIMENSION))
@@ -213,7 +223,7 @@ public class JDomUtility {
     }
     
     public static final String OFFSET="offset";
-    public static final Point getOffset(org.jdom.Element e, String id, Point defaultValue) {
+    public static Point getOffset(org.jdom.Element e, String id, Point defaultValue) {
         if(id!=null)
             e=getChildWithId(e, OFFSET, id);
         else if(e!=null && !e.getName().equals(OFFSET))
@@ -336,13 +346,13 @@ public class JDomUtility {
     }
     
     public static String getParagraphs(org.jdom.Element e){
-        StringBuffer sb=null;
+        StringBuilder sb=null;
         if(e!=null){
             java.util.Iterator itr = e.getChildren(P).iterator();
             while (itr.hasNext()) {
                 String s=((org.jdom.Element)itr.next()).getText();
                 if(sb==null)
-                    sb=new StringBuffer(s);
+                    sb=new StringBuilder(s);
                 else
                     sb.append("\n").append(s);
             }
@@ -359,7 +369,7 @@ public class JDomUtility {
     }
     
     public static String intArrayToString(int[] v, int numElements){
-        StringBuffer sb=new StringBuffer(numElements*4);
+        StringBuilder sb=new StringBuilder(numElements*4);
         for(int i=0; i<numElements; i++){
             sb.append(v[i]).append(' ');
         }
@@ -367,10 +377,9 @@ public class JDomUtility {
     }
     
     public static int[] stringToIntArray(String s) throws Exception{
-        int[] result=null;
         StringTokenizer st=new StringTokenizer(s, " ");
         int numTokens=st.countTokens();
-        result=new int[numTokens];
+        int[] result=new int[numTokens];
         for(int i=0; i<numTokens; i++){
             result[i]=Integer.parseInt(st.nextToken());
         }
@@ -443,7 +452,7 @@ public class JDomUtility {
         Boolean result=defaultValue;
         if(s!=null){
             if(s.equalsIgnoreCase(BOOL_STR[TRUE]) || s.equalsIgnoreCase(BOOL_STR[FALSE])){
-                result=new Boolean(s);
+                result=Boolean.valueOf(s);
             } else{
                 throw new NumberFormatException("invalid boolean: " + s);
             }
@@ -546,7 +555,7 @@ public class JDomUtility {
     
     public static Date getDateAttrShortUS(org.jdom.Element e, String attr, Date defaultValue) throws Exception{
         Date result=defaultValue;
-        String s=null;
+        String s;
         if((s=getStringAttr(e, attr, null, false))!=null){
             result=DateFormat.getDateInstance(DateFormat.SHORT, Locale.US).parse(s);
         }
@@ -556,44 +565,24 @@ public class JDomUtility {
     public static final String NEWLINE="\n", BLANK="";
     public static void clearNewLineElements(org.jdom.Element e){
         if(e!=null){
-            java.util.Vector toRemove=null;            
+            List<org.jdom.Text> toRemove=null;            
             boolean hasChildren=!e.getChildren().isEmpty();
-            java.util.List content=e.getContent();
-            java.util.Iterator it=content.iterator();
-            while(it.hasNext()){
-                Object o=it.next();
+            List content= e.getContent();
+            for(Object o : content){
                 if(o instanceof org.jdom.Element)
                     clearNewLineElements((org.jdom.Element)o);
                 else if(hasChildren && o instanceof org.jdom.Text){
                     if(toRemove==null)
-                        toRemove=new java.util.Vector();
-                    toRemove.add(o);
-                }
-            }
-            if(toRemove!=null)
-                content.removeAll(toRemove);
-            
-            /*
-            java.util.List content=e.getContent();
-            java.util.Iterator it=content.iterator();
-            java.util.Vector toRemove=null;
-            while(it.hasNext()){
-                Object o=it.next();
-                if(o instanceof org.jdom.Element){
-                    clearNewLineElements((org.jdom.Element)o);
-                }
-                else if(o instanceof String){
-                    if(((String)o).startsWith(NEWLINE)){
-                        if(toRemove==null) toRemove=new java.util.Vector(content.size());
-                        toRemove.add(o);
-                    }
+                        toRemove=new ArrayList<org.jdom.Text>();
+                    toRemove.add((org.jdom.Text)o);
                 }
             }
+            //content.removeAll(toRemove);            
             if(toRemove!=null){
-                java.util.Iterator itr=toRemove.iterator();
-                while(itr.hasNext()) content.remove(itr.next());
+                for(org.jdom.Text o : toRemove){
+                    content.remove(o);                    
+                }
             }
-             */
         }
     }
         
@@ -643,10 +632,9 @@ public class JDomUtility {
     }
     
     public static String getClassName(org.jdom.Element e) throws Exception{
-        String className=e.getAttributeValue(CLASS);
         if(e==null)
             throw new org.jdom.JDOMException("Element without class name!");
-        return className;
+        return e.getAttributeValue(CLASS);
     }
     
 }
