@@ -21,15 +21,15 @@
 
 package edu.xtec.util;
 
-import java.io.*;
 import java.awt.Component;
-import javax.swing.*;
 import java.awt.event.*;
+import java.io.*;
+import javax.swing.*;
 
 /**
  *
- * @author Francesc Busquets (fbusquets@xtec.net)
- * @version 1.0
+ * @author Francesc Busquets (fbusquets@xtec.cat)
+ * @version 13.08.29
  */
 public class StreamIO{
         
@@ -54,7 +54,7 @@ public class StreamIO{
     
     public static byte[] readInputStream(InputStream is, InputStreamListener lst, int stepSize) throws IOException{
         cancel=false;
-        BufferedInputStream bufferedStream = null;
+        BufferedInputStream bufferedStream;
         if(is instanceof BufferedInputStream)
             bufferedStream=(BufferedInputStream)is;
         else
@@ -62,10 +62,9 @@ public class StreamIO{
         
         ByteArrayOutputStream os=new ByteArrayOutputStream();
         byte[] buffer=new byte[stepSize];
-        int bytesRead=0;
         while(!cancel){
             //bytesRead=is.read(buffer);
-            bytesRead=bufferedStream.read(buffer);
+            int bytesRead=bufferedStream.read(buffer);
             if(lst!=null) lst.notify(is, bytesRead);
             if(bytesRead<=0) break;
             os.write(buffer, 0, bytesRead);
@@ -119,13 +118,13 @@ public class StreamIO{
     
     public static void writeStreamTo(InputStream is, OutputStream os, InputStreamListener lst, int stepSize) throws IOException{
         cancel=false;        
-        BufferedInputStream bufferedStream = null;
+        BufferedInputStream bufferedStream;
         if(is instanceof BufferedInputStream)
             bufferedStream=(BufferedInputStream)is;
         else
             bufferedStream = new BufferedInputStream(is);
         
-        int bytesRead = 0;
+        int bytesRead;
         byte[] buf = new byte[stepSize];
         while(!cancel){
             bytesRead=bufferedStream.read(buf, 0, stepSize);
@@ -149,7 +148,7 @@ public class StreamIO{
         
         final Messages msg=options.getMessages();
         String title=msg.get("WRITING_FILE");
-        JDialog dialog=null;
+        JDialog dialog;
         if(dlgOwner instanceof java.awt.Dialog)
             dialog=new JDialog((java.awt.Dialog)dlgOwner, title, true);
         else if(dlgOwner!=null)
@@ -160,8 +159,6 @@ public class StreamIO{
         if(mainMsg!=null)
             dialog.getContentPane().add(new JLabel(mainMsg));
         
-        InputStreamListener isl=null;
-
         final JProgressBar progress=new JProgressBar();
 
         if(knownSize>0){
@@ -172,7 +169,7 @@ public class StreamIO{
         else
             progress.setIndeterminate(true);
 
-        isl=new InputStreamListener(){
+        InputStreamListener isl=new InputStreamListener(){
             public void notify(InputStream in, int bytesRead){
                 progress.setValue(bytesRead);
             }
@@ -192,8 +189,10 @@ public class StreamIO{
         dialog.pack();
         
         final JDialog dlg=dialog;
-        SwingWorker sw=new SwingWorker(){            
+        edu.xtec.util.SwingWorker sw=new edu.xtec.util.SwingWorker(){            
             private boolean result=false;
+            
+            @Override
             public Object construct(){
                 try{
                     writeStreamTo(is, os, iis, DEFAULT_READ_STEP_SIZE);                
@@ -203,7 +202,7 @@ public class StreamIO{
                     msg.showErrorWarning(dlg, "ERROR", ex);
                 }
                 dlg.setVisible(false);
-                return new Boolean(result);
+                return result;
             }            
         };        
         sw.startLater();
